import "@polkadot/types/lookup";
import type { Data } from "@polkadot/types";
import type { BTreeMap, BTreeSet, Bytes, Compact, Enum, Null, Option, Result, Set, Struct, Text, U256, U8aFixed, Vec, bool, i64, u128, u16, u32, u64, u8 } from "@polkadot/types-codec";
import type { ITuple } from "@polkadot/types-codec/types";
import type { Vote } from "@polkadot/types/interfaces/elections";
import type { AccountId20, Call, H160, H256, Perbill, Percent } from "@polkadot/types/interfaces/runtime";
import type { Event } from "@polkadot/types/interfaces/system";
declare module "@polkadot/types/lookup" {
    /** @name FrameSystemAccountInfo (3) */
    interface FrameSystemAccountInfo extends Struct {
        readonly nonce: u32;
        readonly consumers: u32;
        readonly providers: u32;
        readonly sufficients: u32;
        readonly data: PalletBalancesAccountData;
    }
    /** @name PalletBalancesAccountData (5) */
    interface PalletBalancesAccountData extends Struct {
        readonly free: u128;
        readonly reserved: u128;
        readonly miscFrozen: u128;
        readonly feeFrozen: u128;
    }
    /** @name FrameSupportDispatchPerDispatchClassWeight (7) */
    interface FrameSupportDispatchPerDispatchClassWeight extends Struct {
        readonly normal: SpWeightsWeightV2Weight;
        readonly operational: SpWeightsWeightV2Weight;
        readonly mandatory: SpWeightsWeightV2Weight;
    }
    /** @name SpWeightsWeightV2Weight (8) */
    interface SpWeightsWeightV2Weight extends Struct {
        readonly refTime: Compact<u64>;
        readonly proofSize: Compact<u64>;
    }
    /** @name SpRuntimeDigest (14) */
    interface SpRuntimeDigest extends Struct {
        readonly logs: Vec<SpRuntimeDigestDigestItem>;
    }
    /** @name SpRuntimeDigestDigestItem (16) */
    interface SpRuntimeDigestDigestItem extends Enum {
        readonly isOther: boolean;
        readonly asOther: Bytes;
        readonly isConsensus: boolean;
        readonly asConsensus: ITuple<[U8aFixed, Bytes]>;
        readonly isSeal: boolean;
        readonly asSeal: ITuple<[U8aFixed, Bytes]>;
        readonly isPreRuntime: boolean;
        readonly asPreRuntime: ITuple<[U8aFixed, Bytes]>;
        readonly isRuntimeEnvironmentUpdated: boolean;
        readonly type: "Other" | "Consensus" | "Seal" | "PreRuntime" | "RuntimeEnvironmentUpdated";
    }
    /** @name FrameSystemEventRecord (19) */
    interface FrameSystemEventRecord extends Struct {
        readonly phase: FrameSystemPhase;
        readonly event: Event;
        readonly topics: Vec<H256>;
    }
    /** @name FrameSystemEvent (21) */
    interface FrameSystemEvent extends Enum {
        readonly isExtrinsicSuccess: boolean;
        readonly asExtrinsicSuccess: {
            readonly dispatchInfo: FrameSupportDispatchDispatchInfo;
        } & Struct;
        readonly isExtrinsicFailed: boolean;
        readonly asExtrinsicFailed: {
            readonly dispatchError: SpRuntimeDispatchError;
            readonly dispatchInfo: FrameSupportDispatchDispatchInfo;
        } & Struct;
        readonly isCodeUpdated: boolean;
        readonly isNewAccount: boolean;
        readonly asNewAccount: {
            readonly account: AccountId20;
        } & Struct;
        readonly isKilledAccount: boolean;
        readonly asKilledAccount: {
            readonly account: AccountId20;
        } & Struct;
        readonly isRemarked: boolean;
        readonly asRemarked: {
            readonly sender: AccountId20;
            readonly hash_: H256;
        } & Struct;
        readonly type: "ExtrinsicSuccess" | "ExtrinsicFailed" | "CodeUpdated" | "NewAccount" | "KilledAccount" | "Remarked";
    }
    /** @name FrameSupportDispatchDispatchInfo (22) */
    interface FrameSupportDispatchDispatchInfo extends Struct {
        readonly weight: SpWeightsWeightV2Weight;
        readonly class: FrameSupportDispatchDispatchClass;
        readonly paysFee: FrameSupportDispatchPays;
    }
    /** @name FrameSupportDispatchDispatchClass (23) */
    interface FrameSupportDispatchDispatchClass extends Enum {
        readonly isNormal: boolean;
        readonly isOperational: boolean;
        readonly isMandatory: boolean;
        readonly type: "Normal" | "Operational" | "Mandatory";
    }
    /** @name FrameSupportDispatchPays (24) */
    interface FrameSupportDispatchPays extends Enum {
        readonly isYes: boolean;
        readonly isNo: boolean;
        readonly type: "Yes" | "No";
    }
    /** @name SpRuntimeDispatchError (25) */
    interface SpRuntimeDispatchError extends Enum {
        readonly isOther: boolean;
        readonly isCannotLookup: boolean;
        readonly isBadOrigin: boolean;
        readonly isModule: boolean;
        readonly asModule: SpRuntimeModuleError;
        readonly isConsumerRemaining: boolean;
        readonly isNoProviders: boolean;
        readonly isTooManyConsumers: boolean;
        readonly isToken: boolean;
        readonly asToken: SpRuntimeTokenError;
        readonly isArithmetic: boolean;
        readonly asArithmetic: SpArithmeticArithmeticError;
        readonly isTransactional: boolean;
        readonly asTransactional: SpRuntimeTransactionalError;
        readonly isExhausted: boolean;
        readonly isCorruption: boolean;
        readonly isUnavailable: boolean;
        readonly type: "Other" | "CannotLookup" | "BadOrigin" | "Module" | "ConsumerRemaining" | "NoProviders" | "TooManyConsumers" | "Token" | "Arithmetic" | "Transactional" | "Exhausted" | "Corruption" | "Unavailable";
    }
    /** @name SpRuntimeModuleError (26) */
    interface SpRuntimeModuleError extends Struct {
        readonly index: u8;
        readonly error: U8aFixed;
    }
    /** @name SpRuntimeTokenError (27) */
    interface SpRuntimeTokenError extends Enum {
        readonly isNoFunds: boolean;
        readonly isWouldDie: boolean;
        readonly isBelowMinimum: boolean;
        readonly isCannotCreate: boolean;
        readonly isUnknownAsset: boolean;
        readonly isFrozen: boolean;
        readonly isUnsupported: boolean;
        readonly type: "NoFunds" | "WouldDie" | "BelowMinimum" | "CannotCreate" | "UnknownAsset" | "Frozen" | "Unsupported";
    }
    /** @name SpArithmeticArithmeticError (28) */
    interface SpArithmeticArithmeticError extends Enum {
        readonly isUnderflow: boolean;
        readonly isOverflow: boolean;
        readonly isDivisionByZero: boolean;
        readonly type: "Underflow" | "Overflow" | "DivisionByZero";
    }
    /** @name SpRuntimeTransactionalError (29) */
    interface SpRuntimeTransactionalError extends Enum {
        readonly isLimitReached: boolean;
        readonly isNoLayer: boolean;
        readonly type: "LimitReached" | "NoLayer";
    }
    /** @name CumulusPalletParachainSystemEvent (30) */
    interface CumulusPalletParachainSystemEvent extends Enum {
        readonly isValidationFunctionStored: boolean;
        readonly isValidationFunctionApplied: boolean;
        readonly asValidationFunctionApplied: {
            readonly relayChainBlockNum: u32;
        } & Struct;
        readonly isValidationFunctionDiscarded: boolean;
        readonly isUpgradeAuthorized: boolean;
        readonly asUpgradeAuthorized: {
            readonly codeHash: H256;
        } & Struct;
        readonly isDownwardMessagesReceived: boolean;
        readonly asDownwardMessagesReceived: {
            readonly count: u32;
        } & Struct;
        readonly isDownwardMessagesProcessed: boolean;
        readonly asDownwardMessagesProcessed: {
            readonly weightUsed: SpWeightsWeightV2Weight;
            readonly dmqHead: H256;
        } & Struct;
        readonly isUpwardMessageSent: boolean;
        readonly asUpwardMessageSent: {
            readonly messageHash: Option<U8aFixed>;
        } & Struct;
        readonly type: "ValidationFunctionStored" | "ValidationFunctionApplied" | "ValidationFunctionDiscarded" | "UpgradeAuthorized" | "DownwardMessagesReceived" | "DownwardMessagesProcessed" | "UpwardMessageSent";
    }
    /** @name PalletBalancesEvent (32) */
    interface PalletBalancesEvent extends Enum {
        readonly isEndowed: boolean;
        readonly asEndowed: {
            readonly account: AccountId20;
            readonly freeBalance: u128;
        } & Struct;
        readonly isDustLost: boolean;
        readonly asDustLost: {
            readonly account: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly from: AccountId20;
            readonly to: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isBalanceSet: boolean;
        readonly asBalanceSet: {
            readonly who: AccountId20;
            readonly free: u128;
            readonly reserved: u128;
        } & Struct;
        readonly isReserved: boolean;
        readonly asReserved: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isUnreserved: boolean;
        readonly asUnreserved: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isReserveRepatriated: boolean;
        readonly asReserveRepatriated: {
            readonly from: AccountId20;
            readonly to: AccountId20;
            readonly amount: u128;
            readonly destinationStatus: FrameSupportTokensMiscBalanceStatus;
        } & Struct;
        readonly isDeposit: boolean;
        readonly asDeposit: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isWithdraw: boolean;
        readonly asWithdraw: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isSlashed: boolean;
        readonly asSlashed: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly type: "Endowed" | "DustLost" | "Transfer" | "BalanceSet" | "Reserved" | "Unreserved" | "ReserveRepatriated" | "Deposit" | "Withdraw" | "Slashed";
    }
    /** @name FrameSupportTokensMiscBalanceStatus (33) */
    interface FrameSupportTokensMiscBalanceStatus extends Enum {
        readonly isFree: boolean;
        readonly isReserved: boolean;
        readonly type: "Free" | "Reserved";
    }
    /** @name PalletTransactionPaymentEvent (34) */
    interface PalletTransactionPaymentEvent extends Enum {
        readonly isTransactionFeePaid: boolean;
        readonly asTransactionFeePaid: {
            readonly who: AccountId20;
            readonly actualFee: u128;
            readonly tip: u128;
        } & Struct;
        readonly type: "TransactionFeePaid";
    }
    /** @name PalletParachainStakingEvent (35) */
    interface PalletParachainStakingEvent extends Enum {
        readonly isNewRound: boolean;
        readonly asNewRound: {
            readonly startingBlock: u32;
            readonly round: u32;
            readonly selectedCollatorsNumber: u32;
            readonly totalBalance: u128;
        } & Struct;
        readonly isJoinedCollatorCandidates: boolean;
        readonly asJoinedCollatorCandidates: {
            readonly account: AccountId20;
            readonly amountLocked: u128;
            readonly newTotalAmtLocked: u128;
        } & Struct;
        readonly isCollatorChosen: boolean;
        readonly asCollatorChosen: {
            readonly round: u32;
            readonly collatorAccount: AccountId20;
            readonly totalExposedAmount: u128;
        } & Struct;
        readonly isCandidateBondLessRequested: boolean;
        readonly asCandidateBondLessRequested: {
            readonly candidate: AccountId20;
            readonly amountToDecrease: u128;
            readonly executeRound: u32;
        } & Struct;
        readonly isCandidateBondedMore: boolean;
        readonly asCandidateBondedMore: {
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly newTotalBond: u128;
        } & Struct;
        readonly isCandidateBondedLess: boolean;
        readonly asCandidateBondedLess: {
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly newBond: u128;
        } & Struct;
        readonly isCandidateWentOffline: boolean;
        readonly asCandidateWentOffline: {
            readonly candidate: AccountId20;
        } & Struct;
        readonly isCandidateBackOnline: boolean;
        readonly asCandidateBackOnline: {
            readonly candidate: AccountId20;
        } & Struct;
        readonly isCandidateScheduledExit: boolean;
        readonly asCandidateScheduledExit: {
            readonly exitAllowedRound: u32;
            readonly candidate: AccountId20;
            readonly scheduledExit: u32;
        } & Struct;
        readonly isCancelledCandidateExit: boolean;
        readonly asCancelledCandidateExit: {
            readonly candidate: AccountId20;
        } & Struct;
        readonly isCancelledCandidateBondLess: boolean;
        readonly asCancelledCandidateBondLess: {
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly executeRound: u32;
        } & Struct;
        readonly isCandidateLeft: boolean;
        readonly asCandidateLeft: {
            readonly exCandidate: AccountId20;
            readonly unlockedAmount: u128;
            readonly newTotalAmtLocked: u128;
        } & Struct;
        readonly isDelegationDecreaseScheduled: boolean;
        readonly asDelegationDecreaseScheduled: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly amountToDecrease: u128;
            readonly executeRound: u32;
        } & Struct;
        readonly isDelegationIncreased: boolean;
        readonly asDelegationIncreased: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly inTop: bool;
        } & Struct;
        readonly isDelegationDecreased: boolean;
        readonly asDelegationDecreased: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly inTop: bool;
        } & Struct;
        readonly isDelegatorExitScheduled: boolean;
        readonly asDelegatorExitScheduled: {
            readonly round: u32;
            readonly delegator: AccountId20;
            readonly scheduledExit: u32;
        } & Struct;
        readonly isDelegationRevocationScheduled: boolean;
        readonly asDelegationRevocationScheduled: {
            readonly round: u32;
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly scheduledExit: u32;
        } & Struct;
        readonly isDelegatorLeft: boolean;
        readonly asDelegatorLeft: {
            readonly delegator: AccountId20;
            readonly unstakedAmount: u128;
        } & Struct;
        readonly isDelegationRevoked: boolean;
        readonly asDelegationRevoked: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly unstakedAmount: u128;
        } & Struct;
        readonly isDelegationKicked: boolean;
        readonly asDelegationKicked: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly unstakedAmount: u128;
        } & Struct;
        readonly isDelegatorExitCancelled: boolean;
        readonly asDelegatorExitCancelled: {
            readonly delegator: AccountId20;
        } & Struct;
        readonly isCancelledDelegationRequest: boolean;
        readonly asCancelledDelegationRequest: {
            readonly delegator: AccountId20;
            readonly cancelledRequest: PalletParachainStakingDelegationRequestsCancelledScheduledRequest;
            readonly collator: AccountId20;
        } & Struct;
        readonly isDelegation: boolean;
        readonly asDelegation: {
            readonly delegator: AccountId20;
            readonly lockedAmount: u128;
            readonly candidate: AccountId20;
            readonly delegatorPosition: PalletParachainStakingDelegatorAdded;
            readonly autoCompound: Percent;
        } & Struct;
        readonly isDelegatorLeftCandidate: boolean;
        readonly asDelegatorLeftCandidate: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
            readonly unstakedAmount: u128;
            readonly totalCandidateStaked: u128;
        } & Struct;
        readonly isRewarded: boolean;
        readonly asRewarded: {
            readonly account: AccountId20;
            readonly rewards: u128;
        } & Struct;
        readonly isReservedForParachainBond: boolean;
        readonly asReservedForParachainBond: {
            readonly account: AccountId20;
            readonly value: u128;
        } & Struct;
        readonly isParachainBondAccountSet: boolean;
        readonly asParachainBondAccountSet: {
            readonly old: AccountId20;
            readonly new_: AccountId20;
        } & Struct;
        readonly isParachainBondReservePercentSet: boolean;
        readonly asParachainBondReservePercentSet: {
            readonly old: Percent;
            readonly new_: Percent;
        } & Struct;
        readonly isInflationSet: boolean;
        readonly asInflationSet: {
            readonly annualMin: Perbill;
            readonly annualIdeal: Perbill;
            readonly annualMax: Perbill;
            readonly roundMin: Perbill;
            readonly roundIdeal: Perbill;
            readonly roundMax: Perbill;
        } & Struct;
        readonly isStakeExpectationsSet: boolean;
        readonly asStakeExpectationsSet: {
            readonly expectMin: u128;
            readonly expectIdeal: u128;
            readonly expectMax: u128;
        } & Struct;
        readonly isTotalSelectedSet: boolean;
        readonly asTotalSelectedSet: {
            readonly old: u32;
            readonly new_: u32;
        } & Struct;
        readonly isCollatorCommissionSet: boolean;
        readonly asCollatorCommissionSet: {
            readonly old: Perbill;
            readonly new_: Perbill;
        } & Struct;
        readonly isBlocksPerRoundSet: boolean;
        readonly asBlocksPerRoundSet: {
            readonly currentRound: u32;
            readonly firstBlock: u32;
            readonly old: u32;
            readonly new_: u32;
            readonly newPerRoundInflationMin: Perbill;
            readonly newPerRoundInflationIdeal: Perbill;
            readonly newPerRoundInflationMax: Perbill;
        } & Struct;
        readonly isAutoCompoundSet: boolean;
        readonly asAutoCompoundSet: {
            readonly candidate: AccountId20;
            readonly delegator: AccountId20;
            readonly value: Percent;
        } & Struct;
        readonly isCompounded: boolean;
        readonly asCompounded: {
            readonly candidate: AccountId20;
            readonly delegator: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly type: "NewRound" | "JoinedCollatorCandidates" | "CollatorChosen" | "CandidateBondLessRequested" | "CandidateBondedMore" | "CandidateBondedLess" | "CandidateWentOffline" | "CandidateBackOnline" | "CandidateScheduledExit" | "CancelledCandidateExit" | "CancelledCandidateBondLess" | "CandidateLeft" | "DelegationDecreaseScheduled" | "DelegationIncreased" | "DelegationDecreased" | "DelegatorExitScheduled" | "DelegationRevocationScheduled" | "DelegatorLeft" | "DelegationRevoked" | "DelegationKicked" | "DelegatorExitCancelled" | "CancelledDelegationRequest" | "Delegation" | "DelegatorLeftCandidate" | "Rewarded" | "ReservedForParachainBond" | "ParachainBondAccountSet" | "ParachainBondReservePercentSet" | "InflationSet" | "StakeExpectationsSet" | "TotalSelectedSet" | "CollatorCommissionSet" | "BlocksPerRoundSet" | "AutoCompoundSet" | "Compounded";
    }
    /** @name PalletParachainStakingDelegationRequestsCancelledScheduledRequest (37) */
    interface PalletParachainStakingDelegationRequestsCancelledScheduledRequest extends Struct {
        readonly whenExecutable: u32;
        readonly action: PalletParachainStakingDelegationRequestsDelegationAction;
    }
    /** @name PalletParachainStakingDelegationRequestsDelegationAction (38) */
    interface PalletParachainStakingDelegationRequestsDelegationAction extends Enum {
        readonly isRevoke: boolean;
        readonly asRevoke: u128;
        readonly isDecrease: boolean;
        readonly asDecrease: u128;
        readonly type: "Revoke" | "Decrease";
    }
    /** @name PalletParachainStakingDelegatorAdded (39) */
    interface PalletParachainStakingDelegatorAdded extends Enum {
        readonly isAddedToTop: boolean;
        readonly asAddedToTop: {
            readonly newTotal: u128;
        } & Struct;
        readonly isAddedToBottom: boolean;
        readonly type: "AddedToTop" | "AddedToBottom";
    }
    /** @name PalletAuthorSlotFilterEvent (42) */
    interface PalletAuthorSlotFilterEvent extends Enum {
        readonly isEligibleUpdated: boolean;
        readonly asEligibleUpdated: u32;
        readonly type: "EligibleUpdated";
    }
    /** @name PalletAuthorMappingEvent (44) */
    interface PalletAuthorMappingEvent extends Enum {
        readonly isKeysRegistered: boolean;
        readonly asKeysRegistered: {
            readonly nimbusId: NimbusPrimitivesNimbusCryptoPublic;
            readonly accountId: AccountId20;
            readonly keys_: SessionKeysPrimitivesVrfVrfCryptoPublic;
        } & Struct;
        readonly isKeysRemoved: boolean;
        readonly asKeysRemoved: {
            readonly nimbusId: NimbusPrimitivesNimbusCryptoPublic;
            readonly accountId: AccountId20;
            readonly keys_: SessionKeysPrimitivesVrfVrfCryptoPublic;
        } & Struct;
        readonly isKeysRotated: boolean;
        readonly asKeysRotated: {
            readonly newNimbusId: NimbusPrimitivesNimbusCryptoPublic;
            readonly accountId: AccountId20;
            readonly newKeys: SessionKeysPrimitivesVrfVrfCryptoPublic;
        } & Struct;
        readonly type: "KeysRegistered" | "KeysRemoved" | "KeysRotated";
    }
    /** @name NimbusPrimitivesNimbusCryptoPublic (45) */
    interface NimbusPrimitivesNimbusCryptoPublic extends SpCoreSr25519Public {
    }
    /** @name SpCoreSr25519Public (46) */
    interface SpCoreSr25519Public extends U8aFixed {
    }
    /** @name SessionKeysPrimitivesVrfVrfCryptoPublic (47) */
    interface SessionKeysPrimitivesVrfVrfCryptoPublic extends SpCoreSr25519Public {
    }
    /** @name PalletMoonbeamOrbitersEvent (48) */
    interface PalletMoonbeamOrbitersEvent extends Enum {
        readonly isOrbiterJoinCollatorPool: boolean;
        readonly asOrbiterJoinCollatorPool: {
            readonly collator: AccountId20;
            readonly orbiter: AccountId20;
        } & Struct;
        readonly isOrbiterLeaveCollatorPool: boolean;
        readonly asOrbiterLeaveCollatorPool: {
            readonly collator: AccountId20;
            readonly orbiter: AccountId20;
        } & Struct;
        readonly isOrbiterRewarded: boolean;
        readonly asOrbiterRewarded: {
            readonly account: AccountId20;
            readonly rewards: u128;
        } & Struct;
        readonly isOrbiterRotation: boolean;
        readonly asOrbiterRotation: {
            readonly collator: AccountId20;
            readonly oldOrbiter: Option<AccountId20>;
            readonly newOrbiter: Option<AccountId20>;
        } & Struct;
        readonly isOrbiterRegistered: boolean;
        readonly asOrbiterRegistered: {
            readonly account: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly isOrbiterUnregistered: boolean;
        readonly asOrbiterUnregistered: {
            readonly account: AccountId20;
        } & Struct;
        readonly type: "OrbiterJoinCollatorPool" | "OrbiterLeaveCollatorPool" | "OrbiterRewarded" | "OrbiterRotation" | "OrbiterRegistered" | "OrbiterUnregistered";
    }
    /** @name PalletUtilityEvent (50) */
    interface PalletUtilityEvent extends Enum {
        readonly isBatchInterrupted: boolean;
        readonly asBatchInterrupted: {
            readonly index: u32;
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly isBatchCompleted: boolean;
        readonly isBatchCompletedWithErrors: boolean;
        readonly isItemCompleted: boolean;
        readonly isItemFailed: boolean;
        readonly asItemFailed: {
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly isDispatchedAs: boolean;
        readonly asDispatchedAs: {
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly type: "BatchInterrupted" | "BatchCompleted" | "BatchCompletedWithErrors" | "ItemCompleted" | "ItemFailed" | "DispatchedAs";
    }
    /** @name PalletProxyEvent (53) */
    interface PalletProxyEvent extends Enum {
        readonly isProxyExecuted: boolean;
        readonly asProxyExecuted: {
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isPureCreated: boolean;
        readonly asPureCreated: {
            readonly pure: AccountId20;
            readonly who: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly disambiguationIndex: u16;
        } & Struct;
        readonly isAnnounced: boolean;
        readonly asAnnounced: {
            readonly real: AccountId20;
            readonly proxy: AccountId20;
            readonly callHash: H256;
        } & Struct;
        readonly isProxyAdded: boolean;
        readonly asProxyAdded: {
            readonly delegator: AccountId20;
            readonly delegatee: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly isProxyRemoved: boolean;
        readonly asProxyRemoved: {
            readonly delegator: AccountId20;
            readonly delegatee: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly type: "ProxyExecuted" | "PureCreated" | "Announced" | "ProxyAdded" | "ProxyRemoved";
    }
    /** @name MoonriverRuntimeProxyType (54) */
    interface MoonriverRuntimeProxyType extends Enum {
        readonly isAny: boolean;
        readonly isNonTransfer: boolean;
        readonly isGovernance: boolean;
        readonly isStaking: boolean;
        readonly isCancelProxy: boolean;
        readonly isBalances: boolean;
        readonly isAuthorMapping: boolean;
        readonly isIdentityJudgement: boolean;
        readonly type: "Any" | "NonTransfer" | "Governance" | "Staking" | "CancelProxy" | "Balances" | "AuthorMapping" | "IdentityJudgement";
    }
    /** @name PalletMaintenanceModeEvent (56) */
    interface PalletMaintenanceModeEvent extends Enum {
        readonly isEnteredMaintenanceMode: boolean;
        readonly isNormalOperationResumed: boolean;
        readonly isFailedToSuspendIdleXcmExecution: boolean;
        readonly asFailedToSuspendIdleXcmExecution: {
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly isFailedToResumeIdleXcmExecution: boolean;
        readonly asFailedToResumeIdleXcmExecution: {
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly type: "EnteredMaintenanceMode" | "NormalOperationResumed" | "FailedToSuspendIdleXcmExecution" | "FailedToResumeIdleXcmExecution";
    }
    /** @name PalletIdentityEvent (57) */
    interface PalletIdentityEvent extends Enum {
        readonly isIdentitySet: boolean;
        readonly asIdentitySet: {
            readonly who: AccountId20;
        } & Struct;
        readonly isIdentityCleared: boolean;
        readonly asIdentityCleared: {
            readonly who: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly isIdentityKilled: boolean;
        readonly asIdentityKilled: {
            readonly who: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly isJudgementRequested: boolean;
        readonly asJudgementRequested: {
            readonly who: AccountId20;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isJudgementUnrequested: boolean;
        readonly asJudgementUnrequested: {
            readonly who: AccountId20;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isJudgementGiven: boolean;
        readonly asJudgementGiven: {
            readonly target: AccountId20;
            readonly registrarIndex: u32;
        } & Struct;
        readonly isRegistrarAdded: boolean;
        readonly asRegistrarAdded: {
            readonly registrarIndex: u32;
        } & Struct;
        readonly isSubIdentityAdded: boolean;
        readonly asSubIdentityAdded: {
            readonly sub: AccountId20;
            readonly main: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly isSubIdentityRemoved: boolean;
        readonly asSubIdentityRemoved: {
            readonly sub: AccountId20;
            readonly main: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly isSubIdentityRevoked: boolean;
        readonly asSubIdentityRevoked: {
            readonly sub: AccountId20;
            readonly main: AccountId20;
            readonly deposit: u128;
        } & Struct;
        readonly type: "IdentitySet" | "IdentityCleared" | "IdentityKilled" | "JudgementRequested" | "JudgementUnrequested" | "JudgementGiven" | "RegistrarAdded" | "SubIdentityAdded" | "SubIdentityRemoved" | "SubIdentityRevoked";
    }
    /** @name PalletMigrationsEvent (58) */
    interface PalletMigrationsEvent extends Enum {
        readonly isRuntimeUpgradeStarted: boolean;
        readonly isRuntimeUpgradeCompleted: boolean;
        readonly asRuntimeUpgradeCompleted: {
            readonly weight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isMigrationStarted: boolean;
        readonly asMigrationStarted: {
            readonly migrationName: Bytes;
        } & Struct;
        readonly isMigrationCompleted: boolean;
        readonly asMigrationCompleted: {
            readonly migrationName: Bytes;
            readonly consumedWeight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isFailedToSuspendIdleXcmExecution: boolean;
        readonly asFailedToSuspendIdleXcmExecution: {
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly isFailedToResumeIdleXcmExecution: boolean;
        readonly asFailedToResumeIdleXcmExecution: {
            readonly error: SpRuntimeDispatchError;
        } & Struct;
        readonly type: "RuntimeUpgradeStarted" | "RuntimeUpgradeCompleted" | "MigrationStarted" | "MigrationCompleted" | "FailedToSuspendIdleXcmExecution" | "FailedToResumeIdleXcmExecution";
    }
    /** @name PalletEvmEvent (59) */
    interface PalletEvmEvent extends Enum {
        readonly isLog: boolean;
        readonly asLog: {
            readonly log: EthereumLog;
        } & Struct;
        readonly isCreated: boolean;
        readonly asCreated: {
            readonly address: H160;
        } & Struct;
        readonly isCreatedFailed: boolean;
        readonly asCreatedFailed: {
            readonly address: H160;
        } & Struct;
        readonly isExecuted: boolean;
        readonly asExecuted: {
            readonly address: H160;
        } & Struct;
        readonly isExecutedFailed: boolean;
        readonly asExecutedFailed: {
            readonly address: H160;
        } & Struct;
        readonly type: "Log" | "Created" | "CreatedFailed" | "Executed" | "ExecutedFailed";
    }
    /** @name EthereumLog (60) */
    interface EthereumLog extends Struct {
        readonly address: H160;
        readonly topics: Vec<H256>;
        readonly data: Bytes;
    }
    /** @name PalletEthereumEvent (63) */
    interface PalletEthereumEvent extends Enum {
        readonly isExecuted: boolean;
        readonly asExecuted: {
            readonly from: H160;
            readonly to: H160;
            readonly transactionHash: H256;
            readonly exitReason: EvmCoreErrorExitReason;
        } & Struct;
        readonly type: "Executed";
    }
    /** @name EvmCoreErrorExitReason (64) */
    interface EvmCoreErrorExitReason extends Enum {
        readonly isSucceed: boolean;
        readonly asSucceed: EvmCoreErrorExitSucceed;
        readonly isError: boolean;
        readonly asError: EvmCoreErrorExitError;
        readonly isRevert: boolean;
        readonly asRevert: EvmCoreErrorExitRevert;
        readonly isFatal: boolean;
        readonly asFatal: EvmCoreErrorExitFatal;
        readonly type: "Succeed" | "Error" | "Revert" | "Fatal";
    }
    /** @name EvmCoreErrorExitSucceed (65) */
    interface EvmCoreErrorExitSucceed extends Enum {
        readonly isStopped: boolean;
        readonly isReturned: boolean;
        readonly isSuicided: boolean;
        readonly type: "Stopped" | "Returned" | "Suicided";
    }
    /** @name EvmCoreErrorExitError (66) */
    interface EvmCoreErrorExitError extends Enum {
        readonly isStackUnderflow: boolean;
        readonly isStackOverflow: boolean;
        readonly isInvalidJump: boolean;
        readonly isInvalidRange: boolean;
        readonly isDesignatedInvalid: boolean;
        readonly isCallTooDeep: boolean;
        readonly isCreateCollision: boolean;
        readonly isCreateContractLimit: boolean;
        readonly isOutOfOffset: boolean;
        readonly isOutOfGas: boolean;
        readonly isOutOfFund: boolean;
        readonly isPcUnderflow: boolean;
        readonly isCreateEmpty: boolean;
        readonly isOther: boolean;
        readonly asOther: Text;
        readonly isInvalidCode: boolean;
        readonly asInvalidCode: u8;
        readonly type: "StackUnderflow" | "StackOverflow" | "InvalidJump" | "InvalidRange" | "DesignatedInvalid" | "CallTooDeep" | "CreateCollision" | "CreateContractLimit" | "OutOfOffset" | "OutOfGas" | "OutOfFund" | "PcUnderflow" | "CreateEmpty" | "Other" | "InvalidCode";
    }
    /** @name EvmCoreErrorExitRevert (70) */
    interface EvmCoreErrorExitRevert extends Enum {
        readonly isReverted: boolean;
        readonly type: "Reverted";
    }
    /** @name EvmCoreErrorExitFatal (71) */
    interface EvmCoreErrorExitFatal extends Enum {
        readonly isNotSupported: boolean;
        readonly isUnhandledInterrupt: boolean;
        readonly isCallErrorAsFatal: boolean;
        readonly asCallErrorAsFatal: EvmCoreErrorExitError;
        readonly isOther: boolean;
        readonly asOther: Text;
        readonly type: "NotSupported" | "UnhandledInterrupt" | "CallErrorAsFatal" | "Other";
    }
    /** @name PalletSchedulerEvent (72) */
    interface PalletSchedulerEvent extends Enum {
        readonly isScheduled: boolean;
        readonly asScheduled: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isCanceled: boolean;
        readonly asCanceled: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isDispatched: boolean;
        readonly asDispatched: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<U8aFixed>;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isCallUnavailable: boolean;
        readonly asCallUnavailable: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<U8aFixed>;
        } & Struct;
        readonly isPeriodicFailed: boolean;
        readonly asPeriodicFailed: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<U8aFixed>;
        } & Struct;
        readonly isPermanentlyOverweight: boolean;
        readonly asPermanentlyOverweight: {
            readonly task: ITuple<[u32, u32]>;
            readonly id: Option<U8aFixed>;
        } & Struct;
        readonly type: "Scheduled" | "Canceled" | "Dispatched" | "CallUnavailable" | "PeriodicFailed" | "PermanentlyOverweight";
    }
    /** @name PalletDemocracyEvent (74) */
    interface PalletDemocracyEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly proposalIndex: u32;
            readonly deposit: u128;
        } & Struct;
        readonly isTabled: boolean;
        readonly asTabled: {
            readonly proposalIndex: u32;
            readonly deposit: u128;
        } & Struct;
        readonly isExternalTabled: boolean;
        readonly isStarted: boolean;
        readonly asStarted: {
            readonly refIndex: u32;
            readonly threshold: PalletDemocracyVoteThreshold;
        } & Struct;
        readonly isPassed: boolean;
        readonly asPassed: {
            readonly refIndex: u32;
        } & Struct;
        readonly isNotPassed: boolean;
        readonly asNotPassed: {
            readonly refIndex: u32;
        } & Struct;
        readonly isCancelled: boolean;
        readonly asCancelled: {
            readonly refIndex: u32;
        } & Struct;
        readonly isDelegated: boolean;
        readonly asDelegated: {
            readonly who: AccountId20;
            readonly target: AccountId20;
        } & Struct;
        readonly isUndelegated: boolean;
        readonly asUndelegated: {
            readonly account: AccountId20;
        } & Struct;
        readonly isVetoed: boolean;
        readonly asVetoed: {
            readonly who: AccountId20;
            readonly proposalHash: H256;
            readonly until: u32;
        } & Struct;
        readonly isBlacklisted: boolean;
        readonly asBlacklisted: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isVoted: boolean;
        readonly asVoted: {
            readonly voter: AccountId20;
            readonly refIndex: u32;
            readonly vote: PalletDemocracyVoteAccountVote;
        } & Struct;
        readonly isSeconded: boolean;
        readonly asSeconded: {
            readonly seconder: AccountId20;
            readonly propIndex: u32;
        } & Struct;
        readonly isProposalCanceled: boolean;
        readonly asProposalCanceled: {
            readonly propIndex: u32;
        } & Struct;
        readonly type: "Proposed" | "Tabled" | "ExternalTabled" | "Started" | "Passed" | "NotPassed" | "Cancelled" | "Delegated" | "Undelegated" | "Vetoed" | "Blacklisted" | "Voted" | "Seconded" | "ProposalCanceled";
    }
    /** @name PalletDemocracyVoteThreshold (75) */
    interface PalletDemocracyVoteThreshold extends Enum {
        readonly isSuperMajorityApprove: boolean;
        readonly isSuperMajorityAgainst: boolean;
        readonly isSimpleMajority: boolean;
        readonly type: "SuperMajorityApprove" | "SuperMajorityAgainst" | "SimpleMajority";
    }
    /** @name PalletDemocracyVoteAccountVote (76) */
    interface PalletDemocracyVoteAccountVote extends Enum {
        readonly isStandard: boolean;
        readonly asStandard: {
            readonly vote: Vote;
            readonly balance: u128;
        } & Struct;
        readonly isSplit: boolean;
        readonly asSplit: {
            readonly aye: u128;
            readonly nay: u128;
        } & Struct;
        readonly type: "Standard" | "Split";
    }
    /** @name PalletPreimageEvent (78) */
    interface PalletPreimageEvent extends Enum {
        readonly isNoted: boolean;
        readonly asNoted: {
            readonly hash_: H256;
        } & Struct;
        readonly isRequested: boolean;
        readonly asRequested: {
            readonly hash_: H256;
        } & Struct;
        readonly isCleared: boolean;
        readonly asCleared: {
            readonly hash_: H256;
        } & Struct;
        readonly type: "Noted" | "Requested" | "Cleared";
    }
    /** @name PalletConvictionVotingEvent (79) */
    interface PalletConvictionVotingEvent extends Enum {
        readonly isDelegated: boolean;
        readonly asDelegated: ITuple<[AccountId20, AccountId20]>;
        readonly isUndelegated: boolean;
        readonly asUndelegated: AccountId20;
        readonly type: "Delegated" | "Undelegated";
    }
    /** @name PalletReferendaEvent (80) */
    interface PalletReferendaEvent extends Enum {
        readonly isSubmitted: boolean;
        readonly asSubmitted: {
            readonly index: u32;
            readonly track: u16;
            readonly proposal: FrameSupportPreimagesBounded;
        } & Struct;
        readonly isDecisionDepositPlaced: boolean;
        readonly asDecisionDepositPlaced: {
            readonly index: u32;
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isDecisionDepositRefunded: boolean;
        readonly asDecisionDepositRefunded: {
            readonly index: u32;
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isDepositSlashed: boolean;
        readonly asDepositSlashed: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isDecisionStarted: boolean;
        readonly asDecisionStarted: {
            readonly index: u32;
            readonly track: u16;
            readonly proposal: FrameSupportPreimagesBounded;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isConfirmStarted: boolean;
        readonly asConfirmStarted: {
            readonly index: u32;
        } & Struct;
        readonly isConfirmAborted: boolean;
        readonly asConfirmAborted: {
            readonly index: u32;
        } & Struct;
        readonly isConfirmed: boolean;
        readonly asConfirmed: {
            readonly index: u32;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isApproved: boolean;
        readonly asApproved: {
            readonly index: u32;
        } & Struct;
        readonly isRejected: boolean;
        readonly asRejected: {
            readonly index: u32;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isTimedOut: boolean;
        readonly asTimedOut: {
            readonly index: u32;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isCancelled: boolean;
        readonly asCancelled: {
            readonly index: u32;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isKilled: boolean;
        readonly asKilled: {
            readonly index: u32;
            readonly tally: PalletConvictionVotingTally;
        } & Struct;
        readonly isSubmissionDepositRefunded: boolean;
        readonly asSubmissionDepositRefunded: {
            readonly index: u32;
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly type: "Submitted" | "DecisionDepositPlaced" | "DecisionDepositRefunded" | "DepositSlashed" | "DecisionStarted" | "ConfirmStarted" | "ConfirmAborted" | "Confirmed" | "Approved" | "Rejected" | "TimedOut" | "Cancelled" | "Killed" | "SubmissionDepositRefunded";
    }
    /** @name FrameSupportPreimagesBounded (81) */
    interface FrameSupportPreimagesBounded extends Enum {
        readonly isLegacy: boolean;
        readonly asLegacy: {
            readonly hash_: H256;
        } & Struct;
        readonly isInline: boolean;
        readonly asInline: Bytes;
        readonly isLookup: boolean;
        readonly asLookup: {
            readonly hash_: H256;
            readonly len: u32;
        } & Struct;
        readonly type: "Legacy" | "Inline" | "Lookup";
    }
    /** @name FrameSystemCall (83) */
    interface FrameSystemCall extends Enum {
        readonly isRemark: boolean;
        readonly asRemark: {
            readonly remark: Bytes;
        } & Struct;
        readonly isSetHeapPages: boolean;
        readonly asSetHeapPages: {
            readonly pages: u64;
        } & Struct;
        readonly isSetCode: boolean;
        readonly asSetCode: {
            readonly code: Bytes;
        } & Struct;
        readonly isSetCodeWithoutChecks: boolean;
        readonly asSetCodeWithoutChecks: {
            readonly code: Bytes;
        } & Struct;
        readonly isSetStorage: boolean;
        readonly asSetStorage: {
            readonly items: Vec<ITuple<[Bytes, Bytes]>>;
        } & Struct;
        readonly isKillStorage: boolean;
        readonly asKillStorage: {
            readonly keys_: Vec<Bytes>;
        } & Struct;
        readonly isKillPrefix: boolean;
        readonly asKillPrefix: {
            readonly prefix: Bytes;
            readonly subkeys: u32;
        } & Struct;
        readonly isRemarkWithEvent: boolean;
        readonly asRemarkWithEvent: {
            readonly remark: Bytes;
        } & Struct;
        readonly type: "Remark" | "SetHeapPages" | "SetCode" | "SetCodeWithoutChecks" | "SetStorage" | "KillStorage" | "KillPrefix" | "RemarkWithEvent";
    }
    /** @name CumulusPalletParachainSystemCall (87) */
    interface CumulusPalletParachainSystemCall extends Enum {
        readonly isSetValidationData: boolean;
        readonly asSetValidationData: {
            readonly data: CumulusPrimitivesParachainInherentParachainInherentData;
        } & Struct;
        readonly isSudoSendUpwardMessage: boolean;
        readonly asSudoSendUpwardMessage: {
            readonly message: Bytes;
        } & Struct;
        readonly isAuthorizeUpgrade: boolean;
        readonly asAuthorizeUpgrade: {
            readonly codeHash: H256;
        } & Struct;
        readonly isEnactAuthorizedUpgrade: boolean;
        readonly asEnactAuthorizedUpgrade: {
            readonly code: Bytes;
        } & Struct;
        readonly type: "SetValidationData" | "SudoSendUpwardMessage" | "AuthorizeUpgrade" | "EnactAuthorizedUpgrade";
    }
    /** @name CumulusPrimitivesParachainInherentParachainInherentData (88) */
    interface CumulusPrimitivesParachainInherentParachainInherentData extends Struct {
        readonly validationData: PolkadotPrimitivesV2PersistedValidationData;
        readonly relayChainState: SpTrieStorageProof;
        readonly downwardMessages: Vec<PolkadotCorePrimitivesInboundDownwardMessage>;
        readonly horizontalMessages: BTreeMap<u32, Vec<PolkadotCorePrimitivesInboundHrmpMessage>>;
    }
    /** @name PolkadotPrimitivesV2PersistedValidationData (89) */
    interface PolkadotPrimitivesV2PersistedValidationData extends Struct {
        readonly parentHead: Bytes;
        readonly relayParentNumber: u32;
        readonly relayParentStorageRoot: H256;
        readonly maxPovSize: u32;
    }
    /** @name SpTrieStorageProof (91) */
    interface SpTrieStorageProof extends Struct {
        readonly trieNodes: BTreeSet<Bytes>;
    }
    /** @name PolkadotCorePrimitivesInboundDownwardMessage (94) */
    interface PolkadotCorePrimitivesInboundDownwardMessage extends Struct {
        readonly sentAt: u32;
        readonly msg: Bytes;
    }
    /** @name PolkadotCorePrimitivesInboundHrmpMessage (98) */
    interface PolkadotCorePrimitivesInboundHrmpMessage extends Struct {
        readonly sentAt: u32;
        readonly data: Bytes;
    }
    /** @name PalletTimestampCall (101) */
    interface PalletTimestampCall extends Enum {
        readonly isSet: boolean;
        readonly asSet: {
            readonly now: Compact<u64>;
        } & Struct;
        readonly type: "Set";
    }
    /** @name PalletRootTestingCall (102) */
    interface PalletRootTestingCall extends Enum {
        readonly isFillBlock: boolean;
        readonly asFillBlock: {
            readonly ratio: Perbill;
        } & Struct;
        readonly type: "FillBlock";
    }
    /** @name PalletBalancesCall (103) */
    interface PalletBalancesCall extends Enum {
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly dest: AccountId20;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isSetBalance: boolean;
        readonly asSetBalance: {
            readonly who: AccountId20;
            readonly newFree: Compact<u128>;
            readonly newReserved: Compact<u128>;
        } & Struct;
        readonly isForceTransfer: boolean;
        readonly asForceTransfer: {
            readonly source: AccountId20;
            readonly dest: AccountId20;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isTransferKeepAlive: boolean;
        readonly asTransferKeepAlive: {
            readonly dest: AccountId20;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isTransferAll: boolean;
        readonly asTransferAll: {
            readonly dest: AccountId20;
            readonly keepAlive: bool;
        } & Struct;
        readonly isForceUnreserve: boolean;
        readonly asForceUnreserve: {
            readonly who: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly type: "Transfer" | "SetBalance" | "ForceTransfer" | "TransferKeepAlive" | "TransferAll" | "ForceUnreserve";
    }
    /** @name PalletParachainStakingCall (105) */
    interface PalletParachainStakingCall extends Enum {
        readonly isSetStakingExpectations: boolean;
        readonly asSetStakingExpectations: {
            readonly expectations: {
                readonly min: u128;
                readonly ideal: u128;
                readonly max: u128;
            } & Struct;
        } & Struct;
        readonly isSetInflation: boolean;
        readonly asSetInflation: {
            readonly schedule: {
                readonly min: Perbill;
                readonly ideal: Perbill;
                readonly max: Perbill;
            } & Struct;
        } & Struct;
        readonly isSetParachainBondAccount: boolean;
        readonly asSetParachainBondAccount: {
            readonly new_: AccountId20;
        } & Struct;
        readonly isSetParachainBondReservePercent: boolean;
        readonly asSetParachainBondReservePercent: {
            readonly new_: Percent;
        } & Struct;
        readonly isSetTotalSelected: boolean;
        readonly asSetTotalSelected: {
            readonly new_: u32;
        } & Struct;
        readonly isSetCollatorCommission: boolean;
        readonly asSetCollatorCommission: {
            readonly new_: Perbill;
        } & Struct;
        readonly isSetBlocksPerRound: boolean;
        readonly asSetBlocksPerRound: {
            readonly new_: u32;
        } & Struct;
        readonly isJoinCandidates: boolean;
        readonly asJoinCandidates: {
            readonly bond: u128;
            readonly candidateCount: u32;
        } & Struct;
        readonly isScheduleLeaveCandidates: boolean;
        readonly asScheduleLeaveCandidates: {
            readonly candidateCount: u32;
        } & Struct;
        readonly isExecuteLeaveCandidates: boolean;
        readonly asExecuteLeaveCandidates: {
            readonly candidate: AccountId20;
            readonly candidateDelegationCount: u32;
        } & Struct;
        readonly isCancelLeaveCandidates: boolean;
        readonly asCancelLeaveCandidates: {
            readonly candidateCount: u32;
        } & Struct;
        readonly isGoOffline: boolean;
        readonly isGoOnline: boolean;
        readonly isCandidateBondMore: boolean;
        readonly asCandidateBondMore: {
            readonly more: u128;
        } & Struct;
        readonly isScheduleCandidateBondLess: boolean;
        readonly asScheduleCandidateBondLess: {
            readonly less: u128;
        } & Struct;
        readonly isExecuteCandidateBondLess: boolean;
        readonly asExecuteCandidateBondLess: {
            readonly candidate: AccountId20;
        } & Struct;
        readonly isCancelCandidateBondLess: boolean;
        readonly isDelegate: boolean;
        readonly asDelegate: {
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly candidateDelegationCount: u32;
            readonly delegationCount: u32;
        } & Struct;
        readonly isDelegateWithAutoCompound: boolean;
        readonly asDelegateWithAutoCompound: {
            readonly candidate: AccountId20;
            readonly amount: u128;
            readonly autoCompound: Percent;
            readonly candidateDelegationCount: u32;
            readonly candidateAutoCompoundingDelegationCount: u32;
            readonly delegationCount: u32;
        } & Struct;
        readonly isScheduleLeaveDelegators: boolean;
        readonly isExecuteLeaveDelegators: boolean;
        readonly asExecuteLeaveDelegators: {
            readonly delegator: AccountId20;
            readonly delegationCount: u32;
        } & Struct;
        readonly isCancelLeaveDelegators: boolean;
        readonly isScheduleRevokeDelegation: boolean;
        readonly asScheduleRevokeDelegation: {
            readonly collator: AccountId20;
        } & Struct;
        readonly isDelegatorBondMore: boolean;
        readonly asDelegatorBondMore: {
            readonly candidate: AccountId20;
            readonly more: u128;
        } & Struct;
        readonly isScheduleDelegatorBondLess: boolean;
        readonly asScheduleDelegatorBondLess: {
            readonly candidate: AccountId20;
            readonly less: u128;
        } & Struct;
        readonly isExecuteDelegationRequest: boolean;
        readonly asExecuteDelegationRequest: {
            readonly delegator: AccountId20;
            readonly candidate: AccountId20;
        } & Struct;
        readonly isCancelDelegationRequest: boolean;
        readonly asCancelDelegationRequest: {
            readonly candidate: AccountId20;
        } & Struct;
        readonly isSetAutoCompound: boolean;
        readonly asSetAutoCompound: {
            readonly candidate: AccountId20;
            readonly value: Percent;
            readonly candidateAutoCompoundingDelegationCountHint: u32;
            readonly delegationCountHint: u32;
        } & Struct;
        readonly isHotfixRemoveDelegationRequestsExitedCandidates: boolean;
        readonly asHotfixRemoveDelegationRequestsExitedCandidates: {
            readonly candidates: Vec<AccountId20>;
        } & Struct;
        readonly type: "SetStakingExpectations" | "SetInflation" | "SetParachainBondAccount" | "SetParachainBondReservePercent" | "SetTotalSelected" | "SetCollatorCommission" | "SetBlocksPerRound" | "JoinCandidates" | "ScheduleLeaveCandidates" | "ExecuteLeaveCandidates" | "CancelLeaveCandidates" | "GoOffline" | "GoOnline" | "CandidateBondMore" | "ScheduleCandidateBondLess" | "ExecuteCandidateBondLess" | "CancelCandidateBondLess" | "Delegate" | "DelegateWithAutoCompound" | "ScheduleLeaveDelegators" | "ExecuteLeaveDelegators" | "CancelLeaveDelegators" | "ScheduleRevokeDelegation" | "DelegatorBondMore" | "ScheduleDelegatorBondLess" | "ExecuteDelegationRequest" | "CancelDelegationRequest" | "SetAutoCompound" | "HotfixRemoveDelegationRequestsExitedCandidates";
    }
    /** @name PalletAuthorInherentCall (109) */
    interface PalletAuthorInherentCall extends Enum {
        readonly isKickOffAuthorshipValidation: boolean;
        readonly type: "KickOffAuthorshipValidation";
    }
    /** @name PalletAuthorSlotFilterCall (110) */
    interface PalletAuthorSlotFilterCall extends Enum {
        readonly isSetEligible: boolean;
        readonly asSetEligible: {
            readonly new_: u32;
        } & Struct;
        readonly type: "SetEligible";
    }
    /** @name PalletAuthorMappingCall (111) */
    interface PalletAuthorMappingCall extends Enum {
        readonly isAddAssociation: boolean;
        readonly asAddAssociation: {
            readonly nimbusId: NimbusPrimitivesNimbusCryptoPublic;
        } & Struct;
        readonly isUpdateAssociation: boolean;
        readonly asUpdateAssociation: {
            readonly oldNimbusId: NimbusPrimitivesNimbusCryptoPublic;
            readonly newNimbusId: NimbusPrimitivesNimbusCryptoPublic;
        } & Struct;
        readonly isClearAssociation: boolean;
        readonly asClearAssociation: {
            readonly nimbusId: NimbusPrimitivesNimbusCryptoPublic;
        } & Struct;
        readonly isRemoveKeys: boolean;
        readonly isSetKeys: boolean;
        readonly asSetKeys: {
            readonly keys_: Bytes;
        } & Struct;
        readonly type: "AddAssociation" | "UpdateAssociation" | "ClearAssociation" | "RemoveKeys" | "SetKeys";
    }
    /** @name PalletMoonbeamOrbitersCall (112) */
    interface PalletMoonbeamOrbitersCall extends Enum {
        readonly isCollatorAddOrbiter: boolean;
        readonly asCollatorAddOrbiter: {
            readonly orbiter: AccountId20;
        } & Struct;
        readonly isCollatorRemoveOrbiter: boolean;
        readonly asCollatorRemoveOrbiter: {
            readonly orbiter: AccountId20;
        } & Struct;
        readonly isOrbiterLeaveCollatorPool: boolean;
        readonly asOrbiterLeaveCollatorPool: {
            readonly collator: AccountId20;
        } & Struct;
        readonly isOrbiterRegister: boolean;
        readonly isOrbiterUnregister: boolean;
        readonly asOrbiterUnregister: {
            readonly collatorsPoolCount: u32;
        } & Struct;
        readonly isAddCollator: boolean;
        readonly asAddCollator: {
            readonly collator: AccountId20;
        } & Struct;
        readonly isRemoveCollator: boolean;
        readonly asRemoveCollator: {
            readonly collator: AccountId20;
        } & Struct;
        readonly type: "CollatorAddOrbiter" | "CollatorRemoveOrbiter" | "OrbiterLeaveCollatorPool" | "OrbiterRegister" | "OrbiterUnregister" | "AddCollator" | "RemoveCollator";
    }
    /** @name PalletUtilityCall (113) */
    interface PalletUtilityCall extends Enum {
        readonly isBatch: boolean;
        readonly asBatch: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isAsDerivative: boolean;
        readonly asAsDerivative: {
            readonly index: u16;
            readonly call: Call;
        } & Struct;
        readonly isBatchAll: boolean;
        readonly asBatchAll: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isDispatchAs: boolean;
        readonly asDispatchAs: {
            readonly asOrigin: MoonriverRuntimeOriginCaller;
            readonly call: Call;
        } & Struct;
        readonly isForceBatch: boolean;
        readonly asForceBatch: {
            readonly calls: Vec<Call>;
        } & Struct;
        readonly isWithWeight: boolean;
        readonly asWithWeight: {
            readonly call: Call;
            readonly weight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly type: "Batch" | "AsDerivative" | "BatchAll" | "DispatchAs" | "ForceBatch" | "WithWeight";
    }
    /** @name MoonriverRuntimeOriginCaller (115) */
    interface MoonriverRuntimeOriginCaller extends Enum {
        readonly isSystem: boolean;
        readonly asSystem: FrameSupportDispatchRawOrigin;
        readonly isVoid: boolean;
        readonly isEthereum: boolean;
        readonly asEthereum: PalletEthereumRawOrigin;
        readonly isOrigins: boolean;
        readonly asOrigins: MoonriverRuntimeGovernanceOriginsCustomOriginsOrigin;
        readonly isCouncilCollective: boolean;
        readonly asCouncilCollective: PalletCollectiveRawOrigin;
        readonly isTechCommitteeCollective: boolean;
        readonly asTechCommitteeCollective: PalletCollectiveRawOrigin;
        readonly isTreasuryCouncilCollective: boolean;
        readonly asTreasuryCouncilCollective: PalletCollectiveRawOrigin;
        readonly isOpenTechCommitteeCollective: boolean;
        readonly asOpenTechCommitteeCollective: PalletCollectiveRawOrigin;
        readonly isCumulusXcm: boolean;
        readonly asCumulusXcm: CumulusPalletXcmOrigin;
        readonly isPolkadotXcm: boolean;
        readonly asPolkadotXcm: PalletXcmOrigin;
        readonly type: "System" | "Void" | "Ethereum" | "Origins" | "CouncilCollective" | "TechCommitteeCollective" | "TreasuryCouncilCollective" | "OpenTechCommitteeCollective" | "CumulusXcm" | "PolkadotXcm";
    }
    /** @name FrameSupportDispatchRawOrigin (116) */
    interface FrameSupportDispatchRawOrigin extends Enum {
        readonly isRoot: boolean;
        readonly isSigned: boolean;
        readonly asSigned: AccountId20;
        readonly isNone: boolean;
        readonly type: "Root" | "Signed" | "None";
    }
    /** @name PalletEthereumRawOrigin (117) */
    interface PalletEthereumRawOrigin extends Enum {
        readonly isEthereumTransaction: boolean;
        readonly asEthereumTransaction: H160;
        readonly type: "EthereumTransaction";
    }
    /** @name MoonriverRuntimeGovernanceOriginsCustomOriginsOrigin (118) */
    interface MoonriverRuntimeGovernanceOriginsCustomOriginsOrigin extends Enum {
        readonly isWhitelistedCaller: boolean;
        readonly isGeneralAdmin: boolean;
        readonly isReferendumCanceller: boolean;
        readonly isReferendumKiller: boolean;
        readonly type: "WhitelistedCaller" | "GeneralAdmin" | "ReferendumCanceller" | "ReferendumKiller";
    }
    /** @name PalletCollectiveRawOrigin (119) */
    interface PalletCollectiveRawOrigin extends Enum {
        readonly isMembers: boolean;
        readonly asMembers: ITuple<[u32, u32]>;
        readonly isMember: boolean;
        readonly asMember: AccountId20;
        readonly isPhantom: boolean;
        readonly type: "Members" | "Member" | "Phantom";
    }
    /** @name CumulusPalletXcmOrigin (123) */
    interface CumulusPalletXcmOrigin extends Enum {
        readonly isRelay: boolean;
        readonly isSiblingParachain: boolean;
        readonly asSiblingParachain: u32;
        readonly type: "Relay" | "SiblingParachain";
    }
    /** @name PalletXcmOrigin (124) */
    interface PalletXcmOrigin extends Enum {
        readonly isXcm: boolean;
        readonly asXcm: XcmV3MultiLocation;
        readonly isResponse: boolean;
        readonly asResponse: XcmV3MultiLocation;
        readonly type: "Xcm" | "Response";
    }
    /** @name XcmV3MultiLocation (125) */
    interface XcmV3MultiLocation extends Struct {
        readonly parents: u8;
        readonly interior: XcmV3Junctions;
    }
    /** @name XcmV3Junctions (126) */
    interface XcmV3Junctions extends Enum {
        readonly isHere: boolean;
        readonly isX1: boolean;
        readonly asX1: XcmV3Junction;
        readonly isX2: boolean;
        readonly asX2: ITuple<[XcmV3Junction, XcmV3Junction]>;
        readonly isX3: boolean;
        readonly asX3: ITuple<[XcmV3Junction, XcmV3Junction, XcmV3Junction]>;
        readonly isX4: boolean;
        readonly asX4: ITuple<[XcmV3Junction, XcmV3Junction, XcmV3Junction, XcmV3Junction]>;
        readonly isX5: boolean;
        readonly asX5: ITuple<[
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction
        ]>;
        readonly isX6: boolean;
        readonly asX6: ITuple<[
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction
        ]>;
        readonly isX7: boolean;
        readonly asX7: ITuple<[
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction
        ]>;
        readonly isX8: boolean;
        readonly asX8: ITuple<[
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction,
            XcmV3Junction
        ]>;
        readonly type: "Here" | "X1" | "X2" | "X3" | "X4" | "X5" | "X6" | "X7" | "X8";
    }
    /** @name XcmV3Junction (127) */
    interface XcmV3Junction extends Enum {
        readonly isParachain: boolean;
        readonly asParachain: Compact<u32>;
        readonly isAccountId32: boolean;
        readonly asAccountId32: {
            readonly network: Option<XcmV3JunctionNetworkId>;
            readonly id: U8aFixed;
        } & Struct;
        readonly isAccountIndex64: boolean;
        readonly asAccountIndex64: {
            readonly network: Option<XcmV3JunctionNetworkId>;
            readonly index: Compact<u64>;
        } & Struct;
        readonly isAccountKey20: boolean;
        readonly asAccountKey20: {
            readonly network: Option<XcmV3JunctionNetworkId>;
            readonly key: U8aFixed;
        } & Struct;
        readonly isPalletInstance: boolean;
        readonly asPalletInstance: u8;
        readonly isGeneralIndex: boolean;
        readonly asGeneralIndex: Compact<u128>;
        readonly isGeneralKey: boolean;
        readonly asGeneralKey: {
            readonly length: u8;
            readonly data: U8aFixed;
        } & Struct;
        readonly isOnlyChild: boolean;
        readonly isPlurality: boolean;
        readonly asPlurality: {
            readonly id: XcmV3JunctionBodyId;
            readonly part: XcmV3JunctionBodyPart;
        } & Struct;
        readonly isGlobalConsensus: boolean;
        readonly asGlobalConsensus: XcmV3JunctionNetworkId;
        readonly type: "Parachain" | "AccountId32" | "AccountIndex64" | "AccountKey20" | "PalletInstance" | "GeneralIndex" | "GeneralKey" | "OnlyChild" | "Plurality" | "GlobalConsensus";
    }
    /** @name XcmV3JunctionNetworkId (130) */
    interface XcmV3JunctionNetworkId extends Enum {
        readonly isByGenesis: boolean;
        readonly asByGenesis: U8aFixed;
        readonly isByFork: boolean;
        readonly asByFork: {
            readonly blockNumber: u64;
            readonly blockHash: U8aFixed;
        } & Struct;
        readonly isPolkadot: boolean;
        readonly isKusama: boolean;
        readonly isWestend: boolean;
        readonly isRococo: boolean;
        readonly isWococo: boolean;
        readonly isEthereum: boolean;
        readonly asEthereum: {
            readonly chainId: Compact<u64>;
        } & Struct;
        readonly isBitcoinCore: boolean;
        readonly isBitcoinCash: boolean;
        readonly type: "ByGenesis" | "ByFork" | "Polkadot" | "Kusama" | "Westend" | "Rococo" | "Wococo" | "Ethereum" | "BitcoinCore" | "BitcoinCash";
    }
    /** @name XcmV3JunctionBodyId (131) */
    interface XcmV3JunctionBodyId extends Enum {
        readonly isUnit: boolean;
        readonly isMoniker: boolean;
        readonly asMoniker: U8aFixed;
        readonly isIndex: boolean;
        readonly asIndex: Compact<u32>;
        readonly isExecutive: boolean;
        readonly isTechnical: boolean;
        readonly isLegislative: boolean;
        readonly isJudicial: boolean;
        readonly isDefense: boolean;
        readonly isAdministration: boolean;
        readonly isTreasury: boolean;
        readonly type: "Unit" | "Moniker" | "Index" | "Executive" | "Technical" | "Legislative" | "Judicial" | "Defense" | "Administration" | "Treasury";
    }
    /** @name XcmV3JunctionBodyPart (132) */
    interface XcmV3JunctionBodyPart extends Enum {
        readonly isVoice: boolean;
        readonly isMembers: boolean;
        readonly asMembers: {
            readonly count: Compact<u32>;
        } & Struct;
        readonly isFraction: boolean;
        readonly asFraction: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly isAtLeastProportion: boolean;
        readonly asAtLeastProportion: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly isMoreThanProportion: boolean;
        readonly asMoreThanProportion: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly type: "Voice" | "Members" | "Fraction" | "AtLeastProportion" | "MoreThanProportion";
    }
    /** @name SpCoreVoid (133) */
    type SpCoreVoid = Null;
    /** @name PalletProxyCall (134) */
    interface PalletProxyCall extends Enum {
        readonly isProxy: boolean;
        readonly asProxy: {
            readonly real: AccountId20;
            readonly forceProxyType: Option<MoonriverRuntimeProxyType>;
            readonly call: Call;
        } & Struct;
        readonly isAddProxy: boolean;
        readonly asAddProxy: {
            readonly delegate: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly isRemoveProxy: boolean;
        readonly asRemoveProxy: {
            readonly delegate: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly delay: u32;
        } & Struct;
        readonly isRemoveProxies: boolean;
        readonly isCreatePure: boolean;
        readonly asCreatePure: {
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly delay: u32;
            readonly index: u16;
        } & Struct;
        readonly isKillPure: boolean;
        readonly asKillPure: {
            readonly spawner: AccountId20;
            readonly proxyType: MoonriverRuntimeProxyType;
            readonly index: u16;
            readonly height: Compact<u32>;
            readonly extIndex: Compact<u32>;
        } & Struct;
        readonly isAnnounce: boolean;
        readonly asAnnounce: {
            readonly real: AccountId20;
            readonly callHash: H256;
        } & Struct;
        readonly isRemoveAnnouncement: boolean;
        readonly asRemoveAnnouncement: {
            readonly real: AccountId20;
            readonly callHash: H256;
        } & Struct;
        readonly isRejectAnnouncement: boolean;
        readonly asRejectAnnouncement: {
            readonly delegate: AccountId20;
            readonly callHash: H256;
        } & Struct;
        readonly isProxyAnnounced: boolean;
        readonly asProxyAnnounced: {
            readonly delegate: AccountId20;
            readonly real: AccountId20;
            readonly forceProxyType: Option<MoonriverRuntimeProxyType>;
            readonly call: Call;
        } & Struct;
        readonly type: "Proxy" | "AddProxy" | "RemoveProxy" | "RemoveProxies" | "CreatePure" | "KillPure" | "Announce" | "RemoveAnnouncement" | "RejectAnnouncement" | "ProxyAnnounced";
    }
    /** @name PalletMaintenanceModeCall (136) */
    interface PalletMaintenanceModeCall extends Enum {
        readonly isEnterMaintenanceMode: boolean;
        readonly isResumeNormalOperation: boolean;
        readonly type: "EnterMaintenanceMode" | "ResumeNormalOperation";
    }
    /** @name PalletIdentityCall (137) */
    interface PalletIdentityCall extends Enum {
        readonly isAddRegistrar: boolean;
        readonly asAddRegistrar: {
            readonly account: AccountId20;
        } & Struct;
        readonly isSetIdentity: boolean;
        readonly asSetIdentity: {
            readonly info: PalletIdentityIdentityInfo;
        } & Struct;
        readonly isSetSubs: boolean;
        readonly asSetSubs: {
            readonly subs: Vec<ITuple<[AccountId20, Data]>>;
        } & Struct;
        readonly isClearIdentity: boolean;
        readonly isRequestJudgement: boolean;
        readonly asRequestJudgement: {
            readonly regIndex: Compact<u32>;
            readonly maxFee: Compact<u128>;
        } & Struct;
        readonly isCancelRequest: boolean;
        readonly asCancelRequest: {
            readonly regIndex: u32;
        } & Struct;
        readonly isSetFee: boolean;
        readonly asSetFee: {
            readonly index: Compact<u32>;
            readonly fee: Compact<u128>;
        } & Struct;
        readonly isSetAccountId: boolean;
        readonly asSetAccountId: {
            readonly index: Compact<u32>;
            readonly new_: AccountId20;
        } & Struct;
        readonly isSetFields: boolean;
        readonly asSetFields: {
            readonly index: Compact<u32>;
            readonly fields: PalletIdentityBitFlags;
        } & Struct;
        readonly isProvideJudgement: boolean;
        readonly asProvideJudgement: {
            readonly regIndex: Compact<u32>;
            readonly target: AccountId20;
            readonly judgement: PalletIdentityJudgement;
            readonly identity: H256;
        } & Struct;
        readonly isKillIdentity: boolean;
        readonly asKillIdentity: {
            readonly target: AccountId20;
        } & Struct;
        readonly isAddSub: boolean;
        readonly asAddSub: {
            readonly sub: AccountId20;
            readonly data: Data;
        } & Struct;
        readonly isRenameSub: boolean;
        readonly asRenameSub: {
            readonly sub: AccountId20;
            readonly data: Data;
        } & Struct;
        readonly isRemoveSub: boolean;
        readonly asRemoveSub: {
            readonly sub: AccountId20;
        } & Struct;
        readonly isQuitSub: boolean;
        readonly type: "AddRegistrar" | "SetIdentity" | "SetSubs" | "ClearIdentity" | "RequestJudgement" | "CancelRequest" | "SetFee" | "SetAccountId" | "SetFields" | "ProvideJudgement" | "KillIdentity" | "AddSub" | "RenameSub" | "RemoveSub" | "QuitSub";
    }
    /** @name PalletIdentityIdentityInfo (138) */
    interface PalletIdentityIdentityInfo extends Struct {
        readonly additional: Vec<ITuple<[Data, Data]>>;
        readonly display: Data;
        readonly legal: Data;
        readonly web: Data;
        readonly riot: Data;
        readonly email: Data;
        readonly pgpFingerprint: Option<U8aFixed>;
        readonly image: Data;
        readonly twitter: Data;
    }
    /** @name PalletIdentityBitFlags (176) */
    interface PalletIdentityBitFlags extends Set {
        readonly isDisplay: boolean;
        readonly isLegal: boolean;
        readonly isWeb: boolean;
        readonly isRiot: boolean;
        readonly isEmail: boolean;
        readonly isPgpFingerprint: boolean;
        readonly isImage: boolean;
        readonly isTwitter: boolean;
    }
    /** @name PalletIdentityIdentityField (177) */
    interface PalletIdentityIdentityField extends Enum {
        readonly isDisplay: boolean;
        readonly isLegal: boolean;
        readonly isWeb: boolean;
        readonly isRiot: boolean;
        readonly isEmail: boolean;
        readonly isPgpFingerprint: boolean;
        readonly isImage: boolean;
        readonly isTwitter: boolean;
        readonly type: "Display" | "Legal" | "Web" | "Riot" | "Email" | "PgpFingerprint" | "Image" | "Twitter";
    }
    /** @name PalletIdentityJudgement (178) */
    interface PalletIdentityJudgement extends Enum {
        readonly isUnknown: boolean;
        readonly isFeePaid: boolean;
        readonly asFeePaid: u128;
        readonly isReasonable: boolean;
        readonly isKnownGood: boolean;
        readonly isOutOfDate: boolean;
        readonly isLowQuality: boolean;
        readonly isErroneous: boolean;
        readonly type: "Unknown" | "FeePaid" | "Reasonable" | "KnownGood" | "OutOfDate" | "LowQuality" | "Erroneous";
    }
    /** @name PalletMigrationsCall (179) */
    interface PalletMigrationsCall extends Enum {
        readonly isMigrateDemocracyPreimage: boolean;
        readonly asMigrateDemocracyPreimage: {
            readonly proposalHash: H256;
            readonly proposalLenUpperBound: Compact<u32>;
        } & Struct;
        readonly type: "MigrateDemocracyPreimage";
    }
    /** @name PalletEvmCall (180) */
    interface PalletEvmCall extends Enum {
        readonly isWithdraw: boolean;
        readonly asWithdraw: {
            readonly address: H160;
            readonly value: u128;
        } & Struct;
        readonly isCall: boolean;
        readonly asCall: {
            readonly source: H160;
            readonly target: H160;
            readonly input: Bytes;
            readonly value: U256;
            readonly gasLimit: u64;
            readonly maxFeePerGas: U256;
            readonly maxPriorityFeePerGas: Option<U256>;
            readonly nonce: Option<U256>;
            readonly accessList: Vec<ITuple<[H160, Vec<H256>]>>;
        } & Struct;
        readonly isCreate: boolean;
        readonly asCreate: {
            readonly source: H160;
            readonly init: Bytes;
            readonly value: U256;
            readonly gasLimit: u64;
            readonly maxFeePerGas: U256;
            readonly maxPriorityFeePerGas: Option<U256>;
            readonly nonce: Option<U256>;
            readonly accessList: Vec<ITuple<[H160, Vec<H256>]>>;
        } & Struct;
        readonly isCreate2: boolean;
        readonly asCreate2: {
            readonly source: H160;
            readonly init: Bytes;
            readonly salt: H256;
            readonly value: U256;
            readonly gasLimit: u64;
            readonly maxFeePerGas: U256;
            readonly maxPriorityFeePerGas: Option<U256>;
            readonly nonce: Option<U256>;
            readonly accessList: Vec<ITuple<[H160, Vec<H256>]>>;
        } & Struct;
        readonly type: "Withdraw" | "Call" | "Create" | "Create2";
    }
    /** @name PalletEthereumCall (186) */
    interface PalletEthereumCall extends Enum {
        readonly isTransact: boolean;
        readonly asTransact: {
            readonly transaction: EthereumTransactionTransactionV2;
        } & Struct;
        readonly type: "Transact";
    }
    /** @name EthereumTransactionTransactionV2 (187) */
    interface EthereumTransactionTransactionV2 extends Enum {
        readonly isLegacy: boolean;
        readonly asLegacy: EthereumTransactionLegacyTransaction;
        readonly isEip2930: boolean;
        readonly asEip2930: EthereumTransactionEip2930Transaction;
        readonly isEip1559: boolean;
        readonly asEip1559: EthereumTransactionEip1559Transaction;
        readonly type: "Legacy" | "Eip2930" | "Eip1559";
    }
    /** @name EthereumTransactionLegacyTransaction (188) */
    interface EthereumTransactionLegacyTransaction extends Struct {
        readonly nonce: U256;
        readonly gasPrice: U256;
        readonly gasLimit: U256;
        readonly action: EthereumTransactionTransactionAction;
        readonly value: U256;
        readonly input: Bytes;
        readonly signature: EthereumTransactionTransactionSignature;
    }
    /** @name EthereumTransactionTransactionAction (189) */
    interface EthereumTransactionTransactionAction extends Enum {
        readonly isCall: boolean;
        readonly asCall: H160;
        readonly isCreate: boolean;
        readonly type: "Call" | "Create";
    }
    /** @name EthereumTransactionTransactionSignature (190) */
    interface EthereumTransactionTransactionSignature extends Struct {
        readonly v: u64;
        readonly r: H256;
        readonly s: H256;
    }
    /** @name EthereumTransactionEip2930Transaction (192) */
    interface EthereumTransactionEip2930Transaction extends Struct {
        readonly chainId: u64;
        readonly nonce: U256;
        readonly gasPrice: U256;
        readonly gasLimit: U256;
        readonly action: EthereumTransactionTransactionAction;
        readonly value: U256;
        readonly input: Bytes;
        readonly accessList: Vec<EthereumTransactionAccessListItem>;
        readonly oddYParity: bool;
        readonly r: H256;
        readonly s: H256;
    }
    /** @name EthereumTransactionAccessListItem (194) */
    interface EthereumTransactionAccessListItem extends Struct {
        readonly address: H160;
        readonly storageKeys: Vec<H256>;
    }
    /** @name EthereumTransactionEip1559Transaction (195) */
    interface EthereumTransactionEip1559Transaction extends Struct {
        readonly chainId: u64;
        readonly nonce: U256;
        readonly maxPriorityFeePerGas: U256;
        readonly maxFeePerGas: U256;
        readonly gasLimit: U256;
        readonly action: EthereumTransactionTransactionAction;
        readonly value: U256;
        readonly input: Bytes;
        readonly accessList: Vec<EthereumTransactionAccessListItem>;
        readonly oddYParity: bool;
        readonly r: H256;
        readonly s: H256;
    }
    /** @name PalletSchedulerCall (196) */
    interface PalletSchedulerCall extends Enum {
        readonly isSchedule: boolean;
        readonly asSchedule: {
            readonly when: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: Call;
        } & Struct;
        readonly isCancel: boolean;
        readonly asCancel: {
            readonly when: u32;
            readonly index: u32;
        } & Struct;
        readonly isScheduleNamed: boolean;
        readonly asScheduleNamed: {
            readonly id: U8aFixed;
            readonly when: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: Call;
        } & Struct;
        readonly isCancelNamed: boolean;
        readonly asCancelNamed: {
            readonly id: U8aFixed;
        } & Struct;
        readonly isScheduleAfter: boolean;
        readonly asScheduleAfter: {
            readonly after: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: Call;
        } & Struct;
        readonly isScheduleNamedAfter: boolean;
        readonly asScheduleNamedAfter: {
            readonly id: U8aFixed;
            readonly after: u32;
            readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
            readonly priority: u8;
            readonly call: Call;
        } & Struct;
        readonly type: "Schedule" | "Cancel" | "ScheduleNamed" | "CancelNamed" | "ScheduleAfter" | "ScheduleNamedAfter";
    }
    /** @name PalletDemocracyCall (198) */
    interface PalletDemocracyCall extends Enum {
        readonly isPropose: boolean;
        readonly asPropose: {
            readonly proposal: FrameSupportPreimagesBounded;
            readonly value: Compact<u128>;
        } & Struct;
        readonly isSecond: boolean;
        readonly asSecond: {
            readonly proposal: Compact<u32>;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly refIndex: Compact<u32>;
            readonly vote: PalletDemocracyVoteAccountVote;
        } & Struct;
        readonly isEmergencyCancel: boolean;
        readonly asEmergencyCancel: {
            readonly refIndex: u32;
        } & Struct;
        readonly isExternalPropose: boolean;
        readonly asExternalPropose: {
            readonly proposal: FrameSupportPreimagesBounded;
        } & Struct;
        readonly isExternalProposeMajority: boolean;
        readonly asExternalProposeMajority: {
            readonly proposal: FrameSupportPreimagesBounded;
        } & Struct;
        readonly isExternalProposeDefault: boolean;
        readonly asExternalProposeDefault: {
            readonly proposal: FrameSupportPreimagesBounded;
        } & Struct;
        readonly isFastTrack: boolean;
        readonly asFastTrack: {
            readonly proposalHash: H256;
            readonly votingPeriod: u32;
            readonly delay: u32;
        } & Struct;
        readonly isVetoExternal: boolean;
        readonly asVetoExternal: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isCancelReferendum: boolean;
        readonly asCancelReferendum: {
            readonly refIndex: Compact<u32>;
        } & Struct;
        readonly isDelegate: boolean;
        readonly asDelegate: {
            readonly to: AccountId20;
            readonly conviction: PalletDemocracyConviction;
            readonly balance: u128;
        } & Struct;
        readonly isUndelegate: boolean;
        readonly isClearPublicProposals: boolean;
        readonly isUnlock: boolean;
        readonly asUnlock: {
            readonly target: AccountId20;
        } & Struct;
        readonly isRemoveVote: boolean;
        readonly asRemoveVote: {
            readonly index: u32;
        } & Struct;
        readonly isRemoveOtherVote: boolean;
        readonly asRemoveOtherVote: {
            readonly target: AccountId20;
            readonly index: u32;
        } & Struct;
        readonly isBlacklist: boolean;
        readonly asBlacklist: {
            readonly proposalHash: H256;
            readonly maybeRefIndex: Option<u32>;
        } & Struct;
        readonly isCancelProposal: boolean;
        readonly asCancelProposal: {
            readonly propIndex: Compact<u32>;
        } & Struct;
        readonly type: "Propose" | "Second" | "Vote" | "EmergencyCancel" | "ExternalPropose" | "ExternalProposeMajority" | "ExternalProposeDefault" | "FastTrack" | "VetoExternal" | "CancelReferendum" | "Delegate" | "Undelegate" | "ClearPublicProposals" | "Unlock" | "RemoveVote" | "RemoveOtherVote" | "Blacklist" | "CancelProposal";
    }
    /** @name PalletDemocracyConviction (199) */
    interface PalletDemocracyConviction extends Enum {
        readonly isNone: boolean;
        readonly isLocked1x: boolean;
        readonly isLocked2x: boolean;
        readonly isLocked3x: boolean;
        readonly isLocked4x: boolean;
        readonly isLocked5x: boolean;
        readonly isLocked6x: boolean;
        readonly type: "None" | "Locked1x" | "Locked2x" | "Locked3x" | "Locked4x" | "Locked5x" | "Locked6x";
    }
    /** @name PalletPreimageCall (201) */
    interface PalletPreimageCall extends Enum {
        readonly isNotePreimage: boolean;
        readonly asNotePreimage: {
            readonly bytes: Bytes;
        } & Struct;
        readonly isUnnotePreimage: boolean;
        readonly asUnnotePreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly isRequestPreimage: boolean;
        readonly asRequestPreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly isUnrequestPreimage: boolean;
        readonly asUnrequestPreimage: {
            readonly hash_: H256;
        } & Struct;
        readonly type: "NotePreimage" | "UnnotePreimage" | "RequestPreimage" | "UnrequestPreimage";
    }
    /** @name PalletConvictionVotingCall (202) */
    interface PalletConvictionVotingCall extends Enum {
        readonly isVote: boolean;
        readonly asVote: {
            readonly pollIndex: Compact<u32>;
            readonly vote: PalletConvictionVotingVoteAccountVote;
        } & Struct;
        readonly isDelegate: boolean;
        readonly asDelegate: {
            readonly class: u16;
            readonly to: AccountId20;
            readonly conviction: PalletConvictionVotingConviction;
            readonly balance: u128;
        } & Struct;
        readonly isUndelegate: boolean;
        readonly asUndelegate: {
            readonly class: u16;
        } & Struct;
        readonly isUnlock: boolean;
        readonly asUnlock: {
            readonly class: u16;
            readonly target: AccountId20;
        } & Struct;
        readonly isRemoveVote: boolean;
        readonly asRemoveVote: {
            readonly class: Option<u16>;
            readonly index: u32;
        } & Struct;
        readonly isRemoveOtherVote: boolean;
        readonly asRemoveOtherVote: {
            readonly target: AccountId20;
            readonly class: u16;
            readonly index: u32;
        } & Struct;
        readonly type: "Vote" | "Delegate" | "Undelegate" | "Unlock" | "RemoveVote" | "RemoveOtherVote";
    }
    /** @name PalletConvictionVotingVoteAccountVote (203) */
    interface PalletConvictionVotingVoteAccountVote extends Enum {
        readonly isStandard: boolean;
        readonly asStandard: {
            readonly vote: Vote;
            readonly balance: u128;
        } & Struct;
        readonly isSplit: boolean;
        readonly asSplit: {
            readonly aye: u128;
            readonly nay: u128;
        } & Struct;
        readonly isSplitAbstain: boolean;
        readonly asSplitAbstain: {
            readonly aye: u128;
            readonly nay: u128;
            readonly abstain: u128;
        } & Struct;
        readonly type: "Standard" | "Split" | "SplitAbstain";
    }
    /** @name PalletConvictionVotingConviction (205) */
    interface PalletConvictionVotingConviction extends Enum {
        readonly isNone: boolean;
        readonly isLocked1x: boolean;
        readonly isLocked2x: boolean;
        readonly isLocked3x: boolean;
        readonly isLocked4x: boolean;
        readonly isLocked5x: boolean;
        readonly isLocked6x: boolean;
        readonly type: "None" | "Locked1x" | "Locked2x" | "Locked3x" | "Locked4x" | "Locked5x" | "Locked6x";
    }
    /** @name PalletReferendaCall (207) */
    interface PalletReferendaCall extends Enum {
        readonly isSubmit: boolean;
        readonly asSubmit: {
            readonly proposalOrigin: MoonriverRuntimeOriginCaller;
            readonly proposal: FrameSupportPreimagesBounded;
            readonly enactmentMoment: FrameSupportScheduleDispatchTime;
        } & Struct;
        readonly isPlaceDecisionDeposit: boolean;
        readonly asPlaceDecisionDeposit: {
            readonly index: u32;
        } & Struct;
        readonly isRefundDecisionDeposit: boolean;
        readonly asRefundDecisionDeposit: {
            readonly index: u32;
        } & Struct;
        readonly isCancel: boolean;
        readonly asCancel: {
            readonly index: u32;
        } & Struct;
        readonly isKill: boolean;
        readonly asKill: {
            readonly index: u32;
        } & Struct;
        readonly isNudgeReferendum: boolean;
        readonly asNudgeReferendum: {
            readonly index: u32;
        } & Struct;
        readonly isOneFewerDeciding: boolean;
        readonly asOneFewerDeciding: {
            readonly track: u16;
        } & Struct;
        readonly isRefundSubmissionDeposit: boolean;
        readonly asRefundSubmissionDeposit: {
            readonly index: u32;
        } & Struct;
        readonly type: "Submit" | "PlaceDecisionDeposit" | "RefundDecisionDeposit" | "Cancel" | "Kill" | "NudgeReferendum" | "OneFewerDeciding" | "RefundSubmissionDeposit";
    }
    /** @name FrameSupportScheduleDispatchTime (208) */
    interface FrameSupportScheduleDispatchTime extends Enum {
        readonly isAt: boolean;
        readonly asAt: u32;
        readonly isAfter: boolean;
        readonly asAfter: u32;
        readonly type: "At" | "After";
    }
    /** @name PalletWhitelistCall (209) */
    interface PalletWhitelistCall extends Enum {
        readonly isWhitelistCall: boolean;
        readonly asWhitelistCall: {
            readonly callHash: H256;
        } & Struct;
        readonly isRemoveWhitelistedCall: boolean;
        readonly asRemoveWhitelistedCall: {
            readonly callHash: H256;
        } & Struct;
        readonly isDispatchWhitelistedCall: boolean;
        readonly asDispatchWhitelistedCall: {
            readonly callHash: H256;
            readonly callEncodedLen: u32;
            readonly callWeightWitness: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isDispatchWhitelistedCallWithPreimage: boolean;
        readonly asDispatchWhitelistedCallWithPreimage: {
            readonly call: Call;
        } & Struct;
        readonly type: "WhitelistCall" | "RemoveWhitelistedCall" | "DispatchWhitelistedCall" | "DispatchWhitelistedCallWithPreimage";
    }
    /** @name PalletCollectiveCall (210) */
    interface PalletCollectiveCall extends Enum {
        readonly isSetMembers: boolean;
        readonly asSetMembers: {
            readonly newMembers: Vec<AccountId20>;
            readonly prime: Option<AccountId20>;
            readonly oldCount: u32;
        } & Struct;
        readonly isExecute: boolean;
        readonly asExecute: {
            readonly proposal: Call;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isPropose: boolean;
        readonly asPropose: {
            readonly threshold: Compact<u32>;
            readonly proposal: Call;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isVote: boolean;
        readonly asVote: {
            readonly proposal: H256;
            readonly index: Compact<u32>;
            readonly approve: bool;
        } & Struct;
        readonly isCloseOldWeight: boolean;
        readonly asCloseOldWeight: {
            readonly proposalHash: H256;
            readonly index: Compact<u32>;
            readonly proposalWeightBound: Compact<u64>;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly isDisapproveProposal: boolean;
        readonly asDisapproveProposal: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isClose: boolean;
        readonly asClose: {
            readonly proposalHash: H256;
            readonly index: Compact<u32>;
            readonly proposalWeightBound: SpWeightsWeightV2Weight;
            readonly lengthBound: Compact<u32>;
        } & Struct;
        readonly type: "SetMembers" | "Execute" | "Propose" | "Vote" | "CloseOldWeight" | "DisapproveProposal" | "Close";
    }
    /** @name PalletTreasuryCall (216) */
    interface PalletTreasuryCall extends Enum {
        readonly isProposeSpend: boolean;
        readonly asProposeSpend: {
            readonly value: Compact<u128>;
            readonly beneficiary: AccountId20;
        } & Struct;
        readonly isRejectProposal: boolean;
        readonly asRejectProposal: {
            readonly proposalId: Compact<u32>;
        } & Struct;
        readonly isApproveProposal: boolean;
        readonly asApproveProposal: {
            readonly proposalId: Compact<u32>;
        } & Struct;
        readonly isSpend: boolean;
        readonly asSpend: {
            readonly amount: Compact<u128>;
            readonly beneficiary: AccountId20;
        } & Struct;
        readonly isRemoveApproval: boolean;
        readonly asRemoveApproval: {
            readonly proposalId: Compact<u32>;
        } & Struct;
        readonly type: "ProposeSpend" | "RejectProposal" | "ApproveProposal" | "Spend" | "RemoveApproval";
    }
    /** @name PalletCrowdloanRewardsCall (217) */
    interface PalletCrowdloanRewardsCall extends Enum {
        readonly isAssociateNativeIdentity: boolean;
        readonly asAssociateNativeIdentity: {
            readonly rewardAccount: AccountId20;
            readonly relayAccount: U8aFixed;
            readonly proof: SpRuntimeMultiSignature;
        } & Struct;
        readonly isChangeAssociationWithRelayKeys: boolean;
        readonly asChangeAssociationWithRelayKeys: {
            readonly rewardAccount: AccountId20;
            readonly previousAccount: AccountId20;
            readonly proofs: Vec<ITuple<[U8aFixed, SpRuntimeMultiSignature]>>;
        } & Struct;
        readonly isClaim: boolean;
        readonly isUpdateRewardAddress: boolean;
        readonly asUpdateRewardAddress: {
            readonly newRewardAccount: AccountId20;
        } & Struct;
        readonly isCompleteInitialization: boolean;
        readonly asCompleteInitialization: {
            readonly leaseEndingBlock: u32;
        } & Struct;
        readonly isInitializeRewardVec: boolean;
        readonly asInitializeRewardVec: {
            readonly rewards: Vec<ITuple<[U8aFixed, Option<AccountId20>, u128]>>;
        } & Struct;
        readonly type: "AssociateNativeIdentity" | "ChangeAssociationWithRelayKeys" | "Claim" | "UpdateRewardAddress" | "CompleteInitialization" | "InitializeRewardVec";
    }
    /** @name SpRuntimeMultiSignature (218) */
    interface SpRuntimeMultiSignature extends Enum {
        readonly isEd25519: boolean;
        readonly asEd25519: SpCoreEd25519Signature;
        readonly isSr25519: boolean;
        readonly asSr25519: SpCoreSr25519Signature;
        readonly isEcdsa: boolean;
        readonly asEcdsa: SpCoreEcdsaSignature;
        readonly type: "Ed25519" | "Sr25519" | "Ecdsa";
    }
    /** @name SpCoreEd25519Signature (219) */
    interface SpCoreEd25519Signature extends U8aFixed {
    }
    /** @name SpCoreSr25519Signature (221) */
    interface SpCoreSr25519Signature extends U8aFixed {
    }
    /** @name SpCoreEcdsaSignature (222) */
    interface SpCoreEcdsaSignature extends U8aFixed {
    }
    /** @name CumulusPalletDmpQueueCall (228) */
    interface CumulusPalletDmpQueueCall extends Enum {
        readonly isServiceOverweight: boolean;
        readonly asServiceOverweight: {
            readonly index: u64;
            readonly weightLimit: SpWeightsWeightV2Weight;
        } & Struct;
        readonly type: "ServiceOverweight";
    }
    /** @name PalletXcmCall (229) */
    interface PalletXcmCall extends Enum {
        readonly isSend: boolean;
        readonly asSend: {
            readonly dest: XcmVersionedMultiLocation;
            readonly message: XcmVersionedXcm;
        } & Struct;
        readonly isTeleportAssets: boolean;
        readonly asTeleportAssets: {
            readonly dest: XcmVersionedMultiLocation;
            readonly beneficiary: XcmVersionedMultiLocation;
            readonly assets: XcmVersionedMultiAssets;
            readonly feeAssetItem: u32;
        } & Struct;
        readonly isReserveTransferAssets: boolean;
        readonly asReserveTransferAssets: {
            readonly dest: XcmVersionedMultiLocation;
            readonly beneficiary: XcmVersionedMultiLocation;
            readonly assets: XcmVersionedMultiAssets;
            readonly feeAssetItem: u32;
        } & Struct;
        readonly isExecute: boolean;
        readonly asExecute: {
            readonly message: XcmVersionedXcm;
            readonly maxWeight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isForceXcmVersion: boolean;
        readonly asForceXcmVersion: {
            readonly location: XcmV3MultiLocation;
            readonly xcmVersion: u32;
        } & Struct;
        readonly isForceDefaultXcmVersion: boolean;
        readonly asForceDefaultXcmVersion: {
            readonly maybeXcmVersion: Option<u32>;
        } & Struct;
        readonly isForceSubscribeVersionNotify: boolean;
        readonly asForceSubscribeVersionNotify: {
            readonly location: XcmVersionedMultiLocation;
        } & Struct;
        readonly isForceUnsubscribeVersionNotify: boolean;
        readonly asForceUnsubscribeVersionNotify: {
            readonly location: XcmVersionedMultiLocation;
        } & Struct;
        readonly isLimitedReserveTransferAssets: boolean;
        readonly asLimitedReserveTransferAssets: {
            readonly dest: XcmVersionedMultiLocation;
            readonly beneficiary: XcmVersionedMultiLocation;
            readonly assets: XcmVersionedMultiAssets;
            readonly feeAssetItem: u32;
            readonly weightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isLimitedTeleportAssets: boolean;
        readonly asLimitedTeleportAssets: {
            readonly dest: XcmVersionedMultiLocation;
            readonly beneficiary: XcmVersionedMultiLocation;
            readonly assets: XcmVersionedMultiAssets;
            readonly feeAssetItem: u32;
            readonly weightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly type: "Send" | "TeleportAssets" | "ReserveTransferAssets" | "Execute" | "ForceXcmVersion" | "ForceDefaultXcmVersion" | "ForceSubscribeVersionNotify" | "ForceUnsubscribeVersionNotify" | "LimitedReserveTransferAssets" | "LimitedTeleportAssets";
    }
    /** @name XcmVersionedMultiLocation (230) */
    interface XcmVersionedMultiLocation extends Enum {
        readonly isV2: boolean;
        readonly asV2: XcmV2MultiLocation;
        readonly isV3: boolean;
        readonly asV3: XcmV3MultiLocation;
        readonly type: "V2" | "V3";
    }
    /** @name XcmV2MultiLocation (231) */
    interface XcmV2MultiLocation extends Struct {
        readonly parents: u8;
        readonly interior: XcmV2MultilocationJunctions;
    }
    /** @name XcmV2MultilocationJunctions (232) */
    interface XcmV2MultilocationJunctions extends Enum {
        readonly isHere: boolean;
        readonly isX1: boolean;
        readonly asX1: XcmV2Junction;
        readonly isX2: boolean;
        readonly asX2: ITuple<[XcmV2Junction, XcmV2Junction]>;
        readonly isX3: boolean;
        readonly asX3: ITuple<[XcmV2Junction, XcmV2Junction, XcmV2Junction]>;
        readonly isX4: boolean;
        readonly asX4: ITuple<[XcmV2Junction, XcmV2Junction, XcmV2Junction, XcmV2Junction]>;
        readonly isX5: boolean;
        readonly asX5: ITuple<[
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction
        ]>;
        readonly isX6: boolean;
        readonly asX6: ITuple<[
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction
        ]>;
        readonly isX7: boolean;
        readonly asX7: ITuple<[
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction
        ]>;
        readonly isX8: boolean;
        readonly asX8: ITuple<[
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction,
            XcmV2Junction
        ]>;
        readonly type: "Here" | "X1" | "X2" | "X3" | "X4" | "X5" | "X6" | "X7" | "X8";
    }
    /** @name XcmV2Junction (233) */
    interface XcmV2Junction extends Enum {
        readonly isParachain: boolean;
        readonly asParachain: Compact<u32>;
        readonly isAccountId32: boolean;
        readonly asAccountId32: {
            readonly network: XcmV2NetworkId;
            readonly id: U8aFixed;
        } & Struct;
        readonly isAccountIndex64: boolean;
        readonly asAccountIndex64: {
            readonly network: XcmV2NetworkId;
            readonly index: Compact<u64>;
        } & Struct;
        readonly isAccountKey20: boolean;
        readonly asAccountKey20: {
            readonly network: XcmV2NetworkId;
            readonly key: U8aFixed;
        } & Struct;
        readonly isPalletInstance: boolean;
        readonly asPalletInstance: u8;
        readonly isGeneralIndex: boolean;
        readonly asGeneralIndex: Compact<u128>;
        readonly isGeneralKey: boolean;
        readonly asGeneralKey: Bytes;
        readonly isOnlyChild: boolean;
        readonly isPlurality: boolean;
        readonly asPlurality: {
            readonly id: XcmV2BodyId;
            readonly part: XcmV2BodyPart;
        } & Struct;
        readonly type: "Parachain" | "AccountId32" | "AccountIndex64" | "AccountKey20" | "PalletInstance" | "GeneralIndex" | "GeneralKey" | "OnlyChild" | "Plurality";
    }
    /** @name XcmV2NetworkId (234) */
    interface XcmV2NetworkId extends Enum {
        readonly isAny: boolean;
        readonly isNamed: boolean;
        readonly asNamed: Bytes;
        readonly isPolkadot: boolean;
        readonly isKusama: boolean;
        readonly type: "Any" | "Named" | "Polkadot" | "Kusama";
    }
    /** @name XcmV2BodyId (236) */
    interface XcmV2BodyId extends Enum {
        readonly isUnit: boolean;
        readonly isNamed: boolean;
        readonly asNamed: Bytes;
        readonly isIndex: boolean;
        readonly asIndex: Compact<u32>;
        readonly isExecutive: boolean;
        readonly isTechnical: boolean;
        readonly isLegislative: boolean;
        readonly isJudicial: boolean;
        readonly isDefense: boolean;
        readonly isAdministration: boolean;
        readonly isTreasury: boolean;
        readonly type: "Unit" | "Named" | "Index" | "Executive" | "Technical" | "Legislative" | "Judicial" | "Defense" | "Administration" | "Treasury";
    }
    /** @name XcmV2BodyPart (237) */
    interface XcmV2BodyPart extends Enum {
        readonly isVoice: boolean;
        readonly isMembers: boolean;
        readonly asMembers: {
            readonly count: Compact<u32>;
        } & Struct;
        readonly isFraction: boolean;
        readonly asFraction: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly isAtLeastProportion: boolean;
        readonly asAtLeastProportion: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly isMoreThanProportion: boolean;
        readonly asMoreThanProportion: {
            readonly nom: Compact<u32>;
            readonly denom: Compact<u32>;
        } & Struct;
        readonly type: "Voice" | "Members" | "Fraction" | "AtLeastProportion" | "MoreThanProportion";
    }
    /** @name XcmVersionedXcm (238) */
    interface XcmVersionedXcm extends Enum {
        readonly isV2: boolean;
        readonly asV2: XcmV2Xcm;
        readonly isV3: boolean;
        readonly asV3: XcmV3Xcm;
        readonly type: "V2" | "V3";
    }
    /** @name XcmV2Xcm (239) */
    interface XcmV2Xcm extends Vec<XcmV2Instruction> {
    }
    /** @name XcmV2Instruction (241) */
    interface XcmV2Instruction extends Enum {
        readonly isWithdrawAsset: boolean;
        readonly asWithdrawAsset: XcmV2MultiassetMultiAssets;
        readonly isReserveAssetDeposited: boolean;
        readonly asReserveAssetDeposited: XcmV2MultiassetMultiAssets;
        readonly isReceiveTeleportedAsset: boolean;
        readonly asReceiveTeleportedAsset: XcmV2MultiassetMultiAssets;
        readonly isQueryResponse: boolean;
        readonly asQueryResponse: {
            readonly queryId: Compact<u64>;
            readonly response: XcmV2Response;
            readonly maxWeight: Compact<u64>;
        } & Struct;
        readonly isTransferAsset: boolean;
        readonly asTransferAsset: {
            readonly assets: XcmV2MultiassetMultiAssets;
            readonly beneficiary: XcmV2MultiLocation;
        } & Struct;
        readonly isTransferReserveAsset: boolean;
        readonly asTransferReserveAsset: {
            readonly assets: XcmV2MultiassetMultiAssets;
            readonly dest: XcmV2MultiLocation;
            readonly xcm: XcmV2Xcm;
        } & Struct;
        readonly isTransact: boolean;
        readonly asTransact: {
            readonly originType: XcmV2OriginKind;
            readonly requireWeightAtMost: Compact<u64>;
            readonly call: XcmDoubleEncoded;
        } & Struct;
        readonly isHrmpNewChannelOpenRequest: boolean;
        readonly asHrmpNewChannelOpenRequest: {
            readonly sender: Compact<u32>;
            readonly maxMessageSize: Compact<u32>;
            readonly maxCapacity: Compact<u32>;
        } & Struct;
        readonly isHrmpChannelAccepted: boolean;
        readonly asHrmpChannelAccepted: {
            readonly recipient: Compact<u32>;
        } & Struct;
        readonly isHrmpChannelClosing: boolean;
        readonly asHrmpChannelClosing: {
            readonly initiator: Compact<u32>;
            readonly sender: Compact<u32>;
            readonly recipient: Compact<u32>;
        } & Struct;
        readonly isClearOrigin: boolean;
        readonly isDescendOrigin: boolean;
        readonly asDescendOrigin: XcmV2MultilocationJunctions;
        readonly isReportError: boolean;
        readonly asReportError: {
            readonly queryId: Compact<u64>;
            readonly dest: XcmV2MultiLocation;
            readonly maxResponseWeight: Compact<u64>;
        } & Struct;
        readonly isDepositAsset: boolean;
        readonly asDepositAsset: {
            readonly assets: XcmV2MultiassetMultiAssetFilter;
            readonly maxAssets: Compact<u32>;
            readonly beneficiary: XcmV2MultiLocation;
        } & Struct;
        readonly isDepositReserveAsset: boolean;
        readonly asDepositReserveAsset: {
            readonly assets: XcmV2MultiassetMultiAssetFilter;
            readonly maxAssets: Compact<u32>;
            readonly dest: XcmV2MultiLocation;
            readonly xcm: XcmV2Xcm;
        } & Struct;
        readonly isExchangeAsset: boolean;
        readonly asExchangeAsset: {
            readonly give: XcmV2MultiassetMultiAssetFilter;
            readonly receive: XcmV2MultiassetMultiAssets;
        } & Struct;
        readonly isInitiateReserveWithdraw: boolean;
        readonly asInitiateReserveWithdraw: {
            readonly assets: XcmV2MultiassetMultiAssetFilter;
            readonly reserve: XcmV2MultiLocation;
            readonly xcm: XcmV2Xcm;
        } & Struct;
        readonly isInitiateTeleport: boolean;
        readonly asInitiateTeleport: {
            readonly assets: XcmV2MultiassetMultiAssetFilter;
            readonly dest: XcmV2MultiLocation;
            readonly xcm: XcmV2Xcm;
        } & Struct;
        readonly isQueryHolding: boolean;
        readonly asQueryHolding: {
            readonly queryId: Compact<u64>;
            readonly dest: XcmV2MultiLocation;
            readonly assets: XcmV2MultiassetMultiAssetFilter;
            readonly maxResponseWeight: Compact<u64>;
        } & Struct;
        readonly isBuyExecution: boolean;
        readonly asBuyExecution: {
            readonly fees: XcmV2MultiAsset;
            readonly weightLimit: XcmV2WeightLimit;
        } & Struct;
        readonly isRefundSurplus: boolean;
        readonly isSetErrorHandler: boolean;
        readonly asSetErrorHandler: XcmV2Xcm;
        readonly isSetAppendix: boolean;
        readonly asSetAppendix: XcmV2Xcm;
        readonly isClearError: boolean;
        readonly isClaimAsset: boolean;
        readonly asClaimAsset: {
            readonly assets: XcmV2MultiassetMultiAssets;
            readonly ticket: XcmV2MultiLocation;
        } & Struct;
        readonly isTrap: boolean;
        readonly asTrap: Compact<u64>;
        readonly isSubscribeVersion: boolean;
        readonly asSubscribeVersion: {
            readonly queryId: Compact<u64>;
            readonly maxResponseWeight: Compact<u64>;
        } & Struct;
        readonly isUnsubscribeVersion: boolean;
        readonly type: "WithdrawAsset" | "ReserveAssetDeposited" | "ReceiveTeleportedAsset" | "QueryResponse" | "TransferAsset" | "TransferReserveAsset" | "Transact" | "HrmpNewChannelOpenRequest" | "HrmpChannelAccepted" | "HrmpChannelClosing" | "ClearOrigin" | "DescendOrigin" | "ReportError" | "DepositAsset" | "DepositReserveAsset" | "ExchangeAsset" | "InitiateReserveWithdraw" | "InitiateTeleport" | "QueryHolding" | "BuyExecution" | "RefundSurplus" | "SetErrorHandler" | "SetAppendix" | "ClearError" | "ClaimAsset" | "Trap" | "SubscribeVersion" | "UnsubscribeVersion";
    }
    /** @name XcmV2MultiassetMultiAssets (242) */
    interface XcmV2MultiassetMultiAssets extends Vec<XcmV2MultiAsset> {
    }
    /** @name XcmV2MultiAsset (244) */
    interface XcmV2MultiAsset extends Struct {
        readonly id: XcmV2MultiassetAssetId;
        readonly fun: XcmV2MultiassetFungibility;
    }
    /** @name XcmV2MultiassetAssetId (245) */
    interface XcmV2MultiassetAssetId extends Enum {
        readonly isConcrete: boolean;
        readonly asConcrete: XcmV2MultiLocation;
        readonly isAbstract: boolean;
        readonly asAbstract: Bytes;
        readonly type: "Concrete" | "Abstract";
    }
    /** @name XcmV2MultiassetFungibility (246) */
    interface XcmV2MultiassetFungibility extends Enum {
        readonly isFungible: boolean;
        readonly asFungible: Compact<u128>;
        readonly isNonFungible: boolean;
        readonly asNonFungible: XcmV2MultiassetAssetInstance;
        readonly type: "Fungible" | "NonFungible";
    }
    /** @name XcmV2MultiassetAssetInstance (247) */
    interface XcmV2MultiassetAssetInstance extends Enum {
        readonly isUndefined: boolean;
        readonly isIndex: boolean;
        readonly asIndex: Compact<u128>;
        readonly isArray4: boolean;
        readonly asArray4: U8aFixed;
        readonly isArray8: boolean;
        readonly asArray8: U8aFixed;
        readonly isArray16: boolean;
        readonly asArray16: U8aFixed;
        readonly isArray32: boolean;
        readonly asArray32: U8aFixed;
        readonly isBlob: boolean;
        readonly asBlob: Bytes;
        readonly type: "Undefined" | "Index" | "Array4" | "Array8" | "Array16" | "Array32" | "Blob";
    }
    /** @name XcmV2Response (248) */
    interface XcmV2Response extends Enum {
        readonly isNull: boolean;
        readonly isAssets: boolean;
        readonly asAssets: XcmV2MultiassetMultiAssets;
        readonly isExecutionResult: boolean;
        readonly asExecutionResult: Option<ITuple<[u32, XcmV2TraitsError]>>;
        readonly isVersion: boolean;
        readonly asVersion: u32;
        readonly type: "Null" | "Assets" | "ExecutionResult" | "Version";
    }
    /** @name XcmV2TraitsError (251) */
    interface XcmV2TraitsError extends Enum {
        readonly isOverflow: boolean;
        readonly isUnimplemented: boolean;
        readonly isUntrustedReserveLocation: boolean;
        readonly isUntrustedTeleportLocation: boolean;
        readonly isMultiLocationFull: boolean;
        readonly isMultiLocationNotInvertible: boolean;
        readonly isBadOrigin: boolean;
        readonly isInvalidLocation: boolean;
        readonly isAssetNotFound: boolean;
        readonly isFailedToTransactAsset: boolean;
        readonly isNotWithdrawable: boolean;
        readonly isLocationCannotHold: boolean;
        readonly isExceedsMaxMessageSize: boolean;
        readonly isDestinationUnsupported: boolean;
        readonly isTransport: boolean;
        readonly isUnroutable: boolean;
        readonly isUnknownClaim: boolean;
        readonly isFailedToDecode: boolean;
        readonly isMaxWeightInvalid: boolean;
        readonly isNotHoldingFees: boolean;
        readonly isTooExpensive: boolean;
        readonly isTrap: boolean;
        readonly asTrap: u64;
        readonly isUnhandledXcmVersion: boolean;
        readonly isWeightLimitReached: boolean;
        readonly asWeightLimitReached: u64;
        readonly isBarrier: boolean;
        readonly isWeightNotComputable: boolean;
        readonly type: "Overflow" | "Unimplemented" | "UntrustedReserveLocation" | "UntrustedTeleportLocation" | "MultiLocationFull" | "MultiLocationNotInvertible" | "BadOrigin" | "InvalidLocation" | "AssetNotFound" | "FailedToTransactAsset" | "NotWithdrawable" | "LocationCannotHold" | "ExceedsMaxMessageSize" | "DestinationUnsupported" | "Transport" | "Unroutable" | "UnknownClaim" | "FailedToDecode" | "MaxWeightInvalid" | "NotHoldingFees" | "TooExpensive" | "Trap" | "UnhandledXcmVersion" | "WeightLimitReached" | "Barrier" | "WeightNotComputable";
    }
    /** @name XcmV2OriginKind (252) */
    interface XcmV2OriginKind extends Enum {
        readonly isNative: boolean;
        readonly isSovereignAccount: boolean;
        readonly isSuperuser: boolean;
        readonly isXcm: boolean;
        readonly type: "Native" | "SovereignAccount" | "Superuser" | "Xcm";
    }
    /** @name XcmDoubleEncoded (253) */
    interface XcmDoubleEncoded extends Struct {
        readonly encoded: Bytes;
    }
    /** @name XcmV2MultiassetMultiAssetFilter (254) */
    interface XcmV2MultiassetMultiAssetFilter extends Enum {
        readonly isDefinite: boolean;
        readonly asDefinite: XcmV2MultiassetMultiAssets;
        readonly isWild: boolean;
        readonly asWild: XcmV2MultiassetWildMultiAsset;
        readonly type: "Definite" | "Wild";
    }
    /** @name XcmV2MultiassetWildMultiAsset (255) */
    interface XcmV2MultiassetWildMultiAsset extends Enum {
        readonly isAll: boolean;
        readonly isAllOf: boolean;
        readonly asAllOf: {
            readonly id: XcmV2MultiassetAssetId;
            readonly fun: XcmV2MultiassetWildFungibility;
        } & Struct;
        readonly type: "All" | "AllOf";
    }
    /** @name XcmV2MultiassetWildFungibility (256) */
    interface XcmV2MultiassetWildFungibility extends Enum {
        readonly isFungible: boolean;
        readonly isNonFungible: boolean;
        readonly type: "Fungible" | "NonFungible";
    }
    /** @name XcmV2WeightLimit (257) */
    interface XcmV2WeightLimit extends Enum {
        readonly isUnlimited: boolean;
        readonly isLimited: boolean;
        readonly asLimited: Compact<u64>;
        readonly type: "Unlimited" | "Limited";
    }
    /** @name XcmV3Xcm (258) */
    interface XcmV3Xcm extends Vec<XcmV3Instruction> {
    }
    /** @name XcmV3Instruction (260) */
    interface XcmV3Instruction extends Enum {
        readonly isWithdrawAsset: boolean;
        readonly asWithdrawAsset: XcmV3MultiassetMultiAssets;
        readonly isReserveAssetDeposited: boolean;
        readonly asReserveAssetDeposited: XcmV3MultiassetMultiAssets;
        readonly isReceiveTeleportedAsset: boolean;
        readonly asReceiveTeleportedAsset: XcmV3MultiassetMultiAssets;
        readonly isQueryResponse: boolean;
        readonly asQueryResponse: {
            readonly queryId: Compact<u64>;
            readonly response: XcmV3Response;
            readonly maxWeight: SpWeightsWeightV2Weight;
            readonly querier: Option<XcmV3MultiLocation>;
        } & Struct;
        readonly isTransferAsset: boolean;
        readonly asTransferAsset: {
            readonly assets: XcmV3MultiassetMultiAssets;
            readonly beneficiary: XcmV3MultiLocation;
        } & Struct;
        readonly isTransferReserveAsset: boolean;
        readonly asTransferReserveAsset: {
            readonly assets: XcmV3MultiassetMultiAssets;
            readonly dest: XcmV3MultiLocation;
            readonly xcm: XcmV3Xcm;
        } & Struct;
        readonly isTransact: boolean;
        readonly asTransact: {
            readonly originKind: XcmV2OriginKind;
            readonly requireWeightAtMost: SpWeightsWeightV2Weight;
            readonly call: XcmDoubleEncoded;
        } & Struct;
        readonly isHrmpNewChannelOpenRequest: boolean;
        readonly asHrmpNewChannelOpenRequest: {
            readonly sender: Compact<u32>;
            readonly maxMessageSize: Compact<u32>;
            readonly maxCapacity: Compact<u32>;
        } & Struct;
        readonly isHrmpChannelAccepted: boolean;
        readonly asHrmpChannelAccepted: {
            readonly recipient: Compact<u32>;
        } & Struct;
        readonly isHrmpChannelClosing: boolean;
        readonly asHrmpChannelClosing: {
            readonly initiator: Compact<u32>;
            readonly sender: Compact<u32>;
            readonly recipient: Compact<u32>;
        } & Struct;
        readonly isClearOrigin: boolean;
        readonly isDescendOrigin: boolean;
        readonly asDescendOrigin: XcmV3Junctions;
        readonly isReportError: boolean;
        readonly asReportError: XcmV3QueryResponseInfo;
        readonly isDepositAsset: boolean;
        readonly asDepositAsset: {
            readonly assets: XcmV3MultiassetMultiAssetFilter;
            readonly beneficiary: XcmV3MultiLocation;
        } & Struct;
        readonly isDepositReserveAsset: boolean;
        readonly asDepositReserveAsset: {
            readonly assets: XcmV3MultiassetMultiAssetFilter;
            readonly dest: XcmV3MultiLocation;
            readonly xcm: XcmV3Xcm;
        } & Struct;
        readonly isExchangeAsset: boolean;
        readonly asExchangeAsset: {
            readonly give: XcmV3MultiassetMultiAssetFilter;
            readonly want: XcmV3MultiassetMultiAssets;
            readonly maximal: bool;
        } & Struct;
        readonly isInitiateReserveWithdraw: boolean;
        readonly asInitiateReserveWithdraw: {
            readonly assets: XcmV3MultiassetMultiAssetFilter;
            readonly reserve: XcmV3MultiLocation;
            readonly xcm: XcmV3Xcm;
        } & Struct;
        readonly isInitiateTeleport: boolean;
        readonly asInitiateTeleport: {
            readonly assets: XcmV3MultiassetMultiAssetFilter;
            readonly dest: XcmV3MultiLocation;
            readonly xcm: XcmV3Xcm;
        } & Struct;
        readonly isReportHolding: boolean;
        readonly asReportHolding: {
            readonly responseInfo: XcmV3QueryResponseInfo;
            readonly assets: XcmV3MultiassetMultiAssetFilter;
        } & Struct;
        readonly isBuyExecution: boolean;
        readonly asBuyExecution: {
            readonly fees: XcmV3MultiAsset;
            readonly weightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isRefundSurplus: boolean;
        readonly isSetErrorHandler: boolean;
        readonly asSetErrorHandler: XcmV3Xcm;
        readonly isSetAppendix: boolean;
        readonly asSetAppendix: XcmV3Xcm;
        readonly isClearError: boolean;
        readonly isClaimAsset: boolean;
        readonly asClaimAsset: {
            readonly assets: XcmV3MultiassetMultiAssets;
            readonly ticket: XcmV3MultiLocation;
        } & Struct;
        readonly isTrap: boolean;
        readonly asTrap: Compact<u64>;
        readonly isSubscribeVersion: boolean;
        readonly asSubscribeVersion: {
            readonly queryId: Compact<u64>;
            readonly maxResponseWeight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isUnsubscribeVersion: boolean;
        readonly isBurnAsset: boolean;
        readonly asBurnAsset: XcmV3MultiassetMultiAssets;
        readonly isExpectAsset: boolean;
        readonly asExpectAsset: XcmV3MultiassetMultiAssets;
        readonly isExpectOrigin: boolean;
        readonly asExpectOrigin: Option<XcmV3MultiLocation>;
        readonly isExpectError: boolean;
        readonly asExpectError: Option<ITuple<[u32, XcmV3TraitsError]>>;
        readonly isExpectTransactStatus: boolean;
        readonly asExpectTransactStatus: XcmV3MaybeErrorCode;
        readonly isQueryPallet: boolean;
        readonly asQueryPallet: {
            readonly moduleName: Bytes;
            readonly responseInfo: XcmV3QueryResponseInfo;
        } & Struct;
        readonly isExpectPallet: boolean;
        readonly asExpectPallet: {
            readonly index: Compact<u32>;
            readonly name: Bytes;
            readonly moduleName: Bytes;
            readonly crateMajor: Compact<u32>;
            readonly minCrateMinor: Compact<u32>;
        } & Struct;
        readonly isReportTransactStatus: boolean;
        readonly asReportTransactStatus: XcmV3QueryResponseInfo;
        readonly isClearTransactStatus: boolean;
        readonly isUniversalOrigin: boolean;
        readonly asUniversalOrigin: XcmV3Junction;
        readonly isExportMessage: boolean;
        readonly asExportMessage: {
            readonly network: XcmV3JunctionNetworkId;
            readonly destination: XcmV3Junctions;
            readonly xcm: XcmV3Xcm;
        } & Struct;
        readonly isLockAsset: boolean;
        readonly asLockAsset: {
            readonly asset: XcmV3MultiAsset;
            readonly unlocker: XcmV3MultiLocation;
        } & Struct;
        readonly isUnlockAsset: boolean;
        readonly asUnlockAsset: {
            readonly asset: XcmV3MultiAsset;
            readonly target: XcmV3MultiLocation;
        } & Struct;
        readonly isNoteUnlockable: boolean;
        readonly asNoteUnlockable: {
            readonly asset: XcmV3MultiAsset;
            readonly owner: XcmV3MultiLocation;
        } & Struct;
        readonly isRequestUnlock: boolean;
        readonly asRequestUnlock: {
            readonly asset: XcmV3MultiAsset;
            readonly locker: XcmV3MultiLocation;
        } & Struct;
        readonly isSetFeesMode: boolean;
        readonly asSetFeesMode: {
            readonly jitWithdraw: bool;
        } & Struct;
        readonly isSetTopic: boolean;
        readonly asSetTopic: U8aFixed;
        readonly isClearTopic: boolean;
        readonly isAliasOrigin: boolean;
        readonly asAliasOrigin: XcmV3MultiLocation;
        readonly isUnpaidExecution: boolean;
        readonly asUnpaidExecution: {
            readonly weightLimit: XcmV3WeightLimit;
            readonly checkOrigin: Option<XcmV3MultiLocation>;
        } & Struct;
        readonly type: "WithdrawAsset" | "ReserveAssetDeposited" | "ReceiveTeleportedAsset" | "QueryResponse" | "TransferAsset" | "TransferReserveAsset" | "Transact" | "HrmpNewChannelOpenRequest" | "HrmpChannelAccepted" | "HrmpChannelClosing" | "ClearOrigin" | "DescendOrigin" | "ReportError" | "DepositAsset" | "DepositReserveAsset" | "ExchangeAsset" | "InitiateReserveWithdraw" | "InitiateTeleport" | "ReportHolding" | "BuyExecution" | "RefundSurplus" | "SetErrorHandler" | "SetAppendix" | "ClearError" | "ClaimAsset" | "Trap" | "SubscribeVersion" | "UnsubscribeVersion" | "BurnAsset" | "ExpectAsset" | "ExpectOrigin" | "ExpectError" | "ExpectTransactStatus" | "QueryPallet" | "ExpectPallet" | "ReportTransactStatus" | "ClearTransactStatus" | "UniversalOrigin" | "ExportMessage" | "LockAsset" | "UnlockAsset" | "NoteUnlockable" | "RequestUnlock" | "SetFeesMode" | "SetTopic" | "ClearTopic" | "AliasOrigin" | "UnpaidExecution";
    }
    /** @name XcmV3MultiassetMultiAssets (261) */
    interface XcmV3MultiassetMultiAssets extends Vec<XcmV3MultiAsset> {
    }
    /** @name XcmV3MultiAsset (263) */
    interface XcmV3MultiAsset extends Struct {
        readonly id: XcmV3MultiassetAssetId;
        readonly fun: XcmV3MultiassetFungibility;
    }
    /** @name XcmV3MultiassetAssetId (264) */
    interface XcmV3MultiassetAssetId extends Enum {
        readonly isConcrete: boolean;
        readonly asConcrete: XcmV3MultiLocation;
        readonly isAbstract: boolean;
        readonly asAbstract: U8aFixed;
        readonly type: "Concrete" | "Abstract";
    }
    /** @name XcmV3MultiassetFungibility (265) */
    interface XcmV3MultiassetFungibility extends Enum {
        readonly isFungible: boolean;
        readonly asFungible: Compact<u128>;
        readonly isNonFungible: boolean;
        readonly asNonFungible: XcmV3MultiassetAssetInstance;
        readonly type: "Fungible" | "NonFungible";
    }
    /** @name XcmV3MultiassetAssetInstance (266) */
    interface XcmV3MultiassetAssetInstance extends Enum {
        readonly isUndefined: boolean;
        readonly isIndex: boolean;
        readonly asIndex: Compact<u128>;
        readonly isArray4: boolean;
        readonly asArray4: U8aFixed;
        readonly isArray8: boolean;
        readonly asArray8: U8aFixed;
        readonly isArray16: boolean;
        readonly asArray16: U8aFixed;
        readonly isArray32: boolean;
        readonly asArray32: U8aFixed;
        readonly type: "Undefined" | "Index" | "Array4" | "Array8" | "Array16" | "Array32";
    }
    /** @name XcmV3Response (267) */
    interface XcmV3Response extends Enum {
        readonly isNull: boolean;
        readonly isAssets: boolean;
        readonly asAssets: XcmV3MultiassetMultiAssets;
        readonly isExecutionResult: boolean;
        readonly asExecutionResult: Option<ITuple<[u32, XcmV3TraitsError]>>;
        readonly isVersion: boolean;
        readonly asVersion: u32;
        readonly isPalletsInfo: boolean;
        readonly asPalletsInfo: XcmV3VecPalletInfo;
        readonly isDispatchResult: boolean;
        readonly asDispatchResult: XcmV3MaybeErrorCode;
        readonly type: "Null" | "Assets" | "ExecutionResult" | "Version" | "PalletsInfo" | "DispatchResult";
    }
    /** @name XcmV3TraitsError (270) */
    interface XcmV3TraitsError extends Enum {
        readonly isOverflow: boolean;
        readonly isUnimplemented: boolean;
        readonly isUntrustedReserveLocation: boolean;
        readonly isUntrustedTeleportLocation: boolean;
        readonly isLocationFull: boolean;
        readonly isLocationNotInvertible: boolean;
        readonly isBadOrigin: boolean;
        readonly isInvalidLocation: boolean;
        readonly isAssetNotFound: boolean;
        readonly isFailedToTransactAsset: boolean;
        readonly isNotWithdrawable: boolean;
        readonly isLocationCannotHold: boolean;
        readonly isExceedsMaxMessageSize: boolean;
        readonly isDestinationUnsupported: boolean;
        readonly isTransport: boolean;
        readonly isUnroutable: boolean;
        readonly isUnknownClaim: boolean;
        readonly isFailedToDecode: boolean;
        readonly isMaxWeightInvalid: boolean;
        readonly isNotHoldingFees: boolean;
        readonly isTooExpensive: boolean;
        readonly isTrap: boolean;
        readonly asTrap: u64;
        readonly isExpectationFalse: boolean;
        readonly isPalletNotFound: boolean;
        readonly isNameMismatch: boolean;
        readonly isVersionIncompatible: boolean;
        readonly isHoldingWouldOverflow: boolean;
        readonly isExportError: boolean;
        readonly isReanchorFailed: boolean;
        readonly isNoDeal: boolean;
        readonly isFeesNotMet: boolean;
        readonly isLockError: boolean;
        readonly isNoPermission: boolean;
        readonly isUnanchored: boolean;
        readonly isNotDepositable: boolean;
        readonly isUnhandledXcmVersion: boolean;
        readonly isWeightLimitReached: boolean;
        readonly asWeightLimitReached: SpWeightsWeightV2Weight;
        readonly isBarrier: boolean;
        readonly isWeightNotComputable: boolean;
        readonly isExceedsStackLimit: boolean;
        readonly type: "Overflow" | "Unimplemented" | "UntrustedReserveLocation" | "UntrustedTeleportLocation" | "LocationFull" | "LocationNotInvertible" | "BadOrigin" | "InvalidLocation" | "AssetNotFound" | "FailedToTransactAsset" | "NotWithdrawable" | "LocationCannotHold" | "ExceedsMaxMessageSize" | "DestinationUnsupported" | "Transport" | "Unroutable" | "UnknownClaim" | "FailedToDecode" | "MaxWeightInvalid" | "NotHoldingFees" | "TooExpensive" | "Trap" | "ExpectationFalse" | "PalletNotFound" | "NameMismatch" | "VersionIncompatible" | "HoldingWouldOverflow" | "ExportError" | "ReanchorFailed" | "NoDeal" | "FeesNotMet" | "LockError" | "NoPermission" | "Unanchored" | "NotDepositable" | "UnhandledXcmVersion" | "WeightLimitReached" | "Barrier" | "WeightNotComputable" | "ExceedsStackLimit";
    }
    /** @name XcmV3VecPalletInfo (271) */
    interface XcmV3VecPalletInfo extends Vec<XcmV3PalletInfo> {
    }
    /** @name XcmV3PalletInfo (273) */
    interface XcmV3PalletInfo extends Struct {
        readonly index: Compact<u32>;
        readonly name: Bytes;
        readonly moduleName: Bytes;
        readonly major: Compact<u32>;
        readonly minor: Compact<u32>;
        readonly patch: Compact<u32>;
    }
    /** @name XcmV3MaybeErrorCode (274) */
    interface XcmV3MaybeErrorCode extends Enum {
        readonly isSuccess: boolean;
        readonly isError: boolean;
        readonly asError: Bytes;
        readonly isTruncatedError: boolean;
        readonly asTruncatedError: Bytes;
        readonly type: "Success" | "Error" | "TruncatedError";
    }
    /** @name XcmV3QueryResponseInfo (276) */
    interface XcmV3QueryResponseInfo extends Struct {
        readonly destination: XcmV3MultiLocation;
        readonly queryId: Compact<u64>;
        readonly maxWeight: SpWeightsWeightV2Weight;
    }
    /** @name XcmV3MultiassetMultiAssetFilter (277) */
    interface XcmV3MultiassetMultiAssetFilter extends Enum {
        readonly isDefinite: boolean;
        readonly asDefinite: XcmV3MultiassetMultiAssets;
        readonly isWild: boolean;
        readonly asWild: XcmV3MultiassetWildMultiAsset;
        readonly type: "Definite" | "Wild";
    }
    /** @name XcmV3MultiassetWildMultiAsset (278) */
    interface XcmV3MultiassetWildMultiAsset extends Enum {
        readonly isAll: boolean;
        readonly isAllOf: boolean;
        readonly asAllOf: {
            readonly id: XcmV3MultiassetAssetId;
            readonly fun: XcmV3MultiassetWildFungibility;
        } & Struct;
        readonly isAllCounted: boolean;
        readonly asAllCounted: Compact<u32>;
        readonly isAllOfCounted: boolean;
        readonly asAllOfCounted: {
            readonly id: XcmV3MultiassetAssetId;
            readonly fun: XcmV3MultiassetWildFungibility;
            readonly count: Compact<u32>;
        } & Struct;
        readonly type: "All" | "AllOf" | "AllCounted" | "AllOfCounted";
    }
    /** @name XcmV3MultiassetWildFungibility (279) */
    interface XcmV3MultiassetWildFungibility extends Enum {
        readonly isFungible: boolean;
        readonly isNonFungible: boolean;
        readonly type: "Fungible" | "NonFungible";
    }
    /** @name XcmV3WeightLimit (280) */
    interface XcmV3WeightLimit extends Enum {
        readonly isUnlimited: boolean;
        readonly isLimited: boolean;
        readonly asLimited: SpWeightsWeightV2Weight;
        readonly type: "Unlimited" | "Limited";
    }
    /** @name XcmVersionedMultiAssets (281) */
    interface XcmVersionedMultiAssets extends Enum {
        readonly isV2: boolean;
        readonly asV2: XcmV2MultiassetMultiAssets;
        readonly isV3: boolean;
        readonly asV3: XcmV3MultiassetMultiAssets;
        readonly type: "V2" | "V3";
    }
    /** @name PalletAssetsCall (290) */
    interface PalletAssetsCall extends Enum {
        readonly isCreate: boolean;
        readonly asCreate: {
            readonly id: Compact<u128>;
            readonly admin: AccountId20;
            readonly minBalance: u128;
        } & Struct;
        readonly isForceCreate: boolean;
        readonly asForceCreate: {
            readonly id: Compact<u128>;
            readonly owner: AccountId20;
            readonly isSufficient: bool;
            readonly minBalance: Compact<u128>;
        } & Struct;
        readonly isStartDestroy: boolean;
        readonly asStartDestroy: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isDestroyAccounts: boolean;
        readonly asDestroyAccounts: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isDestroyApprovals: boolean;
        readonly asDestroyApprovals: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isFinishDestroy: boolean;
        readonly asFinishDestroy: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isMint: boolean;
        readonly asMint: {
            readonly id: Compact<u128>;
            readonly beneficiary: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isBurn: boolean;
        readonly asBurn: {
            readonly id: Compact<u128>;
            readonly who: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly id: Compact<u128>;
            readonly target: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTransferKeepAlive: boolean;
        readonly asTransferKeepAlive: {
            readonly id: Compact<u128>;
            readonly target: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isForceTransfer: boolean;
        readonly asForceTransfer: {
            readonly id: Compact<u128>;
            readonly source: AccountId20;
            readonly dest: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isFreeze: boolean;
        readonly asFreeze: {
            readonly id: Compact<u128>;
            readonly who: AccountId20;
        } & Struct;
        readonly isThaw: boolean;
        readonly asThaw: {
            readonly id: Compact<u128>;
            readonly who: AccountId20;
        } & Struct;
        readonly isFreezeAsset: boolean;
        readonly asFreezeAsset: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isThawAsset: boolean;
        readonly asThawAsset: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isTransferOwnership: boolean;
        readonly asTransferOwnership: {
            readonly id: Compact<u128>;
            readonly owner: AccountId20;
        } & Struct;
        readonly isSetTeam: boolean;
        readonly asSetTeam: {
            readonly id: Compact<u128>;
            readonly issuer: AccountId20;
            readonly admin: AccountId20;
            readonly freezer: AccountId20;
        } & Struct;
        readonly isSetMetadata: boolean;
        readonly asSetMetadata: {
            readonly id: Compact<u128>;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
        } & Struct;
        readonly isClearMetadata: boolean;
        readonly asClearMetadata: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isForceSetMetadata: boolean;
        readonly asForceSetMetadata: {
            readonly id: Compact<u128>;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
            readonly isFrozen: bool;
        } & Struct;
        readonly isForceClearMetadata: boolean;
        readonly asForceClearMetadata: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isForceAssetStatus: boolean;
        readonly asForceAssetStatus: {
            readonly id: Compact<u128>;
            readonly owner: AccountId20;
            readonly issuer: AccountId20;
            readonly admin: AccountId20;
            readonly freezer: AccountId20;
            readonly minBalance: Compact<u128>;
            readonly isSufficient: bool;
            readonly isFrozen: bool;
        } & Struct;
        readonly isApproveTransfer: boolean;
        readonly asApproveTransfer: {
            readonly id: Compact<u128>;
            readonly delegate: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isCancelApproval: boolean;
        readonly asCancelApproval: {
            readonly id: Compact<u128>;
            readonly delegate: AccountId20;
        } & Struct;
        readonly isForceCancelApproval: boolean;
        readonly asForceCancelApproval: {
            readonly id: Compact<u128>;
            readonly owner: AccountId20;
            readonly delegate: AccountId20;
        } & Struct;
        readonly isTransferApproved: boolean;
        readonly asTransferApproved: {
            readonly id: Compact<u128>;
            readonly owner: AccountId20;
            readonly destination: AccountId20;
            readonly amount: Compact<u128>;
        } & Struct;
        readonly isTouch: boolean;
        readonly asTouch: {
            readonly id: Compact<u128>;
        } & Struct;
        readonly isRefund: boolean;
        readonly asRefund: {
            readonly id: Compact<u128>;
            readonly allowBurn: bool;
        } & Struct;
        readonly type: "Create" | "ForceCreate" | "StartDestroy" | "DestroyAccounts" | "DestroyApprovals" | "FinishDestroy" | "Mint" | "Burn" | "Transfer" | "TransferKeepAlive" | "ForceTransfer" | "Freeze" | "Thaw" | "FreezeAsset" | "ThawAsset" | "TransferOwnership" | "SetTeam" | "SetMetadata" | "ClearMetadata" | "ForceSetMetadata" | "ForceClearMetadata" | "ForceAssetStatus" | "ApproveTransfer" | "CancelApproval" | "ForceCancelApproval" | "TransferApproved" | "Touch" | "Refund";
    }
    /** @name PalletAssetManagerCall (291) */
    interface PalletAssetManagerCall extends Enum {
        readonly isRegisterForeignAsset: boolean;
        readonly asRegisterForeignAsset: {
            readonly asset: MoonriverRuntimeXcmConfigAssetType;
            readonly metadata: MoonriverRuntimeAssetConfigAssetRegistrarMetadata;
            readonly minAmount: u128;
            readonly isSufficient: bool;
        } & Struct;
        readonly isSetAssetUnitsPerSecond: boolean;
        readonly asSetAssetUnitsPerSecond: {
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
            readonly unitsPerSecond: u128;
            readonly numAssetsWeightHint: u32;
        } & Struct;
        readonly isChangeExistingAssetType: boolean;
        readonly asChangeExistingAssetType: {
            readonly assetId: u128;
            readonly newAssetType: MoonriverRuntimeXcmConfigAssetType;
            readonly numAssetsWeightHint: u32;
        } & Struct;
        readonly isRemoveSupportedAsset: boolean;
        readonly asRemoveSupportedAsset: {
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
            readonly numAssetsWeightHint: u32;
        } & Struct;
        readonly isRemoveExistingAssetType: boolean;
        readonly asRemoveExistingAssetType: {
            readonly assetId: u128;
            readonly numAssetsWeightHint: u32;
        } & Struct;
        readonly isRegisterLocalAsset: boolean;
        readonly asRegisterLocalAsset: {
            readonly creator: AccountId20;
            readonly owner: AccountId20;
            readonly isSufficient: bool;
            readonly minBalance: u128;
        } & Struct;
        readonly isDestroyForeignAsset: boolean;
        readonly asDestroyForeignAsset: {
            readonly assetId: u128;
            readonly numAssetsWeightHint: u32;
        } & Struct;
        readonly isDestroyLocalAsset: boolean;
        readonly asDestroyLocalAsset: {
            readonly assetId: u128;
        } & Struct;
        readonly type: "RegisterForeignAsset" | "SetAssetUnitsPerSecond" | "ChangeExistingAssetType" | "RemoveSupportedAsset" | "RemoveExistingAssetType" | "RegisterLocalAsset" | "DestroyForeignAsset" | "DestroyLocalAsset";
    }
    /** @name MoonriverRuntimeXcmConfigAssetType (292) */
    interface MoonriverRuntimeXcmConfigAssetType extends Enum {
        readonly isXcm: boolean;
        readonly asXcm: XcmV3MultiLocation;
        readonly type: "Xcm";
    }
    /** @name MoonriverRuntimeAssetConfigAssetRegistrarMetadata (293) */
    interface MoonriverRuntimeAssetConfigAssetRegistrarMetadata extends Struct {
        readonly name: Bytes;
        readonly symbol: Bytes;
        readonly decimals: u8;
        readonly isFrozen: bool;
    }
    /** @name OrmlXtokensModuleCall (294) */
    interface OrmlXtokensModuleCall extends Enum {
        readonly isTransfer: boolean;
        readonly asTransfer: {
            readonly currencyId: MoonriverRuntimeXcmConfigCurrencyId;
            readonly amount: u128;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isTransferMultiasset: boolean;
        readonly asTransferMultiasset: {
            readonly asset: XcmVersionedMultiAsset;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isTransferWithFee: boolean;
        readonly asTransferWithFee: {
            readonly currencyId: MoonriverRuntimeXcmConfigCurrencyId;
            readonly amount: u128;
            readonly fee: u128;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isTransferMultiassetWithFee: boolean;
        readonly asTransferMultiassetWithFee: {
            readonly asset: XcmVersionedMultiAsset;
            readonly fee: XcmVersionedMultiAsset;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isTransferMulticurrencies: boolean;
        readonly asTransferMulticurrencies: {
            readonly currencies: Vec<ITuple<[MoonriverRuntimeXcmConfigCurrencyId, u128]>>;
            readonly feeItem: u32;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly isTransferMultiassets: boolean;
        readonly asTransferMultiassets: {
            readonly assets: XcmVersionedMultiAssets;
            readonly feeItem: u32;
            readonly dest: XcmVersionedMultiLocation;
            readonly destWeightLimit: XcmV3WeightLimit;
        } & Struct;
        readonly type: "Transfer" | "TransferMultiasset" | "TransferWithFee" | "TransferMultiassetWithFee" | "TransferMulticurrencies" | "TransferMultiassets";
    }
    /** @name MoonriverRuntimeXcmConfigCurrencyId (295) */
    interface MoonriverRuntimeXcmConfigCurrencyId extends Enum {
        readonly isSelfReserve: boolean;
        readonly isForeignAsset: boolean;
        readonly asForeignAsset: u128;
        readonly isLocalAssetReserve: boolean;
        readonly asLocalAssetReserve: u128;
        readonly type: "SelfReserve" | "ForeignAsset" | "LocalAssetReserve";
    }
    /** @name XcmVersionedMultiAsset (296) */
    interface XcmVersionedMultiAsset extends Enum {
        readonly isV2: boolean;
        readonly asV2: XcmV2MultiAsset;
        readonly isV3: boolean;
        readonly asV3: XcmV3MultiAsset;
        readonly type: "V2" | "V3";
    }
    /** @name PalletXcmTransactorCall (299) */
    interface PalletXcmTransactorCall extends Enum {
        readonly isRegister: boolean;
        readonly asRegister: {
            readonly who: AccountId20;
            readonly index: u16;
        } & Struct;
        readonly isDeregister: boolean;
        readonly asDeregister: {
            readonly index: u16;
        } & Struct;
        readonly isTransactThroughDerivative: boolean;
        readonly asTransactThroughDerivative: {
            readonly dest: MoonriverRuntimeXcmConfigTransactors;
            readonly index: u16;
            readonly fee: PalletXcmTransactorCurrencyPayment;
            readonly innerCall: Bytes;
            readonly weightInfo: PalletXcmTransactorTransactWeights;
        } & Struct;
        readonly isTransactThroughSovereign: boolean;
        readonly asTransactThroughSovereign: {
            readonly dest: XcmVersionedMultiLocation;
            readonly feePayer: AccountId20;
            readonly fee: PalletXcmTransactorCurrencyPayment;
            readonly call: Bytes;
            readonly originKind: XcmV2OriginKind;
            readonly weightInfo: PalletXcmTransactorTransactWeights;
        } & Struct;
        readonly isSetTransactInfo: boolean;
        readonly asSetTransactInfo: {
            readonly location: XcmVersionedMultiLocation;
            readonly transactExtraWeight: SpWeightsWeightV2Weight;
            readonly maxWeight: SpWeightsWeightV2Weight;
            readonly transactExtraWeightSigned: Option<SpWeightsWeightV2Weight>;
        } & Struct;
        readonly isRemoveTransactInfo: boolean;
        readonly asRemoveTransactInfo: {
            readonly location: XcmVersionedMultiLocation;
        } & Struct;
        readonly isTransactThroughSigned: boolean;
        readonly asTransactThroughSigned: {
            readonly dest: XcmVersionedMultiLocation;
            readonly fee: PalletXcmTransactorCurrencyPayment;
            readonly call: Bytes;
            readonly weightInfo: PalletXcmTransactorTransactWeights;
        } & Struct;
        readonly isSetFeePerSecond: boolean;
        readonly asSetFeePerSecond: {
            readonly assetLocation: XcmVersionedMultiLocation;
            readonly feePerSecond: u128;
        } & Struct;
        readonly isRemoveFeePerSecond: boolean;
        readonly asRemoveFeePerSecond: {
            readonly assetLocation: XcmVersionedMultiLocation;
        } & Struct;
        readonly isHrmpManage: boolean;
        readonly asHrmpManage: {
            readonly action: PalletXcmTransactorHrmpOperation;
            readonly fee: PalletXcmTransactorCurrencyPayment;
            readonly weightInfo: PalletXcmTransactorTransactWeights;
        } & Struct;
        readonly type: "Register" | "Deregister" | "TransactThroughDerivative" | "TransactThroughSovereign" | "SetTransactInfo" | "RemoveTransactInfo" | "TransactThroughSigned" | "SetFeePerSecond" | "RemoveFeePerSecond" | "HrmpManage";
    }
    /** @name MoonriverRuntimeXcmConfigTransactors (300) */
    interface MoonriverRuntimeXcmConfigTransactors extends Enum {
        readonly isRelay: boolean;
        readonly type: "Relay";
    }
    /** @name PalletXcmTransactorCurrencyPayment (301) */
    interface PalletXcmTransactorCurrencyPayment extends Struct {
        readonly currency: PalletXcmTransactorCurrency;
        readonly feeAmount: Option<u128>;
    }
    /** @name PalletXcmTransactorCurrency (302) */
    interface PalletXcmTransactorCurrency extends Enum {
        readonly isAsCurrencyId: boolean;
        readonly asAsCurrencyId: MoonriverRuntimeXcmConfigCurrencyId;
        readonly isAsMultiLocation: boolean;
        readonly asAsMultiLocation: XcmVersionedMultiLocation;
        readonly type: "AsCurrencyId" | "AsMultiLocation";
    }
    /** @name PalletXcmTransactorTransactWeights (304) */
    interface PalletXcmTransactorTransactWeights extends Struct {
        readonly transactRequiredWeightAtMost: SpWeightsWeightV2Weight;
        readonly overallWeight: Option<SpWeightsWeightV2Weight>;
    }
    /** @name PalletXcmTransactorHrmpOperation (306) */
    interface PalletXcmTransactorHrmpOperation extends Enum {
        readonly isInitOpen: boolean;
        readonly asInitOpen: PalletXcmTransactorHrmpInitParams;
        readonly isAccept: boolean;
        readonly asAccept: {
            readonly paraId: u32;
        } & Struct;
        readonly isClose: boolean;
        readonly asClose: PolkadotParachainPrimitivesHrmpChannelId;
        readonly isCancel: boolean;
        readonly asCancel: {
            readonly channelId: PolkadotParachainPrimitivesHrmpChannelId;
            readonly openRequests: u32;
        } & Struct;
        readonly type: "InitOpen" | "Accept" | "Close" | "Cancel";
    }
    /** @name PalletXcmTransactorHrmpInitParams (307) */
    interface PalletXcmTransactorHrmpInitParams extends Struct {
        readonly paraId: u32;
        readonly proposedMaxCapacity: u32;
        readonly proposedMaxMessageSize: u32;
    }
    /** @name PolkadotParachainPrimitivesHrmpChannelId (308) */
    interface PolkadotParachainPrimitivesHrmpChannelId extends Struct {
        readonly sender: u32;
        readonly recipient: u32;
    }
    /** @name PalletRandomnessCall (310) */
    interface PalletRandomnessCall extends Enum {
        readonly isSetBabeRandomnessResults: boolean;
        readonly type: "SetBabeRandomnessResults";
    }
    /** @name PalletConvictionVotingTally (312) */
    interface PalletConvictionVotingTally extends Struct {
        readonly ayes: u128;
        readonly nays: u128;
        readonly support: u128;
    }
    /** @name PalletWhitelistEvent (313) */
    interface PalletWhitelistEvent extends Enum {
        readonly isCallWhitelisted: boolean;
        readonly asCallWhitelisted: {
            readonly callHash: H256;
        } & Struct;
        readonly isWhitelistedCallRemoved: boolean;
        readonly asWhitelistedCallRemoved: {
            readonly callHash: H256;
        } & Struct;
        readonly isWhitelistedCallDispatched: boolean;
        readonly asWhitelistedCallDispatched: {
            readonly callHash: H256;
            readonly result: Result<FrameSupportDispatchPostDispatchInfo, SpRuntimeDispatchErrorWithPostInfo>;
        } & Struct;
        readonly type: "CallWhitelisted" | "WhitelistedCallRemoved" | "WhitelistedCallDispatched";
    }
    /** @name FrameSupportDispatchPostDispatchInfo (315) */
    interface FrameSupportDispatchPostDispatchInfo extends Struct {
        readonly actualWeight: Option<SpWeightsWeightV2Weight>;
        readonly paysFee: FrameSupportDispatchPays;
    }
    /** @name SpRuntimeDispatchErrorWithPostInfo (316) */
    interface SpRuntimeDispatchErrorWithPostInfo extends Struct {
        readonly postInfo: FrameSupportDispatchPostDispatchInfo;
        readonly error: SpRuntimeDispatchError;
    }
    /** @name PalletCollectiveEvent (317) */
    interface PalletCollectiveEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly account: AccountId20;
            readonly proposalIndex: u32;
            readonly proposalHash: H256;
            readonly threshold: u32;
        } & Struct;
        readonly isVoted: boolean;
        readonly asVoted: {
            readonly account: AccountId20;
            readonly proposalHash: H256;
            readonly voted: bool;
            readonly yes: u32;
            readonly no: u32;
        } & Struct;
        readonly isApproved: boolean;
        readonly asApproved: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isDisapproved: boolean;
        readonly asDisapproved: {
            readonly proposalHash: H256;
        } & Struct;
        readonly isExecuted: boolean;
        readonly asExecuted: {
            readonly proposalHash: H256;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isMemberExecuted: boolean;
        readonly asMemberExecuted: {
            readonly proposalHash: H256;
            readonly result: Result<Null, SpRuntimeDispatchError>;
        } & Struct;
        readonly isClosed: boolean;
        readonly asClosed: {
            readonly proposalHash: H256;
            readonly yes: u32;
            readonly no: u32;
        } & Struct;
        readonly type: "Proposed" | "Voted" | "Approved" | "Disapproved" | "Executed" | "MemberExecuted" | "Closed";
    }
    /** @name PalletTreasuryEvent (321) */
    interface PalletTreasuryEvent extends Enum {
        readonly isProposed: boolean;
        readonly asProposed: {
            readonly proposalIndex: u32;
        } & Struct;
        readonly isSpending: boolean;
        readonly asSpending: {
            readonly budgetRemaining: u128;
        } & Struct;
        readonly isAwarded: boolean;
        readonly asAwarded: {
            readonly proposalIndex: u32;
            readonly award: u128;
            readonly account: AccountId20;
        } & Struct;
        readonly isRejected: boolean;
        readonly asRejected: {
            readonly proposalIndex: u32;
            readonly slashed: u128;
        } & Struct;
        readonly isBurnt: boolean;
        readonly asBurnt: {
            readonly burntFunds: u128;
        } & Struct;
        readonly isRollover: boolean;
        readonly asRollover: {
            readonly rolloverBalance: u128;
        } & Struct;
        readonly isDeposit: boolean;
        readonly asDeposit: {
            readonly value: u128;
        } & Struct;
        readonly isSpendApproved: boolean;
        readonly asSpendApproved: {
            readonly proposalIndex: u32;
            readonly amount: u128;
            readonly beneficiary: AccountId20;
        } & Struct;
        readonly isUpdatedInactive: boolean;
        readonly asUpdatedInactive: {
            readonly reactivated: u128;
            readonly deactivated: u128;
        } & Struct;
        readonly type: "Proposed" | "Spending" | "Awarded" | "Rejected" | "Burnt" | "Rollover" | "Deposit" | "SpendApproved" | "UpdatedInactive";
    }
    /** @name PalletCrowdloanRewardsEvent (322) */
    interface PalletCrowdloanRewardsEvent extends Enum {
        readonly isInitialPaymentMade: boolean;
        readonly asInitialPaymentMade: ITuple<[AccountId20, u128]>;
        readonly isNativeIdentityAssociated: boolean;
        readonly asNativeIdentityAssociated: ITuple<[U8aFixed, AccountId20, u128]>;
        readonly isRewardsPaid: boolean;
        readonly asRewardsPaid: ITuple<[AccountId20, u128]>;
        readonly isRewardAddressUpdated: boolean;
        readonly asRewardAddressUpdated: ITuple<[AccountId20, AccountId20]>;
        readonly isInitializedAlreadyInitializedAccount: boolean;
        readonly asInitializedAlreadyInitializedAccount: ITuple<[U8aFixed, Option<AccountId20>, u128]>;
        readonly isInitializedAccountWithNotEnoughContribution: boolean;
        readonly asInitializedAccountWithNotEnoughContribution: ITuple<[
            U8aFixed,
            Option<AccountId20>,
            u128
        ]>;
        readonly type: "InitialPaymentMade" | "NativeIdentityAssociated" | "RewardsPaid" | "RewardAddressUpdated" | "InitializedAlreadyInitializedAccount" | "InitializedAccountWithNotEnoughContribution";
    }
    /** @name CumulusPalletXcmpQueueEvent (323) */
    interface CumulusPalletXcmpQueueEvent extends Enum {
        readonly isSuccess: boolean;
        readonly asSuccess: {
            readonly messageHash: Option<U8aFixed>;
            readonly weight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isFail: boolean;
        readonly asFail: {
            readonly messageHash: Option<U8aFixed>;
            readonly error: XcmV3TraitsError;
            readonly weight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isBadVersion: boolean;
        readonly asBadVersion: {
            readonly messageHash: Option<U8aFixed>;
        } & Struct;
        readonly isBadFormat: boolean;
        readonly asBadFormat: {
            readonly messageHash: Option<U8aFixed>;
        } & Struct;
        readonly isXcmpMessageSent: boolean;
        readonly asXcmpMessageSent: {
            readonly messageHash: Option<U8aFixed>;
        } & Struct;
        readonly isOverweightEnqueued: boolean;
        readonly asOverweightEnqueued: {
            readonly sender: u32;
            readonly sentAt: u32;
            readonly index: u64;
            readonly required: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isOverweightServiced: boolean;
        readonly asOverweightServiced: {
            readonly index: u64;
            readonly used: SpWeightsWeightV2Weight;
        } & Struct;
        readonly type: "Success" | "Fail" | "BadVersion" | "BadFormat" | "XcmpMessageSent" | "OverweightEnqueued" | "OverweightServiced";
    }
    /** @name CumulusPalletXcmEvent (324) */
    interface CumulusPalletXcmEvent extends Enum {
        readonly isInvalidFormat: boolean;
        readonly asInvalidFormat: U8aFixed;
        readonly isUnsupportedVersion: boolean;
        readonly asUnsupportedVersion: U8aFixed;
        readonly isExecutedDownward: boolean;
        readonly asExecutedDownward: ITuple<[U8aFixed, XcmV3TraitsOutcome]>;
        readonly type: "InvalidFormat" | "UnsupportedVersion" | "ExecutedDownward";
    }
    /** @name XcmV3TraitsOutcome (325) */
    interface XcmV3TraitsOutcome extends Enum {
        readonly isComplete: boolean;
        readonly asComplete: SpWeightsWeightV2Weight;
        readonly isIncomplete: boolean;
        readonly asIncomplete: ITuple<[SpWeightsWeightV2Weight, XcmV3TraitsError]>;
        readonly isError: boolean;
        readonly asError: XcmV3TraitsError;
        readonly type: "Complete" | "Incomplete" | "Error";
    }
    /** @name CumulusPalletDmpQueueEvent (326) */
    interface CumulusPalletDmpQueueEvent extends Enum {
        readonly isInvalidFormat: boolean;
        readonly asInvalidFormat: {
            readonly messageId: U8aFixed;
        } & Struct;
        readonly isUnsupportedVersion: boolean;
        readonly asUnsupportedVersion: {
            readonly messageId: U8aFixed;
        } & Struct;
        readonly isExecutedDownward: boolean;
        readonly asExecutedDownward: {
            readonly messageId: U8aFixed;
            readonly outcome: XcmV3TraitsOutcome;
        } & Struct;
        readonly isWeightExhausted: boolean;
        readonly asWeightExhausted: {
            readonly messageId: U8aFixed;
            readonly remainingWeight: SpWeightsWeightV2Weight;
            readonly requiredWeight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isOverweightEnqueued: boolean;
        readonly asOverweightEnqueued: {
            readonly messageId: U8aFixed;
            readonly overweightIndex: u64;
            readonly requiredWeight: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isOverweightServiced: boolean;
        readonly asOverweightServiced: {
            readonly overweightIndex: u64;
            readonly weightUsed: SpWeightsWeightV2Weight;
        } & Struct;
        readonly isMaxMessagesExhausted: boolean;
        readonly asMaxMessagesExhausted: {
            readonly messageId: U8aFixed;
        } & Struct;
        readonly type: "InvalidFormat" | "UnsupportedVersion" | "ExecutedDownward" | "WeightExhausted" | "OverweightEnqueued" | "OverweightServiced" | "MaxMessagesExhausted";
    }
    /** @name PalletXcmEvent (327) */
    interface PalletXcmEvent extends Enum {
        readonly isAttempted: boolean;
        readonly asAttempted: XcmV3TraitsOutcome;
        readonly isSent: boolean;
        readonly asSent: ITuple<[XcmV3MultiLocation, XcmV3MultiLocation, XcmV3Xcm]>;
        readonly isUnexpectedResponse: boolean;
        readonly asUnexpectedResponse: ITuple<[XcmV3MultiLocation, u64]>;
        readonly isResponseReady: boolean;
        readonly asResponseReady: ITuple<[u64, XcmV3Response]>;
        readonly isNotified: boolean;
        readonly asNotified: ITuple<[u64, u8, u8]>;
        readonly isNotifyOverweight: boolean;
        readonly asNotifyOverweight: ITuple<[
            u64,
            u8,
            u8,
            SpWeightsWeightV2Weight,
            SpWeightsWeightV2Weight
        ]>;
        readonly isNotifyDispatchError: boolean;
        readonly asNotifyDispatchError: ITuple<[u64, u8, u8]>;
        readonly isNotifyDecodeFailed: boolean;
        readonly asNotifyDecodeFailed: ITuple<[u64, u8, u8]>;
        readonly isInvalidResponder: boolean;
        readonly asInvalidResponder: ITuple<[XcmV3MultiLocation, u64, Option<XcmV3MultiLocation>]>;
        readonly isInvalidResponderVersion: boolean;
        readonly asInvalidResponderVersion: ITuple<[XcmV3MultiLocation, u64]>;
        readonly isResponseTaken: boolean;
        readonly asResponseTaken: u64;
        readonly isAssetsTrapped: boolean;
        readonly asAssetsTrapped: ITuple<[H256, XcmV3MultiLocation, XcmVersionedMultiAssets]>;
        readonly isVersionChangeNotified: boolean;
        readonly asVersionChangeNotified: ITuple<[XcmV3MultiLocation, u32, XcmV3MultiassetMultiAssets]>;
        readonly isSupportedVersionChanged: boolean;
        readonly asSupportedVersionChanged: ITuple<[XcmV3MultiLocation, u32]>;
        readonly isNotifyTargetSendFail: boolean;
        readonly asNotifyTargetSendFail: ITuple<[XcmV3MultiLocation, u64, XcmV3TraitsError]>;
        readonly isNotifyTargetMigrationFail: boolean;
        readonly asNotifyTargetMigrationFail: ITuple<[XcmVersionedMultiLocation, u64]>;
        readonly isInvalidQuerierVersion: boolean;
        readonly asInvalidQuerierVersion: ITuple<[XcmV3MultiLocation, u64]>;
        readonly isInvalidQuerier: boolean;
        readonly asInvalidQuerier: ITuple<[
            XcmV3MultiLocation,
            u64,
            XcmV3MultiLocation,
            Option<XcmV3MultiLocation>
        ]>;
        readonly isVersionNotifyStarted: boolean;
        readonly asVersionNotifyStarted: ITuple<[XcmV3MultiLocation, XcmV3MultiassetMultiAssets]>;
        readonly isVersionNotifyRequested: boolean;
        readonly asVersionNotifyRequested: ITuple<[XcmV3MultiLocation, XcmV3MultiassetMultiAssets]>;
        readonly isVersionNotifyUnrequested: boolean;
        readonly asVersionNotifyUnrequested: ITuple<[XcmV3MultiLocation, XcmV3MultiassetMultiAssets]>;
        readonly isFeesPaid: boolean;
        readonly asFeesPaid: ITuple<[XcmV3MultiLocation, XcmV3MultiassetMultiAssets]>;
        readonly isAssetsClaimed: boolean;
        readonly asAssetsClaimed: ITuple<[H256, XcmV3MultiLocation, XcmVersionedMultiAssets]>;
        readonly type: "Attempted" | "Sent" | "UnexpectedResponse" | "ResponseReady" | "Notified" | "NotifyOverweight" | "NotifyDispatchError" | "NotifyDecodeFailed" | "InvalidResponder" | "InvalidResponderVersion" | "ResponseTaken" | "AssetsTrapped" | "VersionChangeNotified" | "SupportedVersionChanged" | "NotifyTargetSendFail" | "NotifyTargetMigrationFail" | "InvalidQuerierVersion" | "InvalidQuerier" | "VersionNotifyStarted" | "VersionNotifyRequested" | "VersionNotifyUnrequested" | "FeesPaid" | "AssetsClaimed";
    }
    /** @name PalletAssetsEvent (328) */
    interface PalletAssetsEvent extends Enum {
        readonly isCreated: boolean;
        readonly asCreated: {
            readonly assetId: u128;
            readonly creator: AccountId20;
            readonly owner: AccountId20;
        } & Struct;
        readonly isIssued: boolean;
        readonly asIssued: {
            readonly assetId: u128;
            readonly owner: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isTransferred: boolean;
        readonly asTransferred: {
            readonly assetId: u128;
            readonly from: AccountId20;
            readonly to: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isBurned: boolean;
        readonly asBurned: {
            readonly assetId: u128;
            readonly owner: AccountId20;
            readonly balance: u128;
        } & Struct;
        readonly isTeamChanged: boolean;
        readonly asTeamChanged: {
            readonly assetId: u128;
            readonly issuer: AccountId20;
            readonly admin: AccountId20;
            readonly freezer: AccountId20;
        } & Struct;
        readonly isOwnerChanged: boolean;
        readonly asOwnerChanged: {
            readonly assetId: u128;
            readonly owner: AccountId20;
        } & Struct;
        readonly isFrozen: boolean;
        readonly asFrozen: {
            readonly assetId: u128;
            readonly who: AccountId20;
        } & Struct;
        readonly isThawed: boolean;
        readonly asThawed: {
            readonly assetId: u128;
            readonly who: AccountId20;
        } & Struct;
        readonly isAssetFrozen: boolean;
        readonly asAssetFrozen: {
            readonly assetId: u128;
        } & Struct;
        readonly isAssetThawed: boolean;
        readonly asAssetThawed: {
            readonly assetId: u128;
        } & Struct;
        readonly isAccountsDestroyed: boolean;
        readonly asAccountsDestroyed: {
            readonly assetId: u128;
            readonly accountsDestroyed: u32;
            readonly accountsRemaining: u32;
        } & Struct;
        readonly isApprovalsDestroyed: boolean;
        readonly asApprovalsDestroyed: {
            readonly assetId: u128;
            readonly approvalsDestroyed: u32;
            readonly approvalsRemaining: u32;
        } & Struct;
        readonly isDestructionStarted: boolean;
        readonly asDestructionStarted: {
            readonly assetId: u128;
        } & Struct;
        readonly isDestroyed: boolean;
        readonly asDestroyed: {
            readonly assetId: u128;
        } & Struct;
        readonly isForceCreated: boolean;
        readonly asForceCreated: {
            readonly assetId: u128;
            readonly owner: AccountId20;
        } & Struct;
        readonly isMetadataSet: boolean;
        readonly asMetadataSet: {
            readonly assetId: u128;
            readonly name: Bytes;
            readonly symbol: Bytes;
            readonly decimals: u8;
            readonly isFrozen: bool;
        } & Struct;
        readonly isMetadataCleared: boolean;
        readonly asMetadataCleared: {
            readonly assetId: u128;
        } & Struct;
        readonly isApprovedTransfer: boolean;
        readonly asApprovedTransfer: {
            readonly assetId: u128;
            readonly source: AccountId20;
            readonly delegate: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isApprovalCancelled: boolean;
        readonly asApprovalCancelled: {
            readonly assetId: u128;
            readonly owner: AccountId20;
            readonly delegate: AccountId20;
        } & Struct;
        readonly isTransferredApproved: boolean;
        readonly asTransferredApproved: {
            readonly assetId: u128;
            readonly owner: AccountId20;
            readonly delegate: AccountId20;
            readonly destination: AccountId20;
            readonly amount: u128;
        } & Struct;
        readonly isAssetStatusChanged: boolean;
        readonly asAssetStatusChanged: {
            readonly assetId: u128;
        } & Struct;
        readonly type: "Created" | "Issued" | "Transferred" | "Burned" | "TeamChanged" | "OwnerChanged" | "Frozen" | "Thawed" | "AssetFrozen" | "AssetThawed" | "AccountsDestroyed" | "ApprovalsDestroyed" | "DestructionStarted" | "Destroyed" | "ForceCreated" | "MetadataSet" | "MetadataCleared" | "ApprovedTransfer" | "ApprovalCancelled" | "TransferredApproved" | "AssetStatusChanged";
    }
    /** @name PalletAssetManagerEvent (329) */
    interface PalletAssetManagerEvent extends Enum {
        readonly isForeignAssetRegistered: boolean;
        readonly asForeignAssetRegistered: {
            readonly assetId: u128;
            readonly asset: MoonriverRuntimeXcmConfigAssetType;
            readonly metadata: MoonriverRuntimeAssetConfigAssetRegistrarMetadata;
        } & Struct;
        readonly isUnitsPerSecondChanged: boolean;
        readonly asUnitsPerSecondChanged: {
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
            readonly unitsPerSecond: u128;
        } & Struct;
        readonly isForeignAssetTypeChanged: boolean;
        readonly asForeignAssetTypeChanged: {
            readonly assetId: u128;
            readonly newAssetType: MoonriverRuntimeXcmConfigAssetType;
        } & Struct;
        readonly isForeignAssetRemoved: boolean;
        readonly asForeignAssetRemoved: {
            readonly assetId: u128;
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
        } & Struct;
        readonly isSupportedAssetRemoved: boolean;
        readonly asSupportedAssetRemoved: {
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
        } & Struct;
        readonly isLocalAssetRegistered: boolean;
        readonly asLocalAssetRegistered: {
            readonly assetId: u128;
            readonly creator: AccountId20;
            readonly owner: AccountId20;
        } & Struct;
        readonly isForeignAssetDestroyed: boolean;
        readonly asForeignAssetDestroyed: {
            readonly assetId: u128;
            readonly assetType: MoonriverRuntimeXcmConfigAssetType;
        } & Struct;
        readonly isLocalAssetDestroyed: boolean;
        readonly asLocalAssetDestroyed: {
            readonly assetId: u128;
        } & Struct;
        readonly type: "ForeignAssetRegistered" | "UnitsPerSecondChanged" | "ForeignAssetTypeChanged" | "ForeignAssetRemoved" | "SupportedAssetRemoved" | "LocalAssetRegistered" | "ForeignAssetDestroyed" | "LocalAssetDestroyed";
    }
    /** @name OrmlXtokensModuleEvent (330) */
    interface OrmlXtokensModuleEvent extends Enum {
        readonly isTransferredMultiAssets: boolean;
        readonly asTransferredMultiAssets: {
            readonly sender: AccountId20;
            readonly assets: XcmV3MultiassetMultiAssets;
            readonly fee: XcmV3MultiAsset;
            readonly dest: XcmV3MultiLocation;
        } & Struct;
        readonly type: "TransferredMultiAssets";
    }
    /** @name PalletXcmTransactorEvent (331) */
    interface PalletXcmTransactorEvent extends Enum {
        readonly isTransactedDerivative: boolean;
        readonly asTransactedDerivative: {
            readonly accountId: AccountId20;
            readonly dest: XcmV3MultiLocation;
            readonly call: Bytes;
            readonly index: u16;
        } & Struct;
        readonly isTransactedSovereign: boolean;
        readonly asTransactedSovereign: {
            readonly feePayer: AccountId20;
            readonly dest: XcmV3MultiLocation;
            readonly call: Bytes;
        } & Struct;
        readonly isTransactedSigned: boolean;
        readonly asTransactedSigned: {
            readonly feePayer: AccountId20;
            readonly dest: XcmV3MultiLocation;
            readonly call: Bytes;
        } & Struct;
        readonly isRegisteredDerivative: boolean;
        readonly asRegisteredDerivative: {
            readonly accountId: AccountId20;
            readonly index: u16;
        } & Struct;
        readonly isDeRegisteredDerivative: boolean;
        readonly asDeRegisteredDerivative: {
            readonly index: u16;
        } & Struct;
        readonly isTransactFailed: boolean;
        readonly asTransactFailed: {
            readonly error: XcmV3TraitsError;
        } & Struct;
        readonly isTransactInfoChanged: boolean;
        readonly asTransactInfoChanged: {
            readonly location: XcmV3MultiLocation;
            readonly remoteInfo: PalletXcmTransactorRemoteTransactInfoWithMaxWeight;
        } & Struct;
        readonly isTransactInfoRemoved: boolean;
        readonly asTransactInfoRemoved: {
            readonly location: XcmV3MultiLocation;
        } & Struct;
        readonly isDestFeePerSecondChanged: boolean;
        readonly asDestFeePerSecondChanged: {
            readonly location: XcmV3MultiLocation;
            readonly feePerSecond: u128;
        } & Struct;
        readonly isDestFeePerSecondRemoved: boolean;
        readonly asDestFeePerSecondRemoved: {
            readonly location: XcmV3MultiLocation;
        } & Struct;
        readonly isHrmpManagementSent: boolean;
        readonly asHrmpManagementSent: {
            readonly action: PalletXcmTransactorHrmpOperation;
        } & Struct;
        readonly type: "TransactedDerivative" | "TransactedSovereign" | "TransactedSigned" | "RegisteredDerivative" | "DeRegisteredDerivative" | "TransactFailed" | "TransactInfoChanged" | "TransactInfoRemoved" | "DestFeePerSecondChanged" | "DestFeePerSecondRemoved" | "HrmpManagementSent";
    }
    /** @name PalletXcmTransactorRemoteTransactInfoWithMaxWeight (332) */
    interface PalletXcmTransactorRemoteTransactInfoWithMaxWeight extends Struct {
        readonly transactExtraWeight: SpWeightsWeightV2Weight;
        readonly maxWeight: SpWeightsWeightV2Weight;
        readonly transactExtraWeightSigned: Option<SpWeightsWeightV2Weight>;
    }
    /** @name PalletRandomnessEvent (334) */
    interface PalletRandomnessEvent extends Enum {
        readonly isRandomnessRequestedBabeEpoch: boolean;
        readonly asRandomnessRequestedBabeEpoch: {
            readonly id: u64;
            readonly refundAddress: H160;
            readonly contractAddress: H160;
            readonly fee: u128;
            readonly gasLimit: u64;
            readonly numWords: u8;
            readonly salt: H256;
            readonly earliestEpoch: u64;
        } & Struct;
        readonly isRandomnessRequestedLocal: boolean;
        readonly asRandomnessRequestedLocal: {
            readonly id: u64;
            readonly refundAddress: H160;
            readonly contractAddress: H160;
            readonly fee: u128;
            readonly gasLimit: u64;
            readonly numWords: u8;
            readonly salt: H256;
            readonly earliestBlock: u32;
        } & Struct;
        readonly isRequestFulfilled: boolean;
        readonly asRequestFulfilled: {
            readonly id: u64;
        } & Struct;
        readonly isRequestFeeIncreased: boolean;
        readonly asRequestFeeIncreased: {
            readonly id: u64;
            readonly newFee: u128;
        } & Struct;
        readonly isRequestExpirationExecuted: boolean;
        readonly asRequestExpirationExecuted: {
            readonly id: u64;
        } & Struct;
        readonly type: "RandomnessRequestedBabeEpoch" | "RandomnessRequestedLocal" | "RequestFulfilled" | "RequestFeeIncreased" | "RequestExpirationExecuted";
    }
    /** @name FrameSystemPhase (335) */
    interface FrameSystemPhase extends Enum {
        readonly isApplyExtrinsic: boolean;
        readonly asApplyExtrinsic: u32;
        readonly isFinalization: boolean;
        readonly isInitialization: boolean;
        readonly type: "ApplyExtrinsic" | "Finalization" | "Initialization";
    }
    /** @name FrameSystemLastRuntimeUpgradeInfo (337) */
    interface FrameSystemLastRuntimeUpgradeInfo extends Struct {
        readonly specVersion: Compact<u32>;
        readonly specName: Text;
    }
    /** @name FrameSystemLimitsBlockWeights (338) */
    interface FrameSystemLimitsBlockWeights extends Struct {
        readonly baseBlock: SpWeightsWeightV2Weight;
        readonly maxBlock: SpWeightsWeightV2Weight;
        readonly perClass: FrameSupportDispatchPerDispatchClassWeightsPerClass;
    }
    /** @name FrameSupportDispatchPerDispatchClassWeightsPerClass (339) */
    interface FrameSupportDispatchPerDispatchClassWeightsPerClass extends Struct {
        readonly normal: FrameSystemLimitsWeightsPerClass;
        readonly operational: FrameSystemLimitsWeightsPerClass;
        readonly mandatory: FrameSystemLimitsWeightsPerClass;
    }
    /** @name FrameSystemLimitsWeightsPerClass (340) */
    interface FrameSystemLimitsWeightsPerClass extends Struct {
        readonly baseExtrinsic: SpWeightsWeightV2Weight;
        readonly maxExtrinsic: Option<SpWeightsWeightV2Weight>;
        readonly maxTotal: Option<SpWeightsWeightV2Weight>;
        readonly reserved: Option<SpWeightsWeightV2Weight>;
    }
    /** @name FrameSystemLimitsBlockLength (341) */
    interface FrameSystemLimitsBlockLength extends Struct {
        readonly max: FrameSupportDispatchPerDispatchClassU32;
    }
    /** @name FrameSupportDispatchPerDispatchClassU32 (342) */
    interface FrameSupportDispatchPerDispatchClassU32 extends Struct {
        readonly normal: u32;
        readonly operational: u32;
        readonly mandatory: u32;
    }
    /** @name SpWeightsRuntimeDbWeight (343) */
    interface SpWeightsRuntimeDbWeight extends Struct {
        readonly read: u64;
        readonly write: u64;
    }
    /** @name SpVersionRuntimeVersion (344) */
    interface SpVersionRuntimeVersion extends Struct {
        readonly specName: Text;
        readonly implName: Text;
        readonly authoringVersion: u32;
        readonly specVersion: u32;
        readonly implVersion: u32;
        readonly apis: Vec<ITuple<[U8aFixed, u32]>>;
        readonly transactionVersion: u32;
        readonly stateVersion: u8;
    }
    /** @name FrameSystemError (348) */
    interface FrameSystemError extends Enum {
        readonly isInvalidSpecName: boolean;
        readonly isSpecVersionNeedsToIncrease: boolean;
        readonly isFailedToExtractRuntimeVersion: boolean;
        readonly isNonDefaultComposite: boolean;
        readonly isNonZeroRefCount: boolean;
        readonly isCallFiltered: boolean;
        readonly type: "InvalidSpecName" | "SpecVersionNeedsToIncrease" | "FailedToExtractRuntimeVersion" | "NonDefaultComposite" | "NonZeroRefCount" | "CallFiltered";
    }
    /** @name PolkadotPrimitivesV2UpgradeRestriction (350) */
    interface PolkadotPrimitivesV2UpgradeRestriction extends Enum {
        readonly isPresent: boolean;
        readonly type: "Present";
    }
    /** @name CumulusPalletParachainSystemRelayStateSnapshotMessagingStateSnapshot (351) */
    interface CumulusPalletParachainSystemRelayStateSnapshotMessagingStateSnapshot extends Struct {
        readonly dmqMqcHead: H256;
        readonly relayDispatchQueueSize: ITuple<[u32, u32]>;
        readonly ingressChannels: Vec<ITuple<[u32, PolkadotPrimitivesV2AbridgedHrmpChannel]>>;
        readonly egressChannels: Vec<ITuple<[u32, PolkadotPrimitivesV2AbridgedHrmpChannel]>>;
    }
    /** @name PolkadotPrimitivesV2AbridgedHrmpChannel (354) */
    interface PolkadotPrimitivesV2AbridgedHrmpChannel extends Struct {
        readonly maxCapacity: u32;
        readonly maxTotalSize: u32;
        readonly maxMessageSize: u32;
        readonly msgCount: u32;
        readonly totalSize: u32;
        readonly mqcHead: Option<H256>;
    }
    /** @name PolkadotPrimitivesV2AbridgedHostConfiguration (356) */
    interface PolkadotPrimitivesV2AbridgedHostConfiguration extends Struct {
        readonly maxCodeSize: u32;
        readonly maxHeadDataSize: u32;
        readonly maxUpwardQueueCount: u32;
        readonly maxUpwardQueueSize: u32;
        readonly maxUpwardMessageSize: u32;
        readonly maxUpwardMessageNumPerCandidate: u32;
        readonly hrmpMaxMessageNumPerCandidate: u32;
        readonly validationUpgradeCooldown: u32;
        readonly validationUpgradeDelay: u32;
    }
    /** @name PolkadotCorePrimitivesOutboundHrmpMessage (362) */
    interface PolkadotCorePrimitivesOutboundHrmpMessage extends Struct {
        readonly recipient: u32;
        readonly data: Bytes;
    }
    /** @name CumulusPalletParachainSystemError (363) */
    interface CumulusPalletParachainSystemError extends Enum {
        readonly isOverlappingUpgrades: boolean;
        readonly isProhibitedByPolkadot: boolean;
        readonly isTooBig: boolean;
        readonly isValidationDataNotAvailable: boolean;
        readonly isHostConfigurationNotAvailable: boolean;
        readonly isNotScheduled: boolean;
        readonly isNothingAuthorized: boolean;
        readonly isUnauthorized: boolean;
        readonly type: "OverlappingUpgrades" | "ProhibitedByPolkadot" | "TooBig" | "ValidationDataNotAvailable" | "HostConfigurationNotAvailable" | "NotScheduled" | "NothingAuthorized" | "Unauthorized";
    }
    /** @name PalletBalancesBalanceLock (365) */
    interface PalletBalancesBalanceLock extends Struct {
        readonly id: U8aFixed;
        readonly amount: u128;
        readonly reasons: PalletBalancesReasons;
    }
    /** @name PalletBalancesReasons (366) */
    interface PalletBalancesReasons extends Enum {
        readonly isFee: boolean;
        readonly isMisc: boolean;
        readonly isAll: boolean;
        readonly type: "Fee" | "Misc" | "All";
    }
    /** @name PalletBalancesReserveData (369) */
    interface PalletBalancesReserveData extends Struct {
        readonly id: U8aFixed;
        readonly amount: u128;
    }
    /** @name PalletBalancesError (371) */
    interface PalletBalancesError extends Enum {
        readonly isVestingBalance: boolean;
        readonly isLiquidityRestrictions: boolean;
        readonly isInsufficientBalance: boolean;
        readonly isExistentialDeposit: boolean;
        readonly isKeepAlive: boolean;
        readonly isExistingVestingSchedule: boolean;
        readonly isDeadAccount: boolean;
        readonly isTooManyReserves: boolean;
        readonly type: "VestingBalance" | "LiquidityRestrictions" | "InsufficientBalance" | "ExistentialDeposit" | "KeepAlive" | "ExistingVestingSchedule" | "DeadAccount" | "TooManyReserves";
    }
    /** @name PalletTransactionPaymentReleases (373) */
    interface PalletTransactionPaymentReleases extends Enum {
        readonly isV1Ancient: boolean;
        readonly isV2: boolean;
        readonly type: "V1Ancient" | "V2";
    }
    /** @name PalletParachainStakingParachainBondConfig (374) */
    interface PalletParachainStakingParachainBondConfig extends Struct {
        readonly account: AccountId20;
        readonly percent: Percent;
    }
    /** @name PalletParachainStakingRoundInfo (375) */
    interface PalletParachainStakingRoundInfo extends Struct {
        readonly current: u32;
        readonly first: u32;
        readonly length: u32;
    }
    /** @name PalletParachainStakingDelegator (376) */
    interface PalletParachainStakingDelegator extends Struct {
        readonly id: AccountId20;
        readonly delegations: PalletParachainStakingSetOrderedSet;
        readonly total: u128;
        readonly lessTotal: u128;
        readonly status: PalletParachainStakingDelegatorStatus;
    }
    /** @name PalletParachainStakingSetOrderedSet (377) */
    interface PalletParachainStakingSetOrderedSet extends Vec<PalletParachainStakingBond> {
    }
    /** @name PalletParachainStakingBond (378) */
    interface PalletParachainStakingBond extends Struct {
        readonly owner: AccountId20;
        readonly amount: u128;
    }
    /** @name PalletParachainStakingDelegatorStatus (380) */
    interface PalletParachainStakingDelegatorStatus extends Enum {
        readonly isActive: boolean;
        readonly isLeaving: boolean;
        readonly asLeaving: u32;
        readonly type: "Active" | "Leaving";
    }
    /** @name PalletParachainStakingCandidateMetadata (381) */
    interface PalletParachainStakingCandidateMetadata extends Struct {
        readonly bond: u128;
        readonly delegationCount: u32;
        readonly totalCounted: u128;
        readonly lowestTopDelegationAmount: u128;
        readonly highestBottomDelegationAmount: u128;
        readonly lowestBottomDelegationAmount: u128;
        readonly topCapacity: PalletParachainStakingCapacityStatus;
        readonly bottomCapacity: PalletParachainStakingCapacityStatus;
        readonly request: Option<PalletParachainStakingCandidateBondLessRequest>;
        readonly status: PalletParachainStakingCollatorStatus;
    }
    /** @name PalletParachainStakingCapacityStatus (382) */
    interface PalletParachainStakingCapacityStatus extends Enum {
        readonly isFull: boolean;
        readonly isEmpty: boolean;
        readonly isPartial: boolean;
        readonly type: "Full" | "Empty" | "Partial";
    }
    /** @name PalletParachainStakingCandidateBondLessRequest (384) */
    interface PalletParachainStakingCandidateBondLessRequest extends Struct {
        readonly amount: u128;
        readonly whenExecutable: u32;
    }
    /** @name PalletParachainStakingCollatorStatus (385) */
    interface PalletParachainStakingCollatorStatus extends Enum {
        readonly isActive: boolean;
        readonly isIdle: boolean;
        readonly isLeaving: boolean;
        readonly asLeaving: u32;
        readonly type: "Active" | "Idle" | "Leaving";
    }
    /** @name PalletParachainStakingDelegationRequestsScheduledRequest (387) */
    interface PalletParachainStakingDelegationRequestsScheduledRequest extends Struct {
        readonly delegator: AccountId20;
        readonly whenExecutable: u32;
        readonly action: PalletParachainStakingDelegationRequestsDelegationAction;
    }
    /** @name PalletParachainStakingAutoCompoundAutoCompoundConfig (389) */
    interface PalletParachainStakingAutoCompoundAutoCompoundConfig extends Struct {
        readonly delegator: AccountId20;
        readonly value: Percent;
    }
    /** @name PalletParachainStakingDelegations (390) */
    interface PalletParachainStakingDelegations extends Struct {
        readonly delegations: Vec<PalletParachainStakingBond>;
        readonly total: u128;
    }
    /** @name PalletParachainStakingCollatorSnapshot (392) */
    interface PalletParachainStakingCollatorSnapshot extends Struct {
        readonly bond: u128;
        readonly delegations: Vec<PalletParachainStakingBondWithAutoCompound>;
        readonly total: u128;
    }
    /** @name PalletParachainStakingBondWithAutoCompound (394) */
    interface PalletParachainStakingBondWithAutoCompound extends Struct {
        readonly owner: AccountId20;
        readonly amount: u128;
        readonly autoCompound: Percent;
    }
    /** @name PalletParachainStakingDelayedPayout (395) */
    interface PalletParachainStakingDelayedPayout extends Struct {
        readonly roundIssuance: u128;
        readonly totalStakingReward: u128;
        readonly collatorCommission: Perbill;
    }
    /** @name PalletParachainStakingInflationInflationInfo (396) */
    interface PalletParachainStakingInflationInflationInfo extends Struct {
        readonly expect: {
            readonly min: u128;
            readonly ideal: u128;
            readonly max: u128;
        } & Struct;
        readonly annual: {
            readonly min: Perbill;
            readonly ideal: Perbill;
            readonly max: Perbill;
        } & Struct;
        readonly round: {
            readonly min: Perbill;
            readonly ideal: Perbill;
            readonly max: Perbill;
        } & Struct;
    }
    /** @name PalletParachainStakingError (397) */
    interface PalletParachainStakingError extends Enum {
        readonly isDelegatorDNE: boolean;
        readonly isDelegatorDNEinTopNorBottom: boolean;
        readonly isDelegatorDNEInDelegatorSet: boolean;
        readonly isCandidateDNE: boolean;
        readonly isDelegationDNE: boolean;
        readonly isDelegatorExists: boolean;
        readonly isCandidateExists: boolean;
        readonly isCandidateBondBelowMin: boolean;
        readonly isInsufficientBalance: boolean;
        readonly isDelegatorBondBelowMin: boolean;
        readonly isDelegationBelowMin: boolean;
        readonly isAlreadyOffline: boolean;
        readonly isAlreadyActive: boolean;
        readonly isDelegatorAlreadyLeaving: boolean;
        readonly isDelegatorNotLeaving: boolean;
        readonly isDelegatorCannotLeaveYet: boolean;
        readonly isCannotDelegateIfLeaving: boolean;
        readonly isCandidateAlreadyLeaving: boolean;
        readonly isCandidateNotLeaving: boolean;
        readonly isCandidateCannotLeaveYet: boolean;
        readonly isCannotGoOnlineIfLeaving: boolean;
        readonly isExceedMaxDelegationsPerDelegator: boolean;
        readonly isAlreadyDelegatedCandidate: boolean;
        readonly isInvalidSchedule: boolean;
        readonly isCannotSetBelowMin: boolean;
        readonly isRoundLengthMustBeGreaterThanTotalSelectedCollators: boolean;
        readonly isNoWritingSameValue: boolean;
        readonly isTooLowCandidateCountWeightHintJoinCandidates: boolean;
        readonly isTooLowCandidateCountWeightHintCancelLeaveCandidates: boolean;
        readonly isTooLowCandidateCountToLeaveCandidates: boolean;
        readonly isTooLowDelegationCountToDelegate: boolean;
        readonly isTooLowCandidateDelegationCountToDelegate: boolean;
        readonly isTooLowCandidateDelegationCountToLeaveCandidates: boolean;
        readonly isTooLowDelegationCountToLeaveDelegators: boolean;
        readonly isPendingCandidateRequestsDNE: boolean;
        readonly isPendingCandidateRequestAlreadyExists: boolean;
        readonly isPendingCandidateRequestNotDueYet: boolean;
        readonly isPendingDelegationRequestDNE: boolean;
        readonly isPendingDelegationRequestAlreadyExists: boolean;
        readonly isPendingDelegationRequestNotDueYet: boolean;
        readonly isCannotDelegateLessThanOrEqualToLowestBottomWhenFull: boolean;
        readonly isPendingDelegationRevoke: boolean;
        readonly isTooLowDelegationCountToAutoCompound: boolean;
        readonly isTooLowCandidateAutoCompoundingDelegationCountToAutoCompound: boolean;
        readonly isTooLowCandidateAutoCompoundingDelegationCountToDelegate: boolean;
        readonly type: "DelegatorDNE" | "DelegatorDNEinTopNorBottom" | "DelegatorDNEInDelegatorSet" | "CandidateDNE" | "DelegationDNE" | "DelegatorExists" | "CandidateExists" | "CandidateBondBelowMin" | "InsufficientBalance" | "DelegatorBondBelowMin" | "DelegationBelowMin" | "AlreadyOffline" | "AlreadyActive" | "DelegatorAlreadyLeaving" | "DelegatorNotLeaving" | "DelegatorCannotLeaveYet" | "CannotDelegateIfLeaving" | "CandidateAlreadyLeaving" | "CandidateNotLeaving" | "CandidateCannotLeaveYet" | "CannotGoOnlineIfLeaving" | "ExceedMaxDelegationsPerDelegator" | "AlreadyDelegatedCandidate" | "InvalidSchedule" | "CannotSetBelowMin" | "RoundLengthMustBeGreaterThanTotalSelectedCollators" | "NoWritingSameValue" | "TooLowCandidateCountWeightHintJoinCandidates" | "TooLowCandidateCountWeightHintCancelLeaveCandidates" | "TooLowCandidateCountToLeaveCandidates" | "TooLowDelegationCountToDelegate" | "TooLowCandidateDelegationCountToDelegate" | "TooLowCandidateDelegationCountToLeaveCandidates" | "TooLowDelegationCountToLeaveDelegators" | "PendingCandidateRequestsDNE" | "PendingCandidateRequestAlreadyExists" | "PendingCandidateRequestNotDueYet" | "PendingDelegationRequestDNE" | "PendingDelegationRequestAlreadyExists" | "PendingDelegationRequestNotDueYet" | "CannotDelegateLessThanOrEqualToLowestBottomWhenFull" | "PendingDelegationRevoke" | "TooLowDelegationCountToAutoCompound" | "TooLowCandidateAutoCompoundingDelegationCountToAutoCompound" | "TooLowCandidateAutoCompoundingDelegationCountToDelegate";
    }
    /** @name PalletAuthorInherentError (398) */
    interface PalletAuthorInherentError extends Enum {
        readonly isAuthorAlreadySet: boolean;
        readonly isNoAccountId: boolean;
        readonly isCannotBeAuthor: boolean;
        readonly type: "AuthorAlreadySet" | "NoAccountId" | "CannotBeAuthor";
    }
    /** @name PalletAuthorMappingRegistrationInfo (399) */
    interface PalletAuthorMappingRegistrationInfo extends Struct {
        readonly account: AccountId20;
        readonly deposit: u128;
        readonly keys_: SessionKeysPrimitivesVrfVrfCryptoPublic;
    }
    /** @name PalletAuthorMappingError (400) */
    interface PalletAuthorMappingError extends Enum {
        readonly isAssociationNotFound: boolean;
        readonly isNotYourAssociation: boolean;
        readonly isCannotAffordSecurityDeposit: boolean;
        readonly isAlreadyAssociated: boolean;
        readonly isOldAuthorIdNotFound: boolean;
        readonly isWrongKeySize: boolean;
        readonly isDecodeNimbusFailed: boolean;
        readonly isDecodeKeysFailed: boolean;
        readonly type: "AssociationNotFound" | "NotYourAssociation" | "CannotAffordSecurityDeposit" | "AlreadyAssociated" | "OldAuthorIdNotFound" | "WrongKeySize" | "DecodeNimbusFailed" | "DecodeKeysFailed";
    }
    /** @name PalletMoonbeamOrbitersCollatorPoolInfo (401) */
    interface PalletMoonbeamOrbitersCollatorPoolInfo extends Struct {
        readonly orbiters: Vec<AccountId20>;
        readonly maybeCurrentOrbiter: Option<PalletMoonbeamOrbitersCurrentOrbiter>;
        readonly nextOrbiter: u32;
    }
    /** @name PalletMoonbeamOrbitersCurrentOrbiter (403) */
    interface PalletMoonbeamOrbitersCurrentOrbiter extends Struct {
        readonly accountId: AccountId20;
        readonly removed: bool;
    }
    /** @name PalletMoonbeamOrbitersError (404) */
    interface PalletMoonbeamOrbitersError extends Enum {
        readonly isCollatorAlreadyAdded: boolean;
        readonly isCollatorNotFound: boolean;
        readonly isCollatorPoolTooLarge: boolean;
        readonly isCollatorsPoolCountTooLow: boolean;
        readonly isMinOrbiterDepositNotSet: boolean;
        readonly isOrbiterAlreadyInPool: boolean;
        readonly isOrbiterDepositNotFound: boolean;
        readonly isOrbiterNotFound: boolean;
        readonly isOrbiterStillInAPool: boolean;
        readonly type: "CollatorAlreadyAdded" | "CollatorNotFound" | "CollatorPoolTooLarge" | "CollatorsPoolCountTooLow" | "MinOrbiterDepositNotSet" | "OrbiterAlreadyInPool" | "OrbiterDepositNotFound" | "OrbiterNotFound" | "OrbiterStillInAPool";
    }
    /** @name PalletUtilityError (405) */
    interface PalletUtilityError extends Enum {
        readonly isTooManyCalls: boolean;
        readonly type: "TooManyCalls";
    }
    /** @name PalletProxyProxyDefinition (408) */
    interface PalletProxyProxyDefinition extends Struct {
        readonly delegate: AccountId20;
        readonly proxyType: MoonriverRuntimeProxyType;
        readonly delay: u32;
    }
    /** @name PalletProxyAnnouncement (412) */
    interface PalletProxyAnnouncement extends Struct {
        readonly real: AccountId20;
        readonly callHash: H256;
        readonly height: u32;
    }
    /** @name PalletProxyError (414) */
    interface PalletProxyError extends Enum {
        readonly isTooMany: boolean;
        readonly isNotFound: boolean;
        readonly isNotProxy: boolean;
        readonly isUnproxyable: boolean;
        readonly isDuplicate: boolean;
        readonly isNoPermission: boolean;
        readonly isUnannounced: boolean;
        readonly isNoSelfProxy: boolean;
        readonly type: "TooMany" | "NotFound" | "NotProxy" | "Unproxyable" | "Duplicate" | "NoPermission" | "Unannounced" | "NoSelfProxy";
    }
    /** @name PalletMaintenanceModeError (415) */
    interface PalletMaintenanceModeError extends Enum {
        readonly isAlreadyInMaintenanceMode: boolean;
        readonly isNotInMaintenanceMode: boolean;
        readonly type: "AlreadyInMaintenanceMode" | "NotInMaintenanceMode";
    }
    /** @name PalletIdentityRegistration (416) */
    interface PalletIdentityRegistration extends Struct {
        readonly judgements: Vec<ITuple<[u32, PalletIdentityJudgement]>>;
        readonly deposit: u128;
        readonly info: PalletIdentityIdentityInfo;
    }
    /** @name PalletIdentityRegistrarInfo (424) */
    interface PalletIdentityRegistrarInfo extends Struct {
        readonly account: AccountId20;
        readonly fee: u128;
        readonly fields: PalletIdentityBitFlags;
    }
    /** @name PalletIdentityError (426) */
    interface PalletIdentityError extends Enum {
        readonly isTooManySubAccounts: boolean;
        readonly isNotFound: boolean;
        readonly isNotNamed: boolean;
        readonly isEmptyIndex: boolean;
        readonly isFeeChanged: boolean;
        readonly isNoIdentity: boolean;
        readonly isStickyJudgement: boolean;
        readonly isJudgementGiven: boolean;
        readonly isInvalidJudgement: boolean;
        readonly isInvalidIndex: boolean;
        readonly isInvalidTarget: boolean;
        readonly isTooManyFields: boolean;
        readonly isTooManyRegistrars: boolean;
        readonly isAlreadyClaimed: boolean;
        readonly isNotSub: boolean;
        readonly isNotOwned: boolean;
        readonly isJudgementForDifferentIdentity: boolean;
        readonly isJudgementPaymentFailed: boolean;
        readonly type: "TooManySubAccounts" | "NotFound" | "NotNamed" | "EmptyIndex" | "FeeChanged" | "NoIdentity" | "StickyJudgement" | "JudgementGiven" | "InvalidJudgement" | "InvalidIndex" | "InvalidTarget" | "TooManyFields" | "TooManyRegistrars" | "AlreadyClaimed" | "NotSub" | "NotOwned" | "JudgementForDifferentIdentity" | "JudgementPaymentFailed";
    }
    /** @name PalletMigrationsError (427) */
    interface PalletMigrationsError extends Enum {
        readonly isPreimageMissing: boolean;
        readonly isWrongUpperBound: boolean;
        readonly isPreimageIsTooBig: boolean;
        readonly isPreimageAlreadyExists: boolean;
        readonly type: "PreimageMissing" | "WrongUpperBound" | "PreimageIsTooBig" | "PreimageAlreadyExists";
    }
    /** @name PalletEvmError (429) */
    interface PalletEvmError extends Enum {
        readonly isBalanceLow: boolean;
        readonly isFeeOverflow: boolean;
        readonly isPaymentOverflow: boolean;
        readonly isWithdrawFailed: boolean;
        readonly isGasPriceTooLow: boolean;
        readonly isInvalidNonce: boolean;
        readonly isGasLimitTooLow: boolean;
        readonly isGasLimitTooHigh: boolean;
        readonly isUndefined: boolean;
        readonly isReentrancy: boolean;
        readonly isTransactionMustComeFromEOA: boolean;
        readonly type: "BalanceLow" | "FeeOverflow" | "PaymentOverflow" | "WithdrawFailed" | "GasPriceTooLow" | "InvalidNonce" | "GasLimitTooLow" | "GasLimitTooHigh" | "Undefined" | "Reentrancy" | "TransactionMustComeFromEOA";
    }
    /** @name FpRpcTransactionStatus (432) */
    interface FpRpcTransactionStatus extends Struct {
        readonly transactionHash: H256;
        readonly transactionIndex: u32;
        readonly from: H160;
        readonly to: Option<H160>;
        readonly contractAddress: Option<H160>;
        readonly logs: Vec<EthereumLog>;
        readonly logsBloom: EthbloomBloom;
    }
    /** @name EthbloomBloom (435) */
    interface EthbloomBloom extends U8aFixed {
    }
    /** @name EthereumReceiptReceiptV3 (437) */
    interface EthereumReceiptReceiptV3 extends Enum {
        readonly isLegacy: boolean;
        readonly asLegacy: EthereumReceiptEip658ReceiptData;
        readonly isEip2930: boolean;
        readonly asEip2930: EthereumReceiptEip658ReceiptData;
        readonly isEip1559: boolean;
        readonly asEip1559: EthereumReceiptEip658ReceiptData;
        readonly type: "Legacy" | "Eip2930" | "Eip1559";
    }
    /** @name EthereumReceiptEip658ReceiptData (438) */
    interface EthereumReceiptEip658ReceiptData extends Struct {
        readonly statusCode: u8;
        readonly usedGas: U256;
        readonly logsBloom: EthbloomBloom;
        readonly logs: Vec<EthereumLog>;
    }
    /** @name EthereumBlock (439) */
    interface EthereumBlock extends Struct {
        readonly header: EthereumHeader;
        readonly transactions: Vec<EthereumTransactionTransactionV2>;
        readonly ommers: Vec<EthereumHeader>;
    }
    /** @name EthereumHeader (440) */
    interface EthereumHeader extends Struct {
        readonly parentHash: H256;
        readonly ommersHash: H256;
        readonly beneficiary: H160;
        readonly stateRoot: H256;
        readonly transactionsRoot: H256;
        readonly receiptsRoot: H256;
        readonly logsBloom: EthbloomBloom;
        readonly difficulty: U256;
        readonly number: U256;
        readonly gasLimit: U256;
        readonly gasUsed: U256;
        readonly timestamp: u64;
        readonly extraData: Bytes;
        readonly mixHash: H256;
        readonly nonce: EthereumTypesHashH64;
    }
    /** @name EthereumTypesHashH64 (441) */
    interface EthereumTypesHashH64 extends U8aFixed {
    }
    /** @name PalletEthereumError (446) */
    interface PalletEthereumError extends Enum {
        readonly isInvalidSignature: boolean;
        readonly isPreLogExists: boolean;
        readonly type: "InvalidSignature" | "PreLogExists";
    }
    /** @name PalletSchedulerScheduled (449) */
    interface PalletSchedulerScheduled extends Struct {
        readonly maybeId: Option<U8aFixed>;
        readonly priority: u8;
        readonly call: FrameSupportPreimagesBounded;
        readonly maybePeriodic: Option<ITuple<[u32, u32]>>;
        readonly origin: MoonriverRuntimeOriginCaller;
    }
    /** @name PalletSchedulerError (451) */
    interface PalletSchedulerError extends Enum {
        readonly isFailedToSchedule: boolean;
        readonly isNotFound: boolean;
        readonly isTargetBlockNumberInPast: boolean;
        readonly isRescheduleNoChange: boolean;
        readonly isNamed: boolean;
        readonly type: "FailedToSchedule" | "NotFound" | "TargetBlockNumberInPast" | "RescheduleNoChange" | "Named";
    }
    /** @name PalletDemocracyReferendumInfo (456) */
    interface PalletDemocracyReferendumInfo extends Enum {
        readonly isOngoing: boolean;
        readonly asOngoing: PalletDemocracyReferendumStatus;
        readonly isFinished: boolean;
        readonly asFinished: {
            readonly approved: bool;
            readonly end: u32;
        } & Struct;
        readonly type: "Ongoing" | "Finished";
    }
    /** @name PalletDemocracyReferendumStatus (457) */
    interface PalletDemocracyReferendumStatus extends Struct {
        readonly end: u32;
        readonly proposal: FrameSupportPreimagesBounded;
        readonly threshold: PalletDemocracyVoteThreshold;
        readonly delay: u32;
        readonly tally: PalletDemocracyTally;
    }
    /** @name PalletDemocracyTally (458) */
    interface PalletDemocracyTally extends Struct {
        readonly ayes: u128;
        readonly nays: u128;
        readonly turnout: u128;
    }
    /** @name PalletDemocracyVoteVoting (459) */
    interface PalletDemocracyVoteVoting extends Enum {
        readonly isDirect: boolean;
        readonly asDirect: {
            readonly votes: Vec<ITuple<[u32, PalletDemocracyVoteAccountVote]>>;
            readonly delegations: PalletDemocracyDelegations;
            readonly prior: PalletDemocracyVotePriorLock;
        } & Struct;
        readonly isDelegating: boolean;
        readonly asDelegating: {
            readonly balance: u128;
            readonly target: AccountId20;
            readonly conviction: PalletDemocracyConviction;
            readonly delegations: PalletDemocracyDelegations;
            readonly prior: PalletDemocracyVotePriorLock;
        } & Struct;
        readonly type: "Direct" | "Delegating";
    }
    /** @name PalletDemocracyDelegations (463) */
    interface PalletDemocracyDelegations extends Struct {
        readonly votes: u128;
        readonly capital: u128;
    }
    /** @name PalletDemocracyVotePriorLock (464) */
    interface PalletDemocracyVotePriorLock extends ITuple<[u32, u128]> {
    }
    /** @name PalletDemocracyError (467) */
    interface PalletDemocracyError extends Enum {
        readonly isValueLow: boolean;
        readonly isProposalMissing: boolean;
        readonly isAlreadyCanceled: boolean;
        readonly isDuplicateProposal: boolean;
        readonly isProposalBlacklisted: boolean;
        readonly isNotSimpleMajority: boolean;
        readonly isInvalidHash: boolean;
        readonly isNoProposal: boolean;
        readonly isAlreadyVetoed: boolean;
        readonly isReferendumInvalid: boolean;
        readonly isNoneWaiting: boolean;
        readonly isNotVoter: boolean;
        readonly isNoPermission: boolean;
        readonly isAlreadyDelegating: boolean;
        readonly isInsufficientFunds: boolean;
        readonly isNotDelegating: boolean;
        readonly isVotesExist: boolean;
        readonly isInstantNotAllowed: boolean;
        readonly isNonsense: boolean;
        readonly isWrongUpperBound: boolean;
        readonly isMaxVotesReached: boolean;
        readonly isTooMany: boolean;
        readonly isVotingPeriodLow: boolean;
        readonly type: "ValueLow" | "ProposalMissing" | "AlreadyCanceled" | "DuplicateProposal" | "ProposalBlacklisted" | "NotSimpleMajority" | "InvalidHash" | "NoProposal" | "AlreadyVetoed" | "ReferendumInvalid" | "NoneWaiting" | "NotVoter" | "NoPermission" | "AlreadyDelegating" | "InsufficientFunds" | "NotDelegating" | "VotesExist" | "InstantNotAllowed" | "Nonsense" | "WrongUpperBound" | "MaxVotesReached" | "TooMany" | "VotingPeriodLow";
    }
    /** @name PalletPreimageRequestStatus (468) */
    interface PalletPreimageRequestStatus extends Enum {
        readonly isUnrequested: boolean;
        readonly asUnrequested: {
            readonly deposit: ITuple<[AccountId20, u128]>;
            readonly len: u32;
        } & Struct;
        readonly isRequested: boolean;
        readonly asRequested: {
            readonly deposit: Option<ITuple<[AccountId20, u128]>>;
            readonly count: u32;
            readonly len: Option<u32>;
        } & Struct;
        readonly type: "Unrequested" | "Requested";
    }
    /** @name PalletPreimageError (473) */
    interface PalletPreimageError extends Enum {
        readonly isTooBig: boolean;
        readonly isAlreadyNoted: boolean;
        readonly isNotAuthorized: boolean;
        readonly isNotNoted: boolean;
        readonly isRequested: boolean;
        readonly isNotRequested: boolean;
        readonly type: "TooBig" | "AlreadyNoted" | "NotAuthorized" | "NotNoted" | "Requested" | "NotRequested";
    }
    /** @name PalletConvictionVotingVoteVoting (475) */
    interface PalletConvictionVotingVoteVoting extends Enum {
        readonly isCasting: boolean;
        readonly asCasting: PalletConvictionVotingVoteCasting;
        readonly isDelegating: boolean;
        readonly asDelegating: PalletConvictionVotingVoteDelegating;
        readonly type: "Casting" | "Delegating";
    }
    /** @name PalletConvictionVotingVoteCasting (476) */
    interface PalletConvictionVotingVoteCasting extends Struct {
        readonly votes: Vec<ITuple<[u32, PalletConvictionVotingVoteAccountVote]>>;
        readonly delegations: PalletConvictionVotingDelegations;
        readonly prior: PalletConvictionVotingVotePriorLock;
    }
    /** @name PalletConvictionVotingDelegations (480) */
    interface PalletConvictionVotingDelegations extends Struct {
        readonly votes: u128;
        readonly capital: u128;
    }
    /** @name PalletConvictionVotingVotePriorLock (481) */
    interface PalletConvictionVotingVotePriorLock extends ITuple<[u32, u128]> {
    }
    /** @name PalletConvictionVotingVoteDelegating (482) */
    interface PalletConvictionVotingVoteDelegating extends Struct {
        readonly balance: u128;
        readonly target: AccountId20;
        readonly conviction: PalletConvictionVotingConviction;
        readonly delegations: PalletConvictionVotingDelegations;
        readonly prior: PalletConvictionVotingVotePriorLock;
    }
    /** @name PalletConvictionVotingError (486) */
    interface PalletConvictionVotingError extends Enum {
        readonly isNotOngoing: boolean;
        readonly isNotVoter: boolean;
        readonly isNoPermission: boolean;
        readonly isNoPermissionYet: boolean;
        readonly isAlreadyDelegating: boolean;
        readonly isAlreadyVoting: boolean;
        readonly isInsufficientFunds: boolean;
        readonly isNotDelegating: boolean;
        readonly isNonsense: boolean;
        readonly isMaxVotesReached: boolean;
        readonly isClassNeeded: boolean;
        readonly isBadClass: boolean;
        readonly type: "NotOngoing" | "NotVoter" | "NoPermission" | "NoPermissionYet" | "AlreadyDelegating" | "AlreadyVoting" | "InsufficientFunds" | "NotDelegating" | "Nonsense" | "MaxVotesReached" | "ClassNeeded" | "BadClass";
    }
    /** @name PalletReferendaReferendumInfo (487) */
    interface PalletReferendaReferendumInfo extends Enum {
        readonly isOngoing: boolean;
        readonly asOngoing: PalletReferendaReferendumStatus;
        readonly isApproved: boolean;
        readonly asApproved: ITuple<[
            u32,
            Option<PalletReferendaDeposit>,
            Option<PalletReferendaDeposit>
        ]>;
        readonly isRejected: boolean;
        readonly asRejected: ITuple<[
            u32,
            Option<PalletReferendaDeposit>,
            Option<PalletReferendaDeposit>
        ]>;
        readonly isCancelled: boolean;
        readonly asCancelled: ITuple<[
            u32,
            Option<PalletReferendaDeposit>,
            Option<PalletReferendaDeposit>
        ]>;
        readonly isTimedOut: boolean;
        readonly asTimedOut: ITuple<[
            u32,
            Option<PalletReferendaDeposit>,
            Option<PalletReferendaDeposit>
        ]>;
        readonly isKilled: boolean;
        readonly asKilled: u32;
        readonly type: "Ongoing" | "Approved" | "Rejected" | "Cancelled" | "TimedOut" | "Killed";
    }
    /** @name PalletReferendaReferendumStatus (488) */
    interface PalletReferendaReferendumStatus extends Struct {
        readonly track: u16;
        readonly origin: MoonriverRuntimeOriginCaller;
        readonly proposal: FrameSupportPreimagesBounded;
        readonly enactment: FrameSupportScheduleDispatchTime;
        readonly submitted: u32;
        readonly submissionDeposit: PalletReferendaDeposit;
        readonly decisionDeposit: Option<PalletReferendaDeposit>;
        readonly deciding: Option<PalletReferendaDecidingStatus>;
        readonly tally: PalletConvictionVotingTally;
        readonly inQueue: bool;
        readonly alarm: Option<ITuple<[u32, ITuple<[u32, u32]>]>>;
    }
    /** @name PalletReferendaDeposit (489) */
    interface PalletReferendaDeposit extends Struct {
        readonly who: AccountId20;
        readonly amount: u128;
    }
    /** @name PalletReferendaDecidingStatus (492) */
    interface PalletReferendaDecidingStatus extends Struct {
        readonly since: u32;
        readonly confirming: Option<u32>;
    }
    /** @name PalletReferendaTrackInfo (500) */
    interface PalletReferendaTrackInfo extends Struct {
        readonly name: Text;
        readonly maxDeciding: u32;
        readonly decisionDeposit: u128;
        readonly preparePeriod: u32;
        readonly decisionPeriod: u32;
        readonly confirmPeriod: u32;
        readonly minEnactmentPeriod: u32;
        readonly minApproval: PalletReferendaCurve;
        readonly minSupport: PalletReferendaCurve;
    }
    /** @name PalletReferendaCurve (501) */
    interface PalletReferendaCurve extends Enum {
        readonly isLinearDecreasing: boolean;
        readonly asLinearDecreasing: {
            readonly length: Perbill;
            readonly floor: Perbill;
            readonly ceil: Perbill;
        } & Struct;
        readonly isSteppedDecreasing: boolean;
        readonly asSteppedDecreasing: {
            readonly begin: Perbill;
            readonly end: Perbill;
            readonly step: Perbill;
            readonly period: Perbill;
        } & Struct;
        readonly isReciprocal: boolean;
        readonly asReciprocal: {
            readonly factor: i64;
            readonly xOffset: i64;
            readonly yOffset: i64;
        } & Struct;
        readonly type: "LinearDecreasing" | "SteppedDecreasing" | "Reciprocal";
    }
    /** @name PalletReferendaError (504) */
    interface PalletReferendaError extends Enum {
        readonly isNotOngoing: boolean;
        readonly isHasDeposit: boolean;
        readonly isBadTrack: boolean;
        readonly isFull: boolean;
        readonly isQueueEmpty: boolean;
        readonly isBadReferendum: boolean;
        readonly isNothingToDo: boolean;
        readonly isNoTrack: boolean;
        readonly isUnfinished: boolean;
        readonly isNoPermission: boolean;
        readonly isNoDeposit: boolean;
        readonly isBadStatus: boolean;
        readonly type: "NotOngoing" | "HasDeposit" | "BadTrack" | "Full" | "QueueEmpty" | "BadReferendum" | "NothingToDo" | "NoTrack" | "Unfinished" | "NoPermission" | "NoDeposit" | "BadStatus";
    }
    /** @name PalletWhitelistError (505) */
    interface PalletWhitelistError extends Enum {
        readonly isUnavailablePreImage: boolean;
        readonly isUndecodableCall: boolean;
        readonly isInvalidCallWeightWitness: boolean;
        readonly isCallIsNotWhitelisted: boolean;
        readonly isCallAlreadyWhitelisted: boolean;
        readonly type: "UnavailablePreImage" | "UndecodableCall" | "InvalidCallWeightWitness" | "CallIsNotWhitelisted" | "CallAlreadyWhitelisted";
    }
    /** @name PalletCollectiveVotes (507) */
    interface PalletCollectiveVotes extends Struct {
        readonly index: u32;
        readonly threshold: u32;
        readonly ayes: Vec<AccountId20>;
        readonly nays: Vec<AccountId20>;
        readonly end: u32;
    }
    /** @name PalletCollectiveError (508) */
    interface PalletCollectiveError extends Enum {
        readonly isNotMember: boolean;
        readonly isDuplicateProposal: boolean;
        readonly isProposalMissing: boolean;
        readonly isWrongIndex: boolean;
        readonly isDuplicateVote: boolean;
        readonly isAlreadyInitialized: boolean;
        readonly isTooEarly: boolean;
        readonly isTooManyProposals: boolean;
        readonly isWrongProposalWeight: boolean;
        readonly isWrongProposalLength: boolean;
        readonly type: "NotMember" | "DuplicateProposal" | "ProposalMissing" | "WrongIndex" | "DuplicateVote" | "AlreadyInitialized" | "TooEarly" | "TooManyProposals" | "WrongProposalWeight" | "WrongProposalLength";
    }
    /** @name PalletTreasuryProposal (513) */
    interface PalletTreasuryProposal extends Struct {
        readonly proposer: AccountId20;
        readonly value: u128;
        readonly beneficiary: AccountId20;
        readonly bond: u128;
    }
    /** @name FrameSupportPalletId (517) */
    interface FrameSupportPalletId extends U8aFixed {
    }
    /** @name PalletTreasuryError (518) */
    interface PalletTreasuryError extends Enum {
        readonly isInsufficientProposersBalance: boolean;
        readonly isInvalidIndex: boolean;
        readonly isTooManyApprovals: boolean;
        readonly isInsufficientPermission: boolean;
        readonly isProposalNotApproved: boolean;
        readonly type: "InsufficientProposersBalance" | "InvalidIndex" | "TooManyApprovals" | "InsufficientPermission" | "ProposalNotApproved";
    }
    /** @name PalletCrowdloanRewardsRewardInfo (519) */
    interface PalletCrowdloanRewardsRewardInfo extends Struct {
        readonly totalReward: u128;
        readonly claimedReward: u128;
        readonly contributedRelayAddresses: Vec<U8aFixed>;
    }
    /** @name PalletCrowdloanRewardsError (521) */
    interface PalletCrowdloanRewardsError extends Enum {
        readonly isAlreadyAssociated: boolean;
        readonly isBatchBeyondFundPot: boolean;
        readonly isFirstClaimAlreadyDone: boolean;
        readonly isRewardNotHighEnough: boolean;
        readonly isInvalidClaimSignature: boolean;
        readonly isInvalidFreeClaimSignature: boolean;
        readonly isNoAssociatedClaim: boolean;
        readonly isRewardsAlreadyClaimed: boolean;
        readonly isRewardVecAlreadyInitialized: boolean;
        readonly isRewardVecNotFullyInitializedYet: boolean;
        readonly isRewardsDoNotMatchFund: boolean;
        readonly isTooManyContributors: boolean;
        readonly isVestingPeriodNonValid: boolean;
        readonly isNonContributedAddressProvided: boolean;
        readonly isInsufficientNumberOfValidProofs: boolean;
        readonly type: "AlreadyAssociated" | "BatchBeyondFundPot" | "FirstClaimAlreadyDone" | "RewardNotHighEnough" | "InvalidClaimSignature" | "InvalidFreeClaimSignature" | "NoAssociatedClaim" | "RewardsAlreadyClaimed" | "RewardVecAlreadyInitialized" | "RewardVecNotFullyInitializedYet" | "RewardsDoNotMatchFund" | "TooManyContributors" | "VestingPeriodNonValid" | "NonContributedAddressProvided" | "InsufficientNumberOfValidProofs";
    }
    /** @name CumulusPalletXcmpQueueInboundChannelDetails (523) */
    interface CumulusPalletXcmpQueueInboundChannelDetails extends Struct {
        readonly sender: u32;
        readonly state: CumulusPalletXcmpQueueInboundState;
        readonly messageMetadata: Vec<ITuple<[u32, PolkadotParachainPrimitivesXcmpMessageFormat]>>;
    }
    /** @name CumulusPalletXcmpQueueInboundState (524) */
    interface CumulusPalletXcmpQueueInboundState extends Enum {
        readonly isOk: boolean;
        readonly isSuspended: boolean;
        readonly type: "Ok" | "Suspended";
    }
    /** @name PolkadotParachainPrimitivesXcmpMessageFormat (527) */
    interface PolkadotParachainPrimitivesXcmpMessageFormat extends Enum {
        readonly isConcatenatedVersionedXcm: boolean;
        readonly isConcatenatedEncodedBlob: boolean;
        readonly isSignals: boolean;
        readonly type: "ConcatenatedVersionedXcm" | "ConcatenatedEncodedBlob" | "Signals";
    }
    /** @name CumulusPalletXcmpQueueOutboundChannelDetails (530) */
    interface CumulusPalletXcmpQueueOutboundChannelDetails extends Struct {
        readonly recipient: u32;
        readonly state: CumulusPalletXcmpQueueOutboundState;
        readonly signalsExist: bool;
        readonly firstIndex: u16;
        readonly lastIndex: u16;
    }
    /** @name CumulusPalletXcmpQueueOutboundState (531) */
    interface CumulusPalletXcmpQueueOutboundState extends Enum {
        readonly isOk: boolean;
        readonly isSuspended: boolean;
        readonly type: "Ok" | "Suspended";
    }
    /** @name CumulusPalletXcmpQueueQueueConfigData (533) */
    interface CumulusPalletXcmpQueueQueueConfigData extends Struct {
        readonly suspendThreshold: u32;
        readonly dropThreshold: u32;
        readonly resumeThreshold: u32;
        readonly thresholdWeight: SpWeightsWeightV2Weight;
        readonly weightRestrictDecay: SpWeightsWeightV2Weight;
        readonly xcmpMaxIndividualWeight: SpWeightsWeightV2Weight;
    }
    /** @name CumulusPalletXcmpQueueError (535) */
    interface CumulusPalletXcmpQueueError extends Enum {
        readonly isFailedToSend: boolean;
        readonly isBadXcmOrigin: boolean;
        readonly isBadXcm: boolean;
        readonly isBadOverweightIndex: boolean;
        readonly isWeightOverLimit: boolean;
        readonly type: "FailedToSend" | "BadXcmOrigin" | "BadXcm" | "BadOverweightIndex" | "WeightOverLimit";
    }
    /** @name CumulusPalletXcmError (536) */
    type CumulusPalletXcmError = Null;
    /** @name CumulusPalletDmpQueueConfigData (537) */
    interface CumulusPalletDmpQueueConfigData extends Struct {
        readonly maxIndividual: SpWeightsWeightV2Weight;
    }
    /** @name CumulusPalletDmpQueuePageIndexData (538) */
    interface CumulusPalletDmpQueuePageIndexData extends Struct {
        readonly beginUsed: u32;
        readonly endUsed: u32;
        readonly overweightCount: u64;
    }
    /** @name CumulusPalletDmpQueueError (541) */
    interface CumulusPalletDmpQueueError extends Enum {
        readonly isUnknown: boolean;
        readonly isOverLimit: boolean;
        readonly type: "Unknown" | "OverLimit";
    }
    /** @name PalletXcmQueryStatus (542) */
    interface PalletXcmQueryStatus extends Enum {
        readonly isPending: boolean;
        readonly asPending: {
            readonly responder: XcmVersionedMultiLocation;
            readonly maybeMatchQuerier: Option<XcmVersionedMultiLocation>;
            readonly maybeNotify: Option<ITuple<[u8, u8]>>;
            readonly timeout: u32;
        } & Struct;
        readonly isVersionNotifier: boolean;
        readonly asVersionNotifier: {
            readonly origin: XcmVersionedMultiLocation;
            readonly isActive: bool;
        } & Struct;
        readonly isReady: boolean;
        readonly asReady: {
            readonly response: XcmVersionedResponse;
            readonly at: u32;
        } & Struct;
        readonly type: "Pending" | "VersionNotifier" | "Ready";
    }
    /** @name XcmVersionedResponse (546) */
    interface XcmVersionedResponse extends Enum {
        readonly isV2: boolean;
        readonly asV2: XcmV2Response;
        readonly isV3: boolean;
        readonly asV3: XcmV3Response;
        readonly type: "V2" | "V3";
    }
    /** @name PalletXcmVersionMigrationStage (552) */
    interface PalletXcmVersionMigrationStage extends Enum {
        readonly isMigrateSupportedVersion: boolean;
        readonly isMigrateVersionNotifiers: boolean;
        readonly isNotifyCurrentTargets: boolean;
        readonly asNotifyCurrentTargets: Option<Bytes>;
        readonly isMigrateAndNotifyOldTargets: boolean;
        readonly type: "MigrateSupportedVersion" | "MigrateVersionNotifiers" | "NotifyCurrentTargets" | "MigrateAndNotifyOldTargets";
    }
    /** @name XcmVersionedAssetId (555) */
    interface XcmVersionedAssetId extends Enum {
        readonly isV3: boolean;
        readonly asV3: XcmV3MultiassetAssetId;
        readonly type: "V3";
    }
    /** @name PalletXcmRemoteLockedFungibleRecord (556) */
    interface PalletXcmRemoteLockedFungibleRecord extends Struct {
        readonly amount: u128;
        readonly owner: XcmVersionedMultiLocation;
        readonly locker: XcmVersionedMultiLocation;
        readonly users: u32;
    }
    /** @name PalletXcmError (560) */
    interface PalletXcmError extends Enum {
        readonly isUnreachable: boolean;
        readonly isSendFailure: boolean;
        readonly isFiltered: boolean;
        readonly isUnweighableMessage: boolean;
        readonly isDestinationNotInvertible: boolean;
        readonly isEmpty: boolean;
        readonly isCannotReanchor: boolean;
        readonly isTooManyAssets: boolean;
        readonly isInvalidOrigin: boolean;
        readonly isBadVersion: boolean;
        readonly isBadLocation: boolean;
        readonly isNoSubscription: boolean;
        readonly isAlreadySubscribed: boolean;
        readonly isInvalidAsset: boolean;
        readonly isLowBalance: boolean;
        readonly isTooManyLocks: boolean;
        readonly isAccountNotSovereign: boolean;
        readonly isFeesNotMet: boolean;
        readonly isLockNotFound: boolean;
        readonly isInUse: boolean;
        readonly type: "Unreachable" | "SendFailure" | "Filtered" | "UnweighableMessage" | "DestinationNotInvertible" | "Empty" | "CannotReanchor" | "TooManyAssets" | "InvalidOrigin" | "BadVersion" | "BadLocation" | "NoSubscription" | "AlreadySubscribed" | "InvalidAsset" | "LowBalance" | "TooManyLocks" | "AccountNotSovereign" | "FeesNotMet" | "LockNotFound" | "InUse";
    }
    /** @name PalletAssetsAssetDetails (561) */
    interface PalletAssetsAssetDetails extends Struct {
        readonly owner: AccountId20;
        readonly issuer: AccountId20;
        readonly admin: AccountId20;
        readonly freezer: AccountId20;
        readonly supply: u128;
        readonly deposit: u128;
        readonly minBalance: u128;
        readonly isSufficient: bool;
        readonly accounts: u32;
        readonly sufficients: u32;
        readonly approvals: u32;
        readonly status: PalletAssetsAssetStatus;
    }
    /** @name PalletAssetsAssetStatus (562) */
    interface PalletAssetsAssetStatus extends Enum {
        readonly isLive: boolean;
        readonly isFrozen: boolean;
        readonly isDestroying: boolean;
        readonly type: "Live" | "Frozen" | "Destroying";
    }
    /** @name PalletAssetsAssetAccount (564) */
    interface PalletAssetsAssetAccount extends Struct {
        readonly balance: u128;
        readonly isFrozen: bool;
        readonly reason: PalletAssetsExistenceReason;
        readonly extra: Null;
    }
    /** @name PalletAssetsExistenceReason (565) */
    interface PalletAssetsExistenceReason extends Enum {
        readonly isConsumer: boolean;
        readonly isSufficient: boolean;
        readonly isDepositHeld: boolean;
        readonly asDepositHeld: u128;
        readonly isDepositRefunded: boolean;
        readonly type: "Consumer" | "Sufficient" | "DepositHeld" | "DepositRefunded";
    }
    /** @name PalletAssetsApproval (567) */
    interface PalletAssetsApproval extends Struct {
        readonly amount: u128;
        readonly deposit: u128;
    }
    /** @name PalletAssetsAssetMetadata (568) */
    interface PalletAssetsAssetMetadata extends Struct {
        readonly deposit: u128;
        readonly name: Bytes;
        readonly symbol: Bytes;
        readonly decimals: u8;
        readonly isFrozen: bool;
    }
    /** @name PalletAssetsError (570) */
    interface PalletAssetsError extends Enum {
        readonly isBalanceLow: boolean;
        readonly isNoAccount: boolean;
        readonly isNoPermission: boolean;
        readonly isUnknown: boolean;
        readonly isFrozen: boolean;
        readonly isInUse: boolean;
        readonly isBadWitness: boolean;
        readonly isMinBalanceZero: boolean;
        readonly isNoProvider: boolean;
        readonly isBadMetadata: boolean;
        readonly isUnapproved: boolean;
        readonly isWouldDie: boolean;
        readonly isAlreadyExists: boolean;
        readonly isNoDeposit: boolean;
        readonly isWouldBurn: boolean;
        readonly isLiveAsset: boolean;
        readonly isAssetNotLive: boolean;
        readonly isIncorrectStatus: boolean;
        readonly isNotFrozen: boolean;
        readonly type: "BalanceLow" | "NoAccount" | "NoPermission" | "Unknown" | "Frozen" | "InUse" | "BadWitness" | "MinBalanceZero" | "NoProvider" | "BadMetadata" | "Unapproved" | "WouldDie" | "AlreadyExists" | "NoDeposit" | "WouldBurn" | "LiveAsset" | "AssetNotLive" | "IncorrectStatus" | "NotFrozen";
    }
    /** @name PalletAssetManagerAssetInfo (571) */
    interface PalletAssetManagerAssetInfo extends Struct {
        readonly creator: AccountId20;
        readonly deposit: u128;
    }
    /** @name PalletAssetManagerError (573) */
    interface PalletAssetManagerError extends Enum {
        readonly isErrorCreatingAsset: boolean;
        readonly isAssetAlreadyExists: boolean;
        readonly isAssetDoesNotExist: boolean;
        readonly isTooLowNumAssetsWeightHint: boolean;
        readonly isLocalAssetLimitReached: boolean;
        readonly isErrorDestroyingAsset: boolean;
        readonly isNotSufficientDeposit: boolean;
        readonly isNonExistentLocalAsset: boolean;
        readonly type: "ErrorCreatingAsset" | "AssetAlreadyExists" | "AssetDoesNotExist" | "TooLowNumAssetsWeightHint" | "LocalAssetLimitReached" | "ErrorDestroyingAsset" | "NotSufficientDeposit" | "NonExistentLocalAsset";
    }
    /** @name OrmlXtokensModuleError (574) */
    interface OrmlXtokensModuleError extends Enum {
        readonly isAssetHasNoReserve: boolean;
        readonly isNotCrossChainTransfer: boolean;
        readonly isInvalidDest: boolean;
        readonly isNotCrossChainTransferableCurrency: boolean;
        readonly isUnweighableMessage: boolean;
        readonly isXcmExecutionFailed: boolean;
        readonly isCannotReanchor: boolean;
        readonly isInvalidAncestry: boolean;
        readonly isInvalidAsset: boolean;
        readonly isDestinationNotInvertible: boolean;
        readonly isBadVersion: boolean;
        readonly isDistinctReserveForAssetAndFee: boolean;
        readonly isZeroFee: boolean;
        readonly isZeroAmount: boolean;
        readonly isTooManyAssetsBeingSent: boolean;
        readonly isAssetIndexNonExistent: boolean;
        readonly isFeeNotEnough: boolean;
        readonly isNotSupportedMultiLocation: boolean;
        readonly isMinXcmFeeNotDefined: boolean;
        readonly type: "AssetHasNoReserve" | "NotCrossChainTransfer" | "InvalidDest" | "NotCrossChainTransferableCurrency" | "UnweighableMessage" | "XcmExecutionFailed" | "CannotReanchor" | "InvalidAncestry" | "InvalidAsset" | "DestinationNotInvertible" | "BadVersion" | "DistinctReserveForAssetAndFee" | "ZeroFee" | "ZeroAmount" | "TooManyAssetsBeingSent" | "AssetIndexNonExistent" | "FeeNotEnough" | "NotSupportedMultiLocation" | "MinXcmFeeNotDefined";
    }
    /** @name PalletXcmTransactorError (575) */
    interface PalletXcmTransactorError extends Enum {
        readonly isIndexAlreadyClaimed: boolean;
        readonly isUnclaimedIndex: boolean;
        readonly isNotOwner: boolean;
        readonly isUnweighableMessage: boolean;
        readonly isCannotReanchor: boolean;
        readonly isAssetHasNoReserve: boolean;
        readonly isInvalidDest: boolean;
        readonly isNotCrossChainTransfer: boolean;
        readonly isAssetIsNotReserveInDestination: boolean;
        readonly isDestinationNotInvertible: boolean;
        readonly isErrorDelivering: boolean;
        readonly isDispatchWeightBiggerThanTotalWeight: boolean;
        readonly isWeightOverflow: boolean;
        readonly isAmountOverflow: boolean;
        readonly isTransactorInfoNotSet: boolean;
        readonly isNotCrossChainTransferableCurrency: boolean;
        readonly isXcmExecuteError: boolean;
        readonly isBadVersion: boolean;
        readonly isMaxWeightTransactReached: boolean;
        readonly isUnableToWithdrawAsset: boolean;
        readonly isFeePerSecondNotSet: boolean;
        readonly isSignedTransactNotAllowedForDestination: boolean;
        readonly isFailedMultiLocationToJunction: boolean;
        readonly isHrmpHandlerNotImplemented: boolean;
        readonly isTooMuchFeeUsed: boolean;
        readonly isErrorValidating: boolean;
        readonly type: "IndexAlreadyClaimed" | "UnclaimedIndex" | "NotOwner" | "UnweighableMessage" | "CannotReanchor" | "AssetHasNoReserve" | "InvalidDest" | "NotCrossChainTransfer" | "AssetIsNotReserveInDestination" | "DestinationNotInvertible" | "ErrorDelivering" | "DispatchWeightBiggerThanTotalWeight" | "WeightOverflow" | "AmountOverflow" | "TransactorInfoNotSet" | "NotCrossChainTransferableCurrency" | "XcmExecuteError" | "BadVersion" | "MaxWeightTransactReached" | "UnableToWithdrawAsset" | "FeePerSecondNotSet" | "SignedTransactNotAllowedForDestination" | "FailedMultiLocationToJunction" | "HrmpHandlerNotImplemented" | "TooMuchFeeUsed" | "ErrorValidating";
    }
    /** @name PalletRandomnessRequestState (577) */
    interface PalletRandomnessRequestState extends Struct {
        readonly request: PalletRandomnessRequest;
        readonly deposit: u128;
    }
    /** @name PalletRandomnessRequest (578) */
    interface PalletRandomnessRequest extends Struct {
        readonly refundAddress: H160;
        readonly contractAddress: H160;
        readonly fee: u128;
        readonly gasLimit: u64;
        readonly numWords: u8;
        readonly salt: H256;
        readonly info: PalletRandomnessRequestInfo;
    }
    /** @name PalletRandomnessRequestInfo (579) */
    interface PalletRandomnessRequestInfo extends Enum {
        readonly isBabeEpoch: boolean;
        readonly asBabeEpoch: ITuple<[u64, u64]>;
        readonly isLocal: boolean;
        readonly asLocal: ITuple<[u32, u32]>;
        readonly type: "BabeEpoch" | "Local";
    }
    /** @name PalletRandomnessRequestType (580) */
    interface PalletRandomnessRequestType extends Enum {
        readonly isBabeEpoch: boolean;
        readonly asBabeEpoch: u64;
        readonly isLocal: boolean;
        readonly asLocal: u32;
        readonly type: "BabeEpoch" | "Local";
    }
    /** @name PalletRandomnessRandomnessResult (581) */
    interface PalletRandomnessRandomnessResult extends Struct {
        readonly randomness: Option<H256>;
        readonly requestCount: u64;
    }
    /** @name PalletRandomnessError (582) */
    interface PalletRandomnessError extends Enum {
        readonly isRequestCounterOverflowed: boolean;
        readonly isRequestFeeOverflowed: boolean;
        readonly isMustRequestAtLeastOneWord: boolean;
        readonly isCannotRequestMoreWordsThanMax: boolean;
        readonly isCannotRequestRandomnessAfterMaxDelay: boolean;
        readonly isCannotRequestRandomnessBeforeMinDelay: boolean;
        readonly isRequestDNE: boolean;
        readonly isRequestCannotYetBeFulfilled: boolean;
        readonly isOnlyRequesterCanIncreaseFee: boolean;
        readonly isRequestHasNotExpired: boolean;
        readonly isRandomnessResultDNE: boolean;
        readonly isRandomnessResultNotFilled: boolean;
        readonly type: "RequestCounterOverflowed" | "RequestFeeOverflowed" | "MustRequestAtLeastOneWord" | "CannotRequestMoreWordsThanMax" | "CannotRequestRandomnessAfterMaxDelay" | "CannotRequestRandomnessBeforeMinDelay" | "RequestDNE" | "RequestCannotYetBeFulfilled" | "OnlyRequesterCanIncreaseFee" | "RequestHasNotExpired" | "RandomnessResultDNE" | "RandomnessResultNotFilled";
    }
    /** @name AccountEthereumSignature (584) */
    interface AccountEthereumSignature extends SpCoreEcdsaSignature {
    }
    /** @name FrameSystemExtensionsCheckNonZeroSender (586) */
    type FrameSystemExtensionsCheckNonZeroSender = Null;
    /** @name FrameSystemExtensionsCheckSpecVersion (587) */
    type FrameSystemExtensionsCheckSpecVersion = Null;
    /** @name FrameSystemExtensionsCheckTxVersion (588) */
    type FrameSystemExtensionsCheckTxVersion = Null;
    /** @name FrameSystemExtensionsCheckGenesis (589) */
    type FrameSystemExtensionsCheckGenesis = Null;
    /** @name FrameSystemExtensionsCheckNonce (592) */
    interface FrameSystemExtensionsCheckNonce extends Compact<u32> {
    }
    /** @name FrameSystemExtensionsCheckWeight (593) */
    type FrameSystemExtensionsCheckWeight = Null;
    /** @name PalletTransactionPaymentChargeTransactionPayment (594) */
    interface PalletTransactionPaymentChargeTransactionPayment extends Compact<u128> {
    }
    /** @name MoonriverRuntimeRuntime (596) */
    type MoonriverRuntimeRuntime = Null;
}
